{-# LANGUAGE MagicHash #-}
{-# LANGUAGE ScopedTypeVariables #-}
{-# OPTIONS_GHC -fno-warn-overlapping-patterns #-}

module Curry_REPL
  ( C_GoalCompile (..)
  , d_C_writeErrorMsg
  , d_C_main
  , d_C_defaultImportPaths
  , d_C_defaultImportPathsWith
  , d_C_processArgsAndStart
  , d_C_isCommand
  , d_C_printHelpOnInteractive
  , d_C_printHelpOnTools
  , d_C_getBanner
  , d_C_numericVersion
  , d_C_repl
  , d_C_calcPrompt
  , d_C_cleanUpAndExitRepl
  , d_C_processInput
  , d_C_evalExpression
  , d_C_importUnsafeModule
  , d_C_currentFrontendParams
  , d_C_writeSimpleMainGoalFile
  , d_C_writeMainGoalFile
  , d_C_cleanMainGoalFile
  , d_C_getAcyOfMainGoal
  , d_C_getAcyOfExpr
  , d_C_showTypeOfGoal
  , d_C_getModuleOfFunction
  , d_C_compileProgramWithGoal
  , d_C_insertFreeVarsInMainGoal
  , d_C_makeMainGoalMonomorphic
  , d_C_compileCurryProgram
  , d_C_execMain
  , d_C_processCommand
  , d_C_unsafeExec
  , nd_C_unsafeExec
  , d_C_replCommands
  , nd_C_replCommands
  , d_C_skipCommand
  , d_C_processSysCall
  , d_C_processQuit
  , d_C_processHelp
  , d_C_processCompile
  , d_C_processLoad
  , d_C_processReload
  , d_C_processAdd
  , d_C_validModuleName
  , d_C_processEval
  , d_C_processType
  , d_C_processCd
  , d_C_processPrograms
  , d_C_processEdit
  , d_C_processSource
  , d_C_getModuleName
  , d_C_processShow
  , d_C_processInterface
  , d_C_processBrowse
  , d_C_processUsedImports
  , d_C_processSave
  , d_C_processFork
  , d_C_processSetOption
  , d_C_availOptions
  , nd_C_availOptions
  , d_C_replOptions
  , nd_C_replOptions
  , d_C_setLocalMode
  , d_C_setPrompt
  , d_C_setNoGhci
  , d_C_setOptionPath
  , d_C_setOptionNDMode
  , nd_C_setOptionNDMode
  , d_C_setOptionSupply
  , d_C_printOptions
  , d_C_ifLocal
  , d_C_ifProfiling
  , d_C_showCurrentOptions
  , d_C_printHelpOnCommands
  , d_C_printAllLoadPathPrograms
  , d_C_showFunctionInModule
  , d_C_checkAndCallCpmTool
  , nd_C_checkAndCallCpmTool
  , d_C_execCommandWithPath
  , d_C_checkForCommand
  , nd_C_checkForCommand
  , d_C_checkForWish
  , nd_C_checkForWish
  , d_C_readAndProcessSourceFileOptions
  , d_C_processSourceFileOptions
  , d_C_readSourceFileOptions
  , d_C_terminateSourceProgGUIs )
  where

import Basics
import qualified AbstractCurry.Curry_Files
import qualified AbstractCurry.Curry_Select
import qualified AbstractCurry.Curry_Types
import qualified Curry_Char
import qualified Curry_Directory
import qualified Curry_Distribution
import qualified Curry_FilePath
import qualified Curry_Files
import qualified FlatCurry.Curry_Files
import qualified FlatCurry.Curry_Goodies
import qualified FlatCurry.Curry_Types
import qualified Curry_GhciComm
import qualified Curry_IO
import qualified Curry_IOExts
import qualified Curry_Installation
import qualified Curry_Linker
import qualified Curry_List
import qualified Curry_Names
import qualified Curry_Prelude
import qualified Curry_RCFile
import qualified Curry_ReadNumeric
import qualified Curry_ReadShowTerm
import qualified Curry_Sort
import qualified Curry_System
import qualified Curry_Time
import qualified Curry_Utils


data C_GoalCompile
  = C_GoalError
  | C_GoalWithoutBindings AbstractCurry.Curry_Types.C_CurryProg
  | C_GoalWithBindings AbstractCurry.Curry_Types.C_CurryProg Curry_Prelude.C_Int
    (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  | Choice_C_GoalCompile Cover ID C_GoalCompile C_GoalCompile
  | Choices_C_GoalCompile Cover ID [C_GoalCompile]
  | Fail_C_GoalCompile Cover FailInfo
  | Guard_C_GoalCompile Cover Constraints C_GoalCompile

instance Show C_GoalCompile where
  showsPrec d (Choice_C_GoalCompile cd i x y) = showsChoice d cd i x y
  showsPrec d (Choices_C_GoalCompile cd i xs) = showsChoices d cd i xs
  showsPrec d (Guard_C_GoalCompile cd c e) = showsGuard d cd c e
  showsPrec _ (Fail_C_GoalCompile cd info) = showChar '!'
  showsPrec _ C_GoalError = showString "GoalError"
  showsPrec _ (C_GoalWithoutBindings x1) = showString "(GoalWithoutBindings" .
    (showChar ' ' . (shows x1 . showChar ')'))
  showsPrec _ (C_GoalWithBindings x1 x2 x3) = showString "(GoalWithBindings" .
    (showChar ' ' . (shows x1 . (showChar ' ' . (shows x2 . (showChar ' ' .
    (shows x3 . showChar ')'))))))

instance Read C_GoalCompile where
  readsPrec d s = readParen False (\r -> [(C_GoalError, r0) | (_, r0) <-
    readQualified "REPL" "GoalError" r]) s ++ (readParen ((>) d 10) (\r ->
    [(C_GoalWithoutBindings x1, r1) | (_, r0) <- readQualified "REPL"
    "GoalWithoutBindings" r, (x1, r1) <- readsPrec 11 r0]) s ++ readParen ((>) d
    10) (\r -> [(C_GoalWithBindings x1 x2 x3, r3) | (_, r0) <- readQualified
    "REPL" "GoalWithBindings" r, (x1, r1) <- readsPrec 11 r0, (x2, r2) <-
    readsPrec 11 r1, (x3, r3) <- readsPrec 11 r2]) s)

instance NonDet C_GoalCompile where
  choiceCons = Choice_C_GoalCompile
  choicesCons = Choices_C_GoalCompile
  failCons = Fail_C_GoalCompile
  guardCons = Guard_C_GoalCompile
  try (Choice_C_GoalCompile cd i x y) = tryChoice cd i x y
  try (Choices_C_GoalCompile cd i xs) = tryChoices cd i xs
  try (Fail_C_GoalCompile cd info) = Fail cd info
  try (Guard_C_GoalCompile cd c e) = Guard cd c e
  try x = Val x
  match f _ _ _ _ _ (Choice_C_GoalCompile cd i x y) = f cd i x y
  match _ f _ _ _ _ (Choices_C_GoalCompile cd i@(NarrowedID _ _) xs) = f cd i xs
  match _ _ f _ _ _ (Choices_C_GoalCompile cd i@(FreeID _ _) xs) = f cd i xs
  match _ _ _ _ _ _ (Choices_C_GoalCompile cd i _) = error
    ("REPL.GoalCompile.match: Choices with ChoiceID " ++ show i)
  match _ _ _ f _ _ (Fail_C_GoalCompile cd info) = f cd info
  match _ _ _ _ f _ (Guard_C_GoalCompile cd c e) = f cd c e
  match _ _ _ _ _ f x = f x

instance Generable C_GoalCompile where
  generate s c = Choices_C_GoalCompile c (freeID [0, 1, 3] s) [C_GoalError
    , C_GoalWithoutBindings (generate (leftSupply s) c), C_GoalWithBindings
    (generate (leftSupply (leftSupply s)) c) (generate (rightSupply (leftSupply
    s)) c) (generate (rightSupply s) c)]

instance NormalForm C_GoalCompile where
  ($!!) cont C_GoalError d cs = cont C_GoalError d cs
  ($!!) cont (C_GoalWithoutBindings x1) d cs = ($!!) (\y1 d cs -> cont
    (C_GoalWithoutBindings y1) d cs) x1 d cs
  ($!!) cont (C_GoalWithBindings x1 x2 x3) d cs = ($!!) (\y1 d cs -> ($!!)
    (\y2 d cs -> ($!!) (\y3 d cs -> cont (C_GoalWithBindings y1 y2 y3) d cs) x3
    d cs) x2 d cs) x1 d cs
  ($!!) cont (Choice_C_GoalCompile cd i x y) d cs = nfChoice cont cd i x y cd cs
  ($!!) cont (Choices_C_GoalCompile cd i xs) d cs = nfChoices cont cd i xs d cs
  ($!!) cont (Guard_C_GoalCompile cd c e) d cs = guardCons cd c (($!!) cont e d
    (addCs c cs))
  ($!!) _ (Fail_C_GoalCompile cd info) _ _ = failCons cd info
  ($##) cont C_GoalError d cs = cont C_GoalError d cs
  ($##) cont (C_GoalWithoutBindings x1) d cs = ($##) (\y1 d cs -> cont
    (C_GoalWithoutBindings y1) d cs) x1 d cs
  ($##) cont (C_GoalWithBindings x1 x2 x3) d cs = ($##) (\y1 d cs -> ($##)
    (\y2 d cs -> ($##) (\y3 d cs -> cont (C_GoalWithBindings y1 y2 y3) d cs) x3
    d cs) x2 d cs) x1 d cs
  ($##) cont (Choice_C_GoalCompile cd i x y) d cs = gnfChoice cont cd i x y cd
    cs
  ($##) cont (Choices_C_GoalCompile cd i xs) d cs = gnfChoices cont cd i xs d cs
  ($##) cont (Guard_C_GoalCompile cd c e) d cs = guardCons cd c (($##) cont e d
    (addCs c cs))
  ($##) _ (Fail_C_GoalCompile cd info) _ _ = failCons cd info
  showCons C_GoalError = "REPL.GoalError"
  showCons (C_GoalWithoutBindings _) = "REPL.GoalWithoutBindings _"
  showCons (C_GoalWithBindings _ _ _) = "REPL.GoalWithBindings _ _ _"
  showCons x = error ("REPL.GoalCompile.showCons: no constructor: " ++ show x)
  searchNF _ cont C_GoalError = cont C_GoalError
  searchNF search cont (C_GoalWithoutBindings x1) = search (\y1 -> cont
    (C_GoalWithoutBindings y1)) x1
  searchNF search cont (C_GoalWithBindings x1 x2 x3) = search (\y1 -> search
    (\y2 -> search (\y3 -> cont (C_GoalWithBindings y1 y2 y3)) x3) x2) x1
  searchNF _ _ x = error ("REPL.GoalCompile.searchNF: no constructor: " ++ show
    x)

instance Unifiable C_GoalCompile where
  (=.=) C_GoalError C_GoalError d cs = C_True
  (=.=) (C_GoalWithoutBindings x1) (C_GoalWithoutBindings y1) d cs = (=:=) x1 y1
    d cs
  (=.=) (C_GoalWithBindings x1 x2 x3) (C_GoalWithBindings y1 y2 y3) d cs = (&)
    ((=:=) x1 y1 d cs) ((&) ((=:=) x2 y2 d cs) ((=:=) x3 y3 d cs) d cs) d cs
  (=.=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  (=.<=) C_GoalError C_GoalError d cs = C_True
  (=.<=) (C_GoalWithoutBindings x1) (C_GoalWithoutBindings y1) d cs = (=:<=) x1
    y1 d cs
  (=.<=) (C_GoalWithBindings x1 x2 x3) (C_GoalWithBindings y1 y2 y3) d cs = (&)
    ((=:<=) x1 y1 d cs) ((&) ((=:<=) x2 y2 d cs) ((=:<=) x3 y3 d cs) d cs) d cs
  (=.<=) a b cd _ = Fail_C_Bool cd (unificationFail (showCons a) (showCons b))
  bind cd i C_GoalError = (i :=: ChooseN 0 0) : concat []
  bind cd i (C_GoalWithoutBindings x3) = (i :=: ChooseN 1 1) : concat [bind cd
    (leftID i) x3]
  bind cd i (C_GoalWithBindings x3 x4 x5) = (i :=: ChooseN 2 3) : concat [bind
    cd (leftID (leftID i)) x3, bind cd (rightID (leftID i)) x4, bind cd (rightID
    i) x5]
  bind d i (Choice_C_GoalCompile cd j x y) = [ConstraintChoice cd j (bind d i x)
    (bind d i y)]
  bind d i (Choices_C_GoalCompile cd j@(FreeID _ _) xs) = bindOrNarrow d i cd j
    xs
  bind d i (Choices_C_GoalCompile cd j@(NarrowedID _ _) xs) = [ConstraintChoices
    cd j (map (bind d i) xs)]
  bind _ _ (Choices_C_GoalCompile cd i _) = error
    ("REPL.GoalCompile.bind: Choices with ChoiceID: " ++ show i)
  bind _ _ (Fail_C_GoalCompile cd info) = [Unsolvable info]
  bind d i (Guard_C_GoalCompile cd c e) = getConstrList c ++ bind d i e
  lazyBind cd i C_GoalError = (i :=: ChooseN 0 0) : []
  lazyBind cd i (C_GoalWithoutBindings x3) = (i :=: ChooseN 1 1) : [leftID i :=:
    LazyBind (lazyBind cd (leftID i) x3)]
  lazyBind cd i (C_GoalWithBindings x3 x4 x5) = (i :=: ChooseN 2 3) : [leftID
    (leftID i) :=: LazyBind (lazyBind cd (leftID (leftID i)) x3), rightID
    (leftID i) :=: LazyBind (lazyBind cd (rightID (leftID i)) x4), rightID i :=:
    LazyBind (lazyBind cd (rightID i) x5)]
  lazyBind d i (Choice_C_GoalCompile cd j x y) = [ConstraintChoice cd j
    (lazyBind d i x) (lazyBind d i y)]
  lazyBind d i (Choices_C_GoalCompile cd j@(FreeID _ _) xs) = lazyBindOrNarrow d
    i cd j xs
  lazyBind d i (Choices_C_GoalCompile cd j@(NarrowedID _ _) xs) =
    [ConstraintChoices cd j (map (lazyBind d i) xs)]
  lazyBind _ _ (Choices_C_GoalCompile cd i _) = error
    ("REPL.GoalCompile.lazyBind: Choices with ChoiceID: " ++ show i)
  lazyBind _ _ (Fail_C_GoalCompile cd info) = [Unsolvable info]
  lazyBind d i (Guard_C_GoalCompile cd c e) = getConstrList c ++ [i :=: LazyBind
    (lazyBind d i e)]

instance Curry C_GoalCompile where
  (=?=) (Choice_C_GoalCompile cd i x y) z d cs = narrow cd i ((=?=) x z d cs)
    ((=?=) y z d cs)
  (=?=) (Choices_C_GoalCompile cd i xs) y d cs = narrows cs cd i (\x -> (=?=) x
    y d cs) xs
  (=?=) (Guard_C_GoalCompile cd c e) y d cs = guardCons cd c ((=?=) e y d (addCs
    c cs))
  (=?=) (Fail_C_GoalCompile cd info) _ _ _ = failCons cd info
  (=?=) z (Choice_C_GoalCompile cd i x y) d cs = narrow cd i ((=?=) z x d cs)
    ((=?=) z y d cs)
  (=?=) y (Choices_C_GoalCompile cd i xs) d cs = narrows cs cd i (\x -> (=?=) y
    x d cs) xs
  (=?=) y (Guard_C_GoalCompile cd c e) d cs = guardCons cd c ((=?=) y e d (addCs
    c cs))
  (=?=) _ (Fail_C_GoalCompile cd info) _ _ = failCons cd info
  (=?=) C_GoalError C_GoalError d cs = C_True
  (=?=) (C_GoalWithoutBindings x1) (C_GoalWithoutBindings y1) d cs = (=?=) x1 y1
    d cs
  (=?=) (C_GoalWithBindings x1 x2 x3) (C_GoalWithBindings y1 y2 y3) d cs =
    Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_amp_amp
    ((=?=) x2 y2 d cs) ((=?=) x3 y3 d cs) d cs) d cs
  (=?=) _ _ d _ = C_False
  (<?=) (Choice_C_GoalCompile cd i x y) z d cs = narrow cd i ((<?=) x z d cs)
    ((<?=) y z d cs)
  (<?=) (Choices_C_GoalCompile cd i xs) y d cs = narrows cs cd i (\x -> (<?=) x
    y d cs) xs
  (<?=) (Guard_C_GoalCompile cd c e) y d cs = guardCons cd c ((<?=) e y d (addCs
    c cs))
  (<?=) (Fail_C_GoalCompile cd info) _ _ _ = failCons cd info
  (<?=) z (Choice_C_GoalCompile cd i x y) d cs = narrow cd i ((<?=) z x d cs)
    ((<?=) z y d cs)
  (<?=) y (Choices_C_GoalCompile cd i xs) d cs = narrows cs cd i (\x -> (<?=) y
    x d cs) xs
  (<?=) y (Guard_C_GoalCompile cd c e) d cs = guardCons cd c ((<?=) y e d (addCs
    c cs))
  (<?=) _ (Fail_C_GoalCompile cd info) _ _ = failCons cd info
  (<?=) C_GoalError C_GoalError d cs = C_True
  (<?=) C_GoalError (C_GoalWithoutBindings _) _ _ = C_True
  (<?=) C_GoalError (C_GoalWithBindings _ _ _) _ _ = C_True
  (<?=) (C_GoalWithoutBindings x1) (C_GoalWithoutBindings y1) d cs = (<?=) x1 y1
    d cs
  (<?=) (C_GoalWithoutBindings _) (C_GoalWithBindings _ _ _) _ _ = C_True
  (<?=) (C_GoalWithBindings x1 x2 x3) (C_GoalWithBindings y1 y2 y3) d cs =
    Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_lt x1 y1 d cs)
    (Curry_Prelude.d_OP_amp_amp ((=?=) x1 y1 d cs) (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_lt x2 y2 d cs) (Curry_Prelude.d_OP_amp_amp ((=?=) x2 y2
    d cs) ((<?=) x3 y3 d cs) d cs) d cs) d cs) d cs
  (<?=) _ _ d _ = C_False

d_C_writeErrorMsg :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_writeErrorMsg x1 cd cs = Curry_Prelude.d_C_putStrLn
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "ERROR: ") x1 cd
  cs) cd cs

d_C_main :: Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_main cd cs = Curry_Prelude.d_OP_gt_gt_eq (Curry_RCFile.d_C_readRC cd cs)
  d_OP_main_dot_uscore_hash_lambda1 cd cs

d_OP_main_dot_uscore_hash_lambda1 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_main_dot_uscore_hash_lambda1 x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_System.d_C_getArgs cd cs)
  (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 x1) cd cs

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2 x1 x2 cd cs =
  let x3 = Curry_RCFile.d_C_extractRCArgs x2 cd cs
      x4 = d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs
        x3 cd cs
      x5 = d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs
        x3 cd cs
      x6 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_break
        (Curry_Prelude.d_C_flip (acceptCs id Curry_Prelude.d_OP_eq_eq)
        (Curry_Prelude.toCurryString "--")) cd cs) x4 cd cs
      x7 = d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs
        x6 cd cs
      x8 = d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs
        x6 cd cs
      x9 = Curry_RCFile.d_C_updateRCDefs x1 x5 cd cs
      x10 = Curry_Prelude.d_C_filter
        (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_lambda3
        x1) x5 cd cs
      x11 = d_C__case_201 x8 x9 (Curry_Linker.d_C_initReplState cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (d_C_defaultImportPaths x11 cd cs)
  (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_lambda36
  x10 x7 x11) cd cs

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char))) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs
    l cd cs)
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP5_hash_nodefargs
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.main._#lambda1._#lambda2._#selFP5#nodefargs" [show x1] info)
  _ -> failCons cd (consFail "REPL.main._#lambda1._#lambda2._#selFP5#nodefargs"
    (showCons x1))

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char))) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs
    l cd cs)
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP6_hash_defargs
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.main._#lambda1._#lambda2._#selFP6#defargs" [show x1] info)
  _ -> failCons cd (consFail "REPL.main._#lambda1._#lambda2._#selFP6#defargs"
    (showCons x1))

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs
    l cd cs)
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP3_hash_mainargs
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.main._#lambda1._#lambda2._#selFP3#mainargs" [show x1] info)
  _ -> failCons cd (consFail "REPL.main._#lambda1._#lambda2._#selFP3#mainargs"
    (showCons x1))

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs
    l cd cs)
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_selFP4_hash_rtargs
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.main._#lambda1._#lambda2._#selFP4#rtargs" [show x1] info)
  _ -> failCons cd (consFail "REPL.main._#lambda1._#lambda2._#selFP4#rtargs"
    (showCons x1))

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_lambda3 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_lambda3 x1 x2 cd cs =
  Curry_Prelude.d_C_apply (Curry_Prelude.d_C_notElem (Curry_Prelude.d_C_fst x2
  cd cs) cd cs) (Curry_Prelude.d_C_map Curry_Prelude.d_C_fst x1 cd cs) cd cs

d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_lambda36 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_main_dot_uscore_hash_lambda1_dot_uscore_hash_lambda2_dot_uscore_hash_lambda36 x1 x2 x3 x4 cd cs =
  d_C__case_199 x1 x2 x3 x4 (Curry_Prelude.d_C_null x1 cd cs) cd cs

d_C_defaultImportPaths :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C_defaultImportPaths x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_System.d_C_getEnviron (Curry_Prelude.toCurryString "CURRYPATH") cd cs)
  (d_OP_defaultImportPaths_dot_uscore_hash_lambda69 x1) cd cs

d_OP_defaultImportPaths_dot_uscore_hash_lambda69 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_OP_defaultImportPaths_dot_uscore_hash_lambda69 x1 x2 cd cs =
  let x3 = Curry_RCFile.d_C_rcValue (Curry_Linker.d_C_rcvars x1 cd cs)
        (Curry_Prelude.toCurryString "libraries") cd cs
  in Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_return
  (Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_filter (Curry_Prelude.d_C_flip
  (acceptCs id Curry_Prelude.d_OP_slash_eq) (Curry_Prelude.toCurryString ".")))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_C_splitSearchPath cd cs) x2 cd cs) (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_C_splitSearchPath cd cs) x3 cd cs) cd cs) cd cs) cd cs

d_C_defaultImportPathsWith :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C_defaultImportPathsWith x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_defaultImportPaths x1 cd cs)
  (d_OP_defaultImportPathsWith_dot_uscore_hash_lambda70 x2) cd cs

d_OP_defaultImportPathsWith_dot_uscore_hash_lambda70 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_defaultImportPathsWith_dot_uscore_hash_lambda70 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_mapIO
  Curry_Directory.d_C_getAbsolutePath cd cs) (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_C_splitSearchPath cd cs) x1 cd cs) cd cs)
  (d_OP_defaultImportPathsWith_dot_uscore_hash_lambda70_dot_uscore_hash_lambda71
  x2) cd cs

d_OP_defaultImportPathsWith_dot_uscore_hash_lambda70_dot_uscore_hash_lambda71 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_OP_defaultImportPathsWith_dot_uscore_hash_lambda70_dot_uscore_hash_lambda71 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.d_OP_plus_plus x2 x1 cd cs) cd cs

d_C_processArgsAndStart :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_processArgsAndStart x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_List -> d_C__case_197 x1 (Curry_Linker.d_C_quit x1 cd cs) cd
    cs
  Curry_Prelude.OP_Cons x3 x4 -> let x5 = Curry_Prelude.d_OP_gt_gt
                                       (d_C_printHelpOnInteractive cd cs)
                                       (d_C_printHelpOnTools cd cs) cd cs
    in d_C__case_195 x3 x5 x4 x1 (Curry_Prelude.d_C_null x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_processArgsAndStart x1
    l cd cs) (d_C_processArgsAndStart x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_C_processArgsAndStart x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C_processArgsAndStart x1
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.processArgsAndStart" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.processArgsAndStart" (showCons x2))

d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs l cd cs)
    (d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs e cd $! addCs
    c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processArgsAndStart._#selFP8#cmdargs" [show x1] info)
  _ -> failCons cd (consFail "REPL.processArgsAndStart._#selFP8#cmdargs"
    (showCons x1))

d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more l cd cs)
    (d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processArgsAndStart._#selFP9#more" [show x1] info)
  _ -> failCons cd (consFail "REPL.processArgsAndStart._#selFP9#more" (showCons
    x1))

d_OP_processArgsAndStart_dot_uscore_hash_lambda72 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit -> Curry_Prelude.C_Maybe Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_processArgsAndStart_dot_uscore_hash_lambda72 x1 x2 x3 cd cs =
  Curry_Prelude.d_C_maybe x2
  (d_OP_processArgsAndStart_dot_uscore_hash_lambda72_dot_uscore_hash_lambda73
  x1) x3 cd cs

nd_OP_processArgsAndStart_dot_uscore_hash_lambda72 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit -> Curry_Prelude.C_Maybe Curry_Linker.C_ReplState
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_OP_processArgsAndStart_dot_uscore_hash_lambda72 x1 x2 x3 s cd cs = let s0 = s
  in s0 `seq` Curry_Prelude.nd_C_maybe x2 (wrapDX id
  (d_OP_processArgsAndStart_dot_uscore_hash_lambda72_dot_uscore_hash_lambda73
  x1)) x3 s0 cd cs

d_OP_processArgsAndStart_dot_uscore_hash_lambda72_dot_uscore_hash_lambda73 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_processArgsAndStart_dot_uscore_hash_lambda72_dot_uscore_hash_lambda73 x1 x2 cd cs =
  d_C_processArgsAndStart x2 x1 cd cs

d_C_isCommand :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C_isCommand x1 cd cs = case x1 of
  Curry_Prelude.OP_Cons x2 x3 -> d_C__case_186 x2 (Curry_Prelude.d_OP_eq_eq x2
    (Curry_Prelude.C_Char ':'#) cd cs) cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.C_False
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C_isCommand l cd cs)
    (d_C_isCommand r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C_isCommand z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C_isCommand e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL.isCommand"
    [show x1] info)
  _ -> failCons cd (consFail "REPL.isCommand" (showCons x1))

d_C_printHelpOnInteractive :: Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_printHelpOnInteractive cd cs = Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_putStrLn (Curry_Prelude.d_C_unlines (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "Invoke interactive environment:")
  (Curry_Prelude.OP_Cons Curry_Prelude.OP_List (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "    kics2 <options> <commands>")
  (Curry_Prelude.OP_Cons Curry_Prelude.OP_List (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "with options:") (Curry_Prelude.OP_Cons
  Curry_Prelude.OP_List (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "-h|--help|-?      : show this message and quit") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "-V|--version      : show version and quit")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "--compiler-name   : show the compiler name `kics2' and quit")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "--numeric-version : show the compiler version number and quit")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "--noreadline      : do not use input line editing via command `rlwrap'")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "-Dprop=val        : define kics2rc property `prop' as `val'")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "<commands>        : list of commands of the KiCS2 environment")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "                    (run `kics2 :h :q' to see the list of all commands)")
  (Curry_Prelude.OP_Cons Curry_Prelude.OP_List
  Curry_Prelude.OP_List))))))))))))))) cd cs) cd cs

d_C_printHelpOnTools :: Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_printHelpOnTools cd cs = Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_putStrLn (Curry_Prelude.d_C_unlines (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "Invoke some tool:") (Curry_Prelude.OP_Cons
  Curry_Prelude.OP_List (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "    kics2 <tool> <tool specific options>") (Curry_Prelude.OP_Cons
  Curry_Prelude.OP_List (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "where <tool> is one of:") (Curry_Prelude.OP_Cons Curry_Prelude.OP_List
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "addtypes  : add missing signature to top-level operations")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "analyze   : analyze various properties (via CASS)") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "browse    : browse and analyze")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "check     : check properties") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "createmake: create make file for main module")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "data2xml  : generate XML bindings") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "doc       : generate documentation for Curry programs")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "erd2cdbi  : create database code for ER model and Database.CDBI libraries")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "erd2curry : create database code for ER model") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "frontend  : Curry front end")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "makecgi   : translate Curry HTML program into CGI program")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "peval     : partially evaluate a program") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "pp        : Curry preprocessor")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "spiceup   : create web application via Spicey") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "style     : check style of source programs")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "test      : test assertions (obsolete, no longer supported)")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "verify    : translate Curry module to Agda for property verification")
  (Curry_Prelude.OP_Cons Curry_Prelude.OP_List (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "To get more help about the usage of a tool, type") (Curry_Prelude.OP_Cons
  Curry_Prelude.OP_List (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "    kics2 <tool> -h") Curry_Prelude.OP_List))))))))))))))))))))))))))) cd cs)
  cd cs

d_C_getBanner :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_getBanner cd cs = let x1 = Curry_Prelude.d_OP_plus_plus
                            (Curry_Prelude.toCurryString "Version ")
                            (Curry_Prelude.d_OP_plus_plus (d_C_numericVersion cd
                            cs) (Curry_Prelude.d_OP_plus_plus (d_C__case_185
                            (Curry_Prelude.d_OP_eq_eq
                            (Curry_Installation.d_C_buildVersion cd cs)
                            (Curry_Prelude.C_Int 0#) cd cs) cd cs)
                            (Curry_Prelude.d_OP_plus_plus
                            (Curry_Prelude.toCurryString " of ")
                            (Curry_Prelude.d_OP_plus_plus
                            (Curry_Installation.d_C_compilerDate cd cs)
                            (Curry_Prelude.d_OP_plus_plus
                            (Curry_Prelude.toCurryString " (installed at ")
                            (Curry_Prelude.d_OP_plus_plus
                            (Curry_Installation.d_C_installDate cd cs)
                            (Curry_Prelude.toCurryString ")") cd cs) cd cs) cd
                            cs) cd cs) cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_readFile (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Installation.d_C_installDir cd
  cs) cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString
  "include") cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_dot_gt cd cs) (Curry_Prelude.toCurryString "logo") cd
  cs) (Curry_Prelude.toCurryString "txt") cd cs) cd cs) cd cs) cd cs)
  (d_OP_getBanner_dot_uscore_hash_lambda75 x1) cd cs

d_OP_getBanner_dot_uscore_hash_lambda75 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_getBanner_dot_uscore_hash_lambda75 x1 x2 cd cs = Curry_Prelude.d_C_return
  (Curry_Prelude.d_OP_plus_plus x2 x1 cd cs) cd cs

d_C_numericVersion :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_numericVersion cd cs = Curry_List.d_C_intercalate
  (Curry_Prelude.toCurryString ".") (Curry_Prelude.d_C_map
  Curry_Prelude.d_C_show (Curry_Prelude.OP_Cons
  (Curry_Installation.d_C_majorVersion cd cs) (Curry_Prelude.OP_Cons
  (Curry_Installation.d_C_minorVersion cd cs) (Curry_Prelude.OP_Cons
  (Curry_Installation.d_C_revisionVersion cd cs) Curry_Prelude.OP_List))) cd cs)
  cd cs

d_C_repl :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_repl x1 cd cs = Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_gt_gt
  (Curry_Prelude.d_C_putStr (d_C_calcPrompt x1 cd cs) cd cs)
  (Curry_IO.d_C_hFlush (Curry_IO.d_C_stdout cd cs) cd cs) cd cs)
  (Curry_Prelude.d_OP_gt_gt_eq (Curry_IO.d_C_isEOF cd cs)
  (d_OP_repl_dot_uscore_hash_lambda76 x1) cd cs) cd cs

d_OP_repl_dot_uscore_hash_lambda76 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_OP_repl_dot_uscore_hash_lambda76 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> d_C_cleanUpAndExitRepl x1 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_Prelude.d_C_getLine cd cs) (Curry_Prelude.d_OP_dot (d_C_processInput
    x1) (Curry_Utils.d_C_strip cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_repl_dot_uscore_hash_lambda76 x1 l cd cs)
    (d_OP_repl_dot_uscore_hash_lambda76 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_repl_dot_uscore_hash_lambda76 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_repl_dot_uscore_hash_lambda76 x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.repl._#lambda76" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.repl._#lambda76" (showCons x2))

d_C_calcPrompt :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_calcPrompt x1 cd cs = let x2 = Curry_Prelude.d_C_unwords
                                (Curry_Prelude.OP_Cons (Curry_Linker.d_C_mainMod
                                x1 cd cs) (Curry_Linker.d_C_addMods x1 cd cs))
                                cd cs
  in d_OP_calcPrompt_dot_subst_dot_58 x2 (Curry_Linker.d_C_prompt x1 cd cs) cd
  cs

d_OP_calcPrompt_dot_subst_dot_58 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_calcPrompt_dot_subst_dot_58 x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x3 x4 -> d_C__case_184 x3 x1 x4 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_calcPrompt_dot_subst_dot_58 x1 l cd cs)
    (d_OP_calcPrompt_dot_subst_dot_58 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_calcPrompt_dot_subst_dot_58 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_calcPrompt_dot_subst_dot_58 x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.calcPrompt.subst.58" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.calcPrompt.subst.58" (showCons x2))

d_C_cleanUpAndExitRepl :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_cleanUpAndExitRepl x1 cd cs = Curry_Prelude.d_OP_gt_gt
  (d_C_terminateSourceProgGUIs x1 cd cs) (Curry_System.d_C_exitWith
  (Curry_Linker.d_C_exitStatus x1 cd cs) cd cs) cd cs

d_C_processInput :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_processInput x1 x2 cd cs = d_C__case_180 x2 x1 (Curry_Prelude.d_C_null x2 cd
  cs) cd cs

d_OP_processInput_dot_uscore_hash_lambda79 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Maybe Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_processInput_dot_uscore_hash_lambda79 x1 x2 cd cs = Curry_Prelude.d_C_maybe
  (d_C_repl (Curry_Linker.d_C_setExitStatus (Curry_Prelude.C_Int 1#) x1 cd cs)
  cd cs) d_OP_processInput_dot_uscore_hash_lambda79_dot_uscore_hash_lambda80 x2
  cd cs

d_OP_processInput_dot_uscore_hash_lambda79_dot_uscore_hash_lambda80 :: Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_processInput_dot_uscore_hash_lambda79_dot_uscore_hash_lambda80 x1 cd cs =
  d_C__case_177 x1 (Curry_Linker.d_C_quit x1 cd cs) cd cs

d_C_evalExpression :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Linker.C_ReplState
d_C_evalExpression x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_compileProgramWithGoal x1 (Curry_Prelude.d_C_not
  (Curry_Linker.d_C_useGhci x1 cd cs) cd cs) x2 cd cs)
  (d_OP_evalExpression_dot_uscore_hash_lambda81 x2) cd cs

d_OP_evalExpression_dot_uscore_hash_lambda81 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Linker.C_ReplState
d_OP_evalExpression_dot_uscore_hash_lambda81 x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> Curry_Prelude.d_OP_gt_gt_eq (d_C__case_176 x3
    x4 x1 (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_eq_eq x4
    Curry_Linker.C_MainError cd cs) (Curry_Prelude.d_OP_amp_amp
    (Curry_Linker.d_C_useGhci x3 cd cs) (Curry_Prelude.d_C_not
    (Curry_Linker.d_C_interactive x3 cd cs) cd cs) cd cs) cd cs) cd cs)
    d_OP_evalExpression_dot_uscore_hash_lambda81_dot_uscore_hash_lambda82 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_evalExpression_dot_uscore_hash_lambda81 x1 l cd cs)
    (d_OP_evalExpression_dot_uscore_hash_lambda81 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_evalExpression_dot_uscore_hash_lambda81 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_evalExpression_dot_uscore_hash_lambda81 x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.evalExpression._#lambda81" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.evalExpression._#lambda81" (showCons x2))

d_OP_evalExpression_dot_uscore_hash_lambda81_dot_uscore_hash_lambda82 :: Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_OP_evalExpression_dot_uscore_hash_lambda81_dot_uscore_hash_lambda82 x1 cd cs =
  Curry_Prelude.d_OP_gt_gt (d_C_cleanMainGoalFile x1 cd cs)
  (Curry_Prelude.d_C_return x1 cd cs) cd cs

d_C_importUnsafeModule :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C_importUnsafeModule x1 cd cs = d_C__case_175 x1 (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_elem (Curry_Prelude.toCurryString "Unsafe") cd cs)
  (Curry_Linker.d_C_addMods x1 cd cs) cd cs) cd cs

d_OP_importUnsafeModule_dot_uscore_hash_lambda83 :: FlatCurry.Curry_Types.C_Prog
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_OP_importUnsafeModule_dot_uscore_hash_lambda83 x1 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
  (Curry_Prelude.toCurryString "Unsafe") cd cs) (Curry_Prelude.d_C_apply
  (FlatCurry.Curry_Goodies.d_C_progImports cd cs) x1 cd cs) cd cs) cd cs

d_OP_importUnsafeModule_dot_uscore_hash_lambda84 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_IOError -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.C_Bool
d_OP_importUnsafeModule_dot_uscore_hash_lambda84 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.d_OP_slash_eq
  (Curry_Linker.d_C_mainMod x1 cd cs) (Curry_Prelude.toCurryString "Prelude") cd
  cs) cd cs

d_C_currentFrontendParams :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Distribution.C_FrontendParams
d_C_currentFrontendParams x1 cd cs = Curry_Prelude.d_OP_dollar
  (Curry_Distribution.d_C_setQuiet Curry_Prelude.C_True)
  (Curry_Prelude.d_OP_dollar (Curry_Distribution.d_C_setFullPath
  (Curry_Linker.d_C_loadPaths x1 cd cs)) (Curry_Prelude.d_OP_dollar
  (Curry_Distribution.d_C_setExtended (Curry_Prelude.d_OP_slash_eq
  (Curry_RCFile.d_C_rcValue (Curry_Linker.d_C_rcvars x1 cd cs)
  (Curry_Prelude.toCurryString "curryextensions") cd cs)
  (Curry_Prelude.toCurryString "no") cd cs)) (Curry_Prelude.d_OP_dollar
  (Curry_Distribution.d_C_setOverlapWarn (Curry_Prelude.d_OP_slash_eq
  (Curry_RCFile.d_C_rcValue (Curry_Linker.d_C_rcvars x1 cd cs)
  (Curry_Prelude.toCurryString "warnoverlapping") cd cs)
  (Curry_Prelude.toCurryString "no") cd cs)) (Curry_Distribution.d_C_setSpecials
  (Curry_Linker.d_C_parseOpts x1 cd cs) (Curry_Distribution.d_C_defaultParams cd
  cs) cd cs) cd cs) cd cs) cd cs) cd cs

d_C_writeSimpleMainGoalFile :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_writeSimpleMainGoalFile x1 x2 cd cs = d_C_writeMainGoalFile x1
  Curry_Prelude.OP_List Curry_Prelude.C_Nothing x2 cd cs

d_C_writeMainGoalFile :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_writeMainGoalFile x1 x2 x3 x4 cd cs = let x5 = Curry_Prelude.d_OP_dollar
                                                Curry_List.d_C_nub
                                                (Curry_Prelude.OP_Cons
                                                (Curry_Linker.d_C_mainMod x1 cd
                                                cs)
                                                (Curry_Prelude.d_OP_plus_plus
                                                (Curry_Linker.d_C_addMods x1 cd
                                                cs) x2 cd cs)) cd cs
                                              x6 = Curry_Prelude.toCurryString
                                                "{-# OPTIONS_CYMAKE -W no-missing-signatures #-}"
  in Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_writeFile
  (Curry_Linker.d_C_mainGoalFile cd cs)) (Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_unlines (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.OP_Cons
  x6 Curry_Prelude.OP_List) (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_map
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "import ")) x5 cd
  cs) (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_maybe
  Curry_Prelude.OP_List d_OP_writeMainGoalFile_dot_uscore_hash_lambda85 x3 cd
  cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "kics2MainGoal = ") x4 cd cs)
  Curry_Prelude.OP_List) cd cs) cd cs) cd cs) cd cs) cd cs

d_OP_writeMainGoalFile_dot_uscore_hash_lambda85 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_writeMainGoalFile_dot_uscore_hash_lambda85 x1 cd cs = Curry_Prelude.OP_Cons
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "kics2MainGoal :: ") x1 cd cs) Curry_Prelude.OP_List

d_C_cleanMainGoalFile :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_cleanMainGoalFile x1 cd cs = let x2 = Curry_Prelude.d_OP_eq_eq
                                       (Curry_RCFile.d_C_rcValue
                                       (Curry_Linker.d_C_rcvars x1 cd cs)
                                       (Curry_Prelude.toCurryString "keepfiles")
                                       cd cs) (Curry_Prelude.toCurryString
                                       "yes") cd cs
  in Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_unless x2)
  (Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar Curry_System.d_C_system
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Installation.d_C_installDir cd
  cs) cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString "bin") cd
  cs) (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "cleancurry ")
  (Curry_Linker.d_C_mainGoalFile cd cs) cd cs) cd cs) cd cs) cd cs)
  (Curry_Files.d_C_removeFileIfExists (Curry_Linker.d_C_mainGoalFile cd cs) cd
  cs) cd cs) cd cs

d_C_getAcyOfMainGoal :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg)
d_C_getAcyOfMainGoal x1 cd cs = let x2 = Curry_Distribution.d_C_stripCurrySuffix
                                      (Curry_Linker.d_C_mainGoalFile cd cs) cd
                                      cs
                                    x3 = Curry_Prelude.d_OP_plus_plus
                                      (Curry_Distribution.d_C_inCurrySubdir
                                      (Curry_Distribution.d_C_stripCurrySuffix
                                      x2 cd cs) cd cs)
                                      (Curry_Prelude.toCurryString ".acy") cd cs
                                    x4 = d_C_currentFrontendParams x1 cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_Prelude.d_C_catch
  (Curry_Prelude.d_OP_gt_gt (Curry_Distribution.d_C_callFrontendWithParams
  Curry_Distribution.C_ACY x4 x2 cd cs)
  (AbstractCurry.Curry_Files.d_C_tryReadACYFile x3 cd cs) cd cs)
  d_OP_getAcyOfMainGoal_dot_uscore_hash_lambda86 cd cs)
  (d_OP_getAcyOfMainGoal_dot_uscore_hash_lambda87 x3) cd cs

d_OP_getAcyOfMainGoal_dot_uscore_hash_lambda86 :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Prelude.C_IOError -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe t0)
d_OP_getAcyOfMainGoal_dot_uscore_hash_lambda86 x1 cd cs =
  Curry_Prelude.d_C_return Curry_Prelude.C_Nothing cd cs

d_OP_getAcyOfMainGoal_dot_uscore_hash_lambda87 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg)
d_OP_getAcyOfMainGoal_dot_uscore_hash_lambda87 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Files.d_C_removeFileIfExists x1 cd cs)
  (Curry_Prelude.d_C_return x2 cd cs) cd cs

d_C_getAcyOfExpr :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe AbstractCurry.Curry_Types.C_CurryProg)
d_C_getAcyOfExpr x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt
  (d_C_writeSimpleMainGoalFile x1 x2 cd cs) (Curry_Prelude.d_OP_gt_gt_eq
  (d_C_getAcyOfMainGoal x1 cd cs) d_OP_getAcyOfExpr_dot_uscore_hash_lambda88 cd
  cs) cd cs

d_OP_getAcyOfExpr_dot_uscore_hash_lambda88 :: Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg)
d_OP_getAcyOfExpr_dot_uscore_hash_lambda88 x1 cd cs = Curry_Prelude.d_OP_gt_gt
  (Curry_Files.d_C_removeFileIfExists (Curry_Linker.d_C_mainGoalFile cd cs) cd
  cs) (Curry_Prelude.d_C_return x1 cd cs) cd cs

d_C_showTypeOfGoal :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.C_Bool
d_C_showTypeOfGoal x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_getAcyOfExpr
  x1 x2 cd cs) (d_OP_showTypeOfGoal_dot_uscore_hash_lambda89 x2) cd cs

d_OP_showTypeOfGoal_dot_uscore_hash_lambda89 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_OP_showTypeOfGoal_dot_uscore_hash_lambda89 x1 x2 cd cs =
  Curry_Prelude.d_C_maybe (Curry_Prelude.d_C_return Curry_Prelude.C_False cd cs)
  (d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 x1) x2
  cd cs

d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> AbstractCurry.Curry_Types.C_CurryProg -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 x1 x2 cd cs =
  case x2 of
  AbstractCurry.Curry_Types.C_CurryProg x3 x4 x5 x6 x7 -> d_C__case_174 x1 x6 cd
    cs
  AbstractCurry.Curry_Types.Choice_C_CurryProg d i l r -> narrow d i
    (d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 x1 l
    cd cs)
    (d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 x1 r
    cd cs)
  AbstractCurry.Curry_Types.Choices_C_CurryProg d i xs -> narrows cs d i (\z ->
    d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 x1 z
    cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CurryProg d c e -> guardCons d c
    (d_OP_showTypeOfGoal_dot_uscore_hash_lambda89_dot_uscore_hash_lambda90 x1 e
    cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CurryProg d info -> failCons d (traceFail
    "REPL.showTypeOfGoal._#lambda89._#lambda90" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.showTypeOfGoal._#lambda89._#lambda90"
    (showCons x2))

d_C_getModuleOfFunction :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_getModuleOfFunction x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_Prelude.d_OP_dollar (d_C_getAcyOfExpr x1) (d_C__case_171 x2
  (Curry_Char.d_C_isAlpha (Curry_Prelude.d_C_head x2 cd cs) cd cs) cd cs) cd cs)
  d_OP_getModuleOfFunction_dot_uscore_hash_lambda92 cd cs

d_OP_getModuleOfFunction_dot_modOfMain_dot_134 :: Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CRule -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_getModuleOfFunction_dot_modOfMain_dot_134 x1 cd cs = case x1 of
  Curry_Prelude.OP_Cons x2 x3 -> d_C__case_170 x3 x2 cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_getModuleOfFunction_dot_modOfMain_dot_134 l cd cs)
    (d_OP_getModuleOfFunction_dot_modOfMain_dot_134 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_getModuleOfFunction_dot_modOfMain_dot_134 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_getModuleOfFunction_dot_modOfMain_dot_134 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.getModuleOfFunction.modOfMain.134" [show x1] info)
  _ -> failCons cd (consFail "REPL.getModuleOfFunction.modOfMain.134" (showCons
    x1))

d_OP_getModuleOfFunction_dot_uscore_hash_lambda92 :: Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_getModuleOfFunction_dot_uscore_hash_lambda92 x1 cd cs =
  Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_return (Curry_Prelude.d_C_maybe
  Curry_Prelude.OP_List
  d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93 x1
  cd cs) cd cs

d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93 :: AbstractCurry.Curry_Types.C_CurryProg
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93 x1 cd cs =
  case x1 of
  AbstractCurry.Curry_Types.C_CurryProg x2 x3 x4 x5 x6 -> d_C__case_156 x5 cd cs
  AbstractCurry.Curry_Types.Choice_C_CurryProg d i l r -> narrow d i
    (d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93
    l cd cs)
    (d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93
    r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CurryProg d i xs -> narrows cs d i (\z ->
    d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93 z
    cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CurryProg d c e -> guardCons d c
    (d_OP_getModuleOfFunction_dot_uscore_hash_lambda92_dot_uscore_hash_lambda93
    e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CurryProg d info -> failCons d (traceFail
    "REPL.getModuleOfFunction._#lambda92._#lambda93" [show x1] info)
  _ -> failCons cd (consFail "REPL.getModuleOfFunction._#lambda92._#lambda93"
    (showCons x1))

d_C_compileProgramWithGoal :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile)
d_C_compileProgramWithGoal x1 x2 x3 cd cs =
  let x4 = Curry_Names.d_C_funcInfoFile (Curry_Linker.d_C_outputSubdir x1 cd cs)
        (Curry_Linker.d_C_mainModuleIdent cd cs) (Curry_Linker.d_C_mainGoalFile
        cd cs) cd cs
      x5 = Curry_Prelude.d_OP_gt_gt (Curry_Files.d_C_removeFileIfExists x4 cd
        cs) (Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
        Curry_Files.d_C_removeFileIfExists
        (FlatCurry.Curry_Files.d_C_flatCurryFileName
        (Curry_Linker.d_C_mainGoalFile cd cs) cd cs) cd cs)
        (Curry_Prelude.d_OP_gt_gt (d_C_writeSimpleMainGoalFile x1 x3 cd cs)
        (Curry_Prelude.d_OP_gt_gt_eq (Curry_Prelude.d_OP_gt_gt_eq
        (d_C_getAcyOfMainGoal x1 cd cs) (d_C_insertFreeVarsInMainGoal x1 x3) cd
        cs) (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94 x2 x3 x4 x1)
        cd cs) cd cs) cd cs) cd cs
  in d_C__case_153 x1 x5 (Curry_Linker.d_C_safeExec x1 cd cs) cd cs

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94 :: Curry_Prelude.C_Bool
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> C_GoalCompile -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2
  Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94 x1 x2 x3 x4 x5 cd cs =
  d_C__case_152 x5 x2 x4 x3 x1 (Curry_Prelude.d_OP_eq_eq x5 C_GoalError cd cs)
  cd cs

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog :: Curry_Prelude.OP_Tuple3
  AbstractCurry.Curry_Types.C_CurryProg (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_Maybe Curry_Prelude.C_Int) -> Cover
  -> ConstStore -> AbstractCurry.Curry_Types.C_CurryProg
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple3 x2 x3 x4 -> x2
  Curry_Prelude.Choice_OP_Tuple3 d i l r -> narrow d i
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog
    l cd cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple3 d i xs -> narrows cs d i (\z ->
    d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple3 d c e -> guardCons d c
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple3 d info -> failCons d (traceFail
    "REPL.compileProgramWithGoal._#lambda94._#selFP11#newprog" [show x1] info)
  _ -> failCons cd (consFail
    "REPL.compileProgramWithGoal._#lambda94._#selFP11#newprog" (showCons x1))

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal :: Curry_Prelude.OP_Tuple3
  AbstractCurry.Curry_Types.C_CurryProg (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_Maybe Curry_Prelude.C_Int) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple3 x2 x3 x4 -> x3
  Curry_Prelude.Choice_OP_Tuple3 d i l r -> narrow d i
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal
    l cd cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple3 d i xs -> narrows cs d i (\z ->
    d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple3 d c e -> guardCons d c
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple3 d info -> failCons d (traceFail
    "REPL.compileProgramWithGoal._#lambda94._#selFP12#newgoal" [show x1] info)
  _ -> failCons cd (consFail
    "REPL.compileProgramWithGoal._#lambda94._#selFP12#newgoal" (showCons x1))

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings :: Curry_Prelude.OP_Tuple3
  AbstractCurry.Curry_Types.C_CurryProg (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_Maybe Curry_Prelude.C_Int) -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe Curry_Prelude.C_Int
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple3 x2 x3 x4 -> x4
  Curry_Prelude.Choice_OP_Tuple3 d i l r -> narrow d i
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings
    l cd cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple3 d i xs -> narrows cs d i (\z ->
    d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple3 d c e -> guardCons d c
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple3 d info -> failCons d (traceFail
    "REPL.compileProgramWithGoal._#lambda94._#selFP13#bindings" [show x1] info)
  _ -> failCons cd (consFail
    "REPL.compileProgramWithGoal._#lambda94._#selFP13#bindings" (showCons x1))

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96 :: Curry_Prelude.C_Maybe
  Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile)
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96 x1 x2 x3 x4 x5 x6 cd cs =
  case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq (d_C_compileCurryProgram
    x5 (Curry_Linker.d_C_mainGoalFile cd cs) cd cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96_dot_uscore_hash_lambda97
    x1 x2 x3 x4 x5) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2
    (Curry_Linker.d_C_setExitStatus (Curry_Prelude.C_Int 1#) x5 cd cs)
    Curry_Linker.C_MainError) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96
    x1 x2 x3 x4 x5 l cd cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96
    x1 x2 x3 x4 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96
    x1 x2 x3 x4 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96
    x1 x2 x3 x4 x5 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.compileProgramWithGoal._#lambda94._#lambda96" [show x1, show x2, show
    x3, show x4, show x5, show x6] info)
  _ -> failCons cd (consFail "REPL.compileProgramWithGoal._#lambda94._#lambda96"
    (showCons x6))

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96_dot_uscore_hash_lambda97 :: Curry_Prelude.C_Maybe
  Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile)
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96_dot_uscore_hash_lambda97 x1 x2 x3 x4 x5 x6 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Directory.d_C_doesFileExist x4 cd cs)
  (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96_dot_uscore_hash_lambda97_dot_uscore_hash_lambda98
  x1 x2 x3 x5 x6) cd cs

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96_dot_uscore_hash_lambda97_dot_uscore_hash_lambda98 :: Curry_Prelude.C_Maybe
  Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Int
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96_dot_uscore_hash_lambda97_dot_uscore_hash_lambda98 x1 x2 x3 x4 x5 x6 cd cs =
  d_C__case_150 x6 x5 x4 x1 x3 x2 (Curry_Prelude.d_OP_amp_amp
  (Curry_Prelude.d_OP_eq_eq x5 (Curry_Prelude.C_Int 0#) cd cs) x6 cd cs) cd cs

d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 :: Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile)
d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_writeErrorMsg
    (Curry_Prelude.toCurryString "Import of 'Unsafe' not allowed in safe mode!")
    cd cs) (Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2
    (Curry_Linker.d_C_setExitStatus (Curry_Prelude.C_Int 1#) x2 cd cs)
    Curry_Linker.C_MainError) cd cs) cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 l cd cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 e cd $! addCs c
    cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.compileProgramWithGoal._#lambda99" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.compileProgramWithGoal._#lambda99" (showCons
    x3))

nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 :: Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2
  Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 x3 s cd cs =
  case x3 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt (d_C_writeErrorMsg
    (Curry_Prelude.toCurryString "Import of 'Unsafe' not allowed in safe mode!")
    cd cs) (Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2
    (Curry_Linker.d_C_setExitStatus (Curry_Prelude.C_Int 1#) x2 cd cs)
    Curry_Linker.C_MainError) cd cs) s0 cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 l s cd cs)
    (nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x1 x2 e s cd $! addCs
    c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.compileProgramWithGoal._#lambda99" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.compileProgramWithGoal._#lambda99" (showCons
    x3))

d_C_insertFreeVarsInMainGoal :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_GoalCompile
d_C_insertFreeVarsInMainGoal x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_Nothing -> Curry_Prelude.d_C_return C_GoalError cd cs
  Curry_Prelude.C_Just x4 -> d_C__case_149 x2 x1 x4 cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i
    (d_C_insertFreeVarsInMainGoal x1 x2 l cd cs) (d_C_insertFreeVarsInMainGoal
    x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z ->
    d_C_insertFreeVarsInMainGoal x1 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c
    (d_C_insertFreeVarsInMainGoal x1 x2 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail
    "REPL.insertFreeVarsInMainGoal" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.insertFreeVarsInMainGoal" (showCons x3))

d_OP_insertFreeVarsInMainGoal_dot_isPrtChoices_dot_186 :: Curry_Linker.C_NonDetMode
  -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_insertFreeVarsInMainGoal_dot_isPrtChoices_dot_186 x1 cd cs =
  let x2 = Curry_Prelude.C_False in d_C__case_143 x2 x1 cd cs

d_OP_insertFreeVarsInMainGoal_dot_lvarName_dot_186 :: AbstractCurry.Curry_Types.C_CLocalDecl
  -> Cover -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_insertFreeVarsInMainGoal_dot_lvarName_dot_186 x1 cd cs =
  let x2 = Curry_Prelude.OP_List in d_C__case_142 x2 x1 cd cs

d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186 :: AbstractCurry.Curry_Types.C_CRhs
  -> Cover -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186 x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CSimpleRhs x2 x3 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap
    d_OP_insertFreeVarsInMainGoal_dot_lvarName_dot_186 cd cs) x3 cd cs
  AbstractCurry.Curry_Types.C_CGuardedRhs x4 x5 -> Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_concatMap
    d_OP_insertFreeVarsInMainGoal_dot_lvarName_dot_186 cd cs) x5 cd cs
  AbstractCurry.Curry_Types.Choice_C_CRhs d i l r -> narrow d i
    (d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186 l cd cs)
    (d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CRhs d i xs -> narrows cs d i (\z ->
    d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CRhs d c e -> guardCons d c
    (d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CRhs d info -> failCons d (traceFail
    "REPL.insertFreeVarsInMainGoal.freeVarsInRhs.186" [show x1] info)
  _ -> failCons cd (consFail "REPL.insertFreeVarsInMainGoal.freeVarsInRhs.186"
    (showCons x1))

d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186 :: AbstractCurry.Curry_Types.C_CFuncDecl
  -> Cover -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186 x1 cd cs =
  case x1 of
  AbstractCurry.Curry_Types.C_CFunc x2 x3 x4 x5 x6 -> d_C__case_141 x6 cd cs
  AbstractCurry.Curry_Types.C_CmtFunc x11 x12 x13 x14 x15 x16 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString
    "REPL.insertFreeVarsInMainGoal.freeVarsInFuncRule") cd cs
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186 l cd cs)
    (d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186 e cd $! addCs
    c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "REPL.insertFreeVarsInMainGoal.freeVarsInFuncRule.186" [show x1] info)
  _ -> failCons cd (consFail
    "REPL.insertFreeVarsInMainGoal.freeVarsInFuncRule.186" (showCons x1))

d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186 x1 cd cs =
  let x2 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_reverse cd cs) x1 cd cs
  in d_C__case_139 x2 x1 (Curry_Prelude.d_OP_eq_eq (Curry_Prelude.d_C_take
  (Curry_Prelude.C_Int 4#) x2 cd cs) (Curry_Prelude.toCurryString "eerf") cd cs)
  cd cs

d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224 x1 cd cs =
  case x1 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x2 x3 -> d_C__case_137 x3 x2 (Curry_Prelude.d_OP_amp_amp
    (Curry_Char.d_C_isSpace x2 cd cs) (Curry_Prelude.d_OP_eq_eq
    (Curry_Prelude.d_C_take (Curry_Prelude.C_Int 6#) x3 cd cs)
    (Curry_Prelude.toCurryString "erehw ") cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224
    l cd cs)
    (d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224
    r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224
    z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.insertFreeVarsInMainGoal.breakWhereFreeClause.186.findWhere.224" [show
    x1] info)
  _ -> failCons cd (consFail
    "REPL.insertFreeVarsInMainGoal.breakWhereFreeClause.186.findWhere.224"
    (showCons x1))

d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp l cd cs)
    (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.insertFreeVarsInMainGoal._#selFP15#exp" [show x1] info)
  _ -> failCons cd (consFail "REPL.insertFreeVarsInMainGoal._#selFP15#exp"
    (showCons x1))

d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause l cd
    cs) (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause z cd
    cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.insertFreeVarsInMainGoal._#selFP16#whereclause" [show x1] info)
  _ -> failCons cd (consFail
    "REPL.insertFreeVarsInMainGoal._#selFP16#whereclause" (showCons x1))

d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda105 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda105 x1 cd cs =
  Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "\"")
  (Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.toCurryString "\"") cd cs) cd
  cs

d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda106 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda106 x1 cd cs =
  Curry_Prelude.OP_Cons (Curry_Prelude.C_Char ','#) x1

d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda107 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  AbstractCurry.Curry_Types.C_CurryProg -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_GoalCompile
d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda107 x1 x2 x3 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.d_C_maybe C_GoalError
  (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda107_dot_uscore_hash_lambda108
  x1 x2) x3 cd cs) cd cs

d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda107_dot_uscore_hash_lambda108 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> AbstractCurry.Curry_Types.C_CurryProg -> Cover
  -> ConstStore -> C_GoalCompile
d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda107_dot_uscore_hash_lambda108 x1 x2 x3 cd cs =
  C_GoalWithBindings x3 (Curry_Prelude.d_C_length x1 cd cs) x2

d_C_makeMainGoalMonomorphic :: Curry_Linker.C_ReplState
  -> AbstractCurry.Curry_Types.C_CurryProg -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.C_Bool
d_C_makeMainGoalMonomorphic x1 x2 x3 cd cs = case x2 of
  AbstractCurry.Curry_Types.C_CurryProg x4 x5 x6 x7 x8 -> d_C__case_135 x3 x1 x7
    cd cs
  AbstractCurry.Curry_Types.Choice_C_CurryProg d i l r -> narrow d i
    (d_C_makeMainGoalMonomorphic x1 l x3 cd cs) (d_C_makeMainGoalMonomorphic x1
    r x3 cd cs)
  AbstractCurry.Curry_Types.Choices_C_CurryProg d i xs -> narrows cs d i (\z ->
    d_C_makeMainGoalMonomorphic x1 z x3 cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CurryProg d c e -> guardCons d c
    (d_C_makeMainGoalMonomorphic x1 e x3 cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CurryProg d info -> failCons d (traceFail
    "REPL.makeMainGoalMonomorphic" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.makeMainGoalMonomorphic" (showCons x2))

d_OP_makeMainGoalMonomorphic_dot_newgoal_dot_262 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> AbstractCurry.Curry_Types.C_CTypeExpr -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_makeMainGoalMonomorphic_dot_newgoal_dot_262 x1 x2 cd cs = d_C__case_129 x2
  x1 (AbstractCurry.Curry_Select.d_C_isIOReturnType x2 cd cs) cd cs

d_C_compileCurryProgram :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.C_Int
d_C_compileCurryProgram x1 x2 cd cs = let x3 = Curry_Prelude.d_C_apply
                                            (Curry_Prelude.d_C_apply
                                            (Curry_FilePath.d_OP_lt_slash_gt cd
                                            cs) (Curry_Linker.d_C_kics2Home x1
                                            cd cs) cd cs)
                                            (Curry_Prelude.d_C_apply
                                            (Curry_Prelude.d_C_apply
                                            (Curry_FilePath.d_OP_lt_slash_gt cd
                                            cs) (Curry_Prelude.toCurryString
                                            "bin") cd cs)
                                            (Curry_Prelude.d_C_apply
                                            (Curry_Prelude.d_C_apply
                                            (Curry_FilePath.d_OP_lt_slash_gt cd
                                            cs) (Curry_Prelude.toCurryString
                                            ".local") cd cs)
                                            (Curry_Prelude.toCurryString
                                            "kics2c") cd cs) cd cs) cd cs
                                          x4 = Curry_Prelude.d_OP_dollar
                                            Curry_Prelude.d_C_unwords
                                            (Curry_Prelude.d_OP_plus_plus
                                            (Curry_Prelude.OP_Cons
                                            (Curry_Prelude.d_OP_plus_plus
                                            (Curry_Prelude.toCurryString
                                            "-Dbindingoptimization=")
                                            (Curry_RCFile.d_C_rcValue
                                            (Curry_Linker.d_C_rcvars x1 cd cs)
                                            (Curry_Prelude.toCurryString
                                            "bindingoptimization") cd cs) cd cs)
                                            (Curry_Prelude.OP_Cons
                                            (Curry_Prelude.d_OP_plus_plus
                                            (Curry_Prelude.toCurryString "-v")
                                            (Curry_Prelude.d_C_show
                                            (d_OP_compileCurryProgram_dot_transVerbose_dot_281
                                            (Curry_Linker.d_C_verbose x1 cd cs)
                                            cd cs) cd cs) cd cs)
                                            (Curry_Prelude.OP_Cons
                                            (Curry_Prelude.d_OP_plus_plus
                                            (Curry_Prelude.toCurryString "-i")
                                            (Curry_List.d_C_intercalate
                                            (Curry_Prelude.OP_Cons
                                            (Curry_FilePath.d_C_searchPathSeparator
                                            cd cs) Curry_Prelude.OP_List)
                                            (Curry_Linker.d_C_loadPaths x1 cd
                                            cs) cd cs) cd cs)
                                            Curry_Prelude.OP_List)))
                                            (Curry_Prelude.d_OP_plus_plus
                                            (d_C__case_128 x1
                                            (Curry_Prelude.d_C_null
                                            (Curry_Linker.d_C_parseOpts x1 cd
                                            cs) cd cs) cd cs) (d_C__case_127 x1
                                            (Curry_Linker.d_C_traceFailure x1 cd
                                            cs) cd cs) cd cs) cd cs) cd cs
                                          x5 = Curry_Prelude.d_C_unwords
                                            (Curry_Prelude.OP_Cons x3
                                            (Curry_Prelude.OP_Cons x4
                                            (Curry_Prelude.OP_Cons
                                            (Curry_Linker.d_C_cmpOpts x1 cd cs)
                                            (Curry_Prelude.OP_Cons x2
                                            Curry_Prelude.OP_List)))) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_Linker.d_C_getTimeCmd x1
  (Curry_Prelude.toCurryString "KiCS2 compilation") x5 cd cs)
  (d_OP_compileCurryProgram_dot_uscore_hash_lambda111 x1) cd cs

d_OP_compileCurryProgram_dot_transVerbose_dot_281 :: Curry_Prelude.C_Int
  -> Cover -> ConstStore -> Curry_Prelude.C_Int
d_OP_compileCurryProgram_dot_transVerbose_dot_281 x1 cd cs = d_C__case_126 x1
  (Curry_Prelude.d_OP_eq_eq x1 (Curry_Prelude.C_Int 3#) cd cs) cd cs

d_OP_compileCurryProgram_dot_uscore_hash_lambda111 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Int
d_OP_compileCurryProgram_dot_uscore_hash_lambda111 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
  (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 2#))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "Executing: ") x2
  cd cs) cd cs) (Curry_System.d_C_system x2 cd cs) cd cs

d_C_execMain :: Curry_Linker.C_ReplState -> Curry_Linker.C_MainCompile
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_C_execMain x1 x2 x3 cd cs = let x4 = Curry_Prelude.d_C_apply
                                    (Curry_Prelude.d_C_apply
                                    (Curry_FilePath.d_OP_lt_slash_gt cd cs)
                                    (Curry_Prelude.toCurryString ".") cd cs)
                                    (Curry_Prelude.d_C_apply
                                    (Curry_Prelude.d_C_apply
                                    (Curry_FilePath.d_OP_lt_slash_gt cd cs)
                                    (Curry_Linker.d_C_outputSubdir x1 cd cs) cd
                                    cs) (Curry_Prelude.toCurryString "Main") cd
                                    cs) cd cs
                                  x5 = Curry_Prelude.d_C_unwords
                                    (Curry_Prelude.OP_Cons x4
                                    (Curry_Prelude.OP_Cons
                                    (Curry_Linker.d_C_rtsArgs x1 cd cs)
                                    Curry_Prelude.OP_List)) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_Linker.d_C_getTimeCmd x1
  (Curry_Prelude.toCurryString "Execution") x5 cd cs)
  (d_OP_execMain_dot_uscore_hash_lambda112 x3 x1) cd cs

d_OP_execMain_dot_uscore_hash_lambda112 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Linker.C_ReplState
d_OP_execMain_dot_uscore_hash_lambda112 x1 x2 x3 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
  (Curry_Linker.d_C_writeVerboseInfo x2 (Curry_Prelude.C_Int 1#))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "Evaluating expression: ") (Curry_Prelude.d_C_apply (Curry_Utils.d_C_strip cd
  cs) x1 cd cs) cd cs) cd cs) (Curry_Prelude.d_OP_gt_gt
  (Curry_Prelude.d_OP_dollar (Curry_Linker.d_C_writeVerboseInfo x2
  (Curry_Prelude.C_Int 3#)) (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "Executing: ") x3 cd cs) cd cs)
  (Curry_Prelude.d_OP_gt_gt_eq (Curry_System.d_C_system x3 cd cs)
  (d_OP_execMain_dot_uscore_hash_lambda112_dot_uscore_hash_lambda113 x2) cd cs)
  cd cs) cd cs

d_OP_execMain_dot_uscore_hash_lambda112_dot_uscore_hash_lambda113 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Linker.C_ReplState
d_OP_execMain_dot_uscore_hash_lambda112_dot_uscore_hash_lambda113 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_unless
  (Curry_Prelude.d_OP_eq_eq x2 (Curry_Prelude.C_Int 0#) cd cs))
  (Curry_Prelude.d_C_putStrLn (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "Evaluation terminated with non-zero status ")
  (Curry_Prelude.d_C_show x2 cd cs) cd cs) cd cs) cd cs)
  (Curry_Prelude.d_C_return (Curry_Linker.d_C_setExitStatus x2 x1 cd cs) cd cs)
  cd cs

d_C_processCommand :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processCommand x1 x2 cd cs = let x3 = Curry_Prelude.d_C_apply
                                       (Curry_Prelude.d_C_break
                                       (Curry_Prelude.d_C_flip (acceptCs id
                                       Curry_Prelude.d_OP_eq_eq)
                                       (Curry_Prelude.C_Char ' '#)) cd cs) x2 cd
                                       cs
                                     x4 = d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd
                                       x3 cd cs
                                     x5 = d_OP_processCommand_dot_uscore_hash_selFP19_hash_args
                                       x3 cd cs
                                     x6 = Curry_Prelude.d_C_filter
                                       (Curry_Prelude.d_OP_dot
                                       (Curry_List.d_C_isPrefixOf
                                       (Curry_Prelude.d_C_map
                                       Curry_Char.d_C_toLower x4 cd cs))
                                       Curry_Prelude.d_C_fst cd cs)
                                       (d_C_replCommands cd cs) cd cs
  in d_C__case_123 x2 x6 x5 x1 (Curry_Prelude.d_C_null x2 cd cs) cd cs

d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd l cd cs)
    (d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processCommand_dot_uscore_hash_selFP18_hash_cmd e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processCommand._#selFP18#cmd" [show x1] info)
  _ -> failCons cd (consFail "REPL.processCommand._#selFP18#cmd" (showCons x1))

d_OP_processCommand_dot_uscore_hash_selFP19_hash_args :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processCommand_dot_uscore_hash_selFP19_hash_args x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processCommand_dot_uscore_hash_selFP19_hash_args l cd cs)
    (d_OP_processCommand_dot_uscore_hash_selFP19_hash_args r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processCommand_dot_uscore_hash_selFP19_hash_args z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processCommand_dot_uscore_hash_selFP19_hash_args e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processCommand._#selFP19#args" [show x1] info)
  _ -> failCons cd (consFail "REPL.processCommand._#selFP19#args" (showCons x1))

d_C_unsafeExec :: Curry_Linker.C_ReplState -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_unsafeExec x1 x2 cd cs = d_C__case_116 x1 x2 (Curry_Linker.d_C_safeExec x1
  cd cs) cd cs

nd_C_unsafeExec :: Curry_Linker.C_ReplState -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C_unsafeExec x1 x2 s cd cs = let s0 = s
  in s0 `seq` nd_C__case_116 x1 x2 (Curry_Linker.d_C_safeExec x1 cd cs) s0 cd cs

d_C_replCommands :: Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
d_C_replCommands cd cs = Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "?") (acceptCs id d_C_processHelp))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "add") (acceptCs id d_C_processAdd)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "browse") (acceptCs id
  d_C_processBrowse)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "cd") (acceptCs id d_C_processCd))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "compile") (acceptCs id d_C_processCompile)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "edit") (acceptCs id
  d_C_processEdit)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "eval") (acceptCs id d_C_processEval))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "fork") (acceptCs id d_C_processFork)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "help") (acceptCs id
  d_C_processHelp)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "interface") (acceptCs id d_C_processInterface))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "load") (acceptCs id d_C_processLoad)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "programs") (acceptCs id
  d_C_processPrograms)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "reload") (acceptCs id d_C_processReload))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "quit") (acceptCs id d_C_processQuit)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "save") (acceptCs id
  d_C_processSave)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "set") (acceptCs id d_C_processSetOption))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "source") (acceptCs id d_C_processSource)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "show") (acceptCs id
  d_C_processShow)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "type") (acceptCs id d_C_processType))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "usedimports") (acceptCs id d_C_processUsedImports))
  Curry_Prelude.OP_List)))))))))))))))))))

nd_C_replCommands :: IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func
  Curry_Linker.C_ReplState (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))))
nd_C_replCommands s cd cs = Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "?") (wrapDX (wrapDX id) (acceptCs id
  d_C_processHelp))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "add") (wrapDX (wrapDX id) (acceptCs id
  d_C_processAdd))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "browse") (wrapDX (wrapDX id) (acceptCs id
  d_C_processBrowse))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "cd") (wrapDX (wrapDX id) (acceptCs id
  d_C_processCd))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "compile") (wrapDX (wrapDX id) (acceptCs id
  d_C_processCompile))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "edit") (wrapDX (wrapDX id) (acceptCs id
  d_C_processEdit))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "eval") (wrapDX (wrapDX id) (acceptCs id
  d_C_processEval))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "fork") (wrapDX (wrapDX id) (acceptCs id
  d_C_processFork))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "help") (wrapDX (wrapDX id) (acceptCs id
  d_C_processHelp))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "interface") (wrapDX (wrapDX id) (acceptCs id
  d_C_processInterface))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "load") (wrapDX (wrapDX id) (acceptCs id
  d_C_processLoad))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "programs") (wrapDX (wrapDX id) (acceptCs id
  d_C_processPrograms))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "reload") (wrapDX (wrapDX id) (acceptCs id
  d_C_processReload))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "quit") (wrapDX (wrapDX id) (acceptCs id
  d_C_processQuit))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "save") (wrapDX (wrapDX id) (acceptCs id
  d_C_processSave))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "set") (wrapDX (wrapDX id) (acceptCs id
  d_C_processSetOption))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "source") (wrapDX (wrapDX id) (acceptCs id
  d_C_processSource))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "show") (wrapDX (wrapDX id) (acceptCs id
  d_C_processShow))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "type") (wrapDX (wrapDX id) (acceptCs id
  d_C_processType))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "usedimports") (wrapDX (wrapDX id) (acceptCs id
  d_C_processUsedImports))) Curry_Prelude.OP_List)))))))))))))))))))

d_C_skipCommand :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C_skipCommand x1 cd cs = Curry_Prelude.d_OP_gt_gt (d_C_writeErrorMsg x1 cd cs)
  (Curry_Prelude.d_C_return Curry_Prelude.C_Nothing cd cs) cd cs

d_C_processSysCall :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processSysCall x1 x2 cd cs = d_C__case_115 x2 x1 (Curry_Prelude.d_C_null x2
  cd cs) cd cs

d_C_processQuit :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processQuit x1 x2 cd cs = Curry_Prelude.d_C_return (Curry_Prelude.C_Just
  (d_C__case_113 x1 cd cs)) cd cs

d_C_processHelp :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processHelp x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt (d_C_printHelpOnCommands
  cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_putStrLn
  (Curry_Prelude.toCurryString "... or type any <expression> to evaluate\n") cd
  cs) (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd cs) cd cs) cd cs

d_C_processCompile :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processCompile x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_processLoad x1
  x2 cd cs) (Curry_Prelude.d_C_maybe (Curry_Prelude.d_C_return
  Curry_Prelude.C_Nothing cd cs) d_OP_processCompile_dot_uscore_hash_lambda147)
  cd cs

d_OP_processCompile_dot_uscore_hash_lambda147 :: Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_processCompile_dot_uscore_hash_lambda147 x1 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Linker.d_C_compileModuleWithGHC x1
  (Curry_Linker.d_C_mainMod x1 cd cs) cd cs)
  d_OP_processCompile_dot_uscore_hash_lambda147_dot_uscore_hash_lambda148 cd cs

d_OP_processCompile_dot_uscore_hash_lambda147_dot_uscore_hash_lambda148 :: Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_processCompile_dot_uscore_hash_lambda147_dot_uscore_hash_lambda148 x1 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd cs

d_C_processLoad :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processLoad x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_terminateSourceProgGUIs x1 cd cs)
  (d_OP_processLoad_dot_uscore_hash_lambda149 x2) cd cs

d_OP_processLoad_dot_uscore_hash_lambda149 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processLoad_dot_uscore_hash_lambda149 x1 x2 cd cs =
  let x3 = Curry_Distribution.d_C_stripCurrySuffix x1 cd cs
  in d_C__case_112 x3 x2 (Curry_Prelude.d_C_null x3 cd cs) cd cs

d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname
    l cd cs)
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processLoad._#lambda149._#selFP21#dirname" [show x1] info)
  _ -> failCons cd (consFail "REPL.processLoad._#lambda149._#selFP21#dirname"
    (showCons x1))

d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname
    l cd cs)
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processLoad._#lambda149._#selFP22#modname" [show x1] info)
  _ -> failCons cd (consFail "REPL.processLoad._#lambda149._#selFP22#modname"
    (showCons x1))

d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Maybe Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150 x1 x2 x3 cd cs =
  Curry_Prelude.d_C_maybe (Curry_Prelude.d_C_return Curry_Prelude.C_Nothing cd
  cs)
  (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151
  x1 x2) x3 cd cs

d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151 x1 x2 x3 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Distribution.d_C_lookupModuleSource
  (Curry_Linker.d_C_loadPaths x3 cd cs) x2 cd cs) (Curry_Prelude.d_C_maybe
  (Curry_Prelude.d_OP_dollar d_C_skipCommand (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "source file of module ")
  (Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.toCurryString " not found") cd
  cs) cd cs) cd cs)
  (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152
  x2 x3)) cd cs

d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152 x1 x2 x3 cd cs =
  case x3 of
  Curry_Prelude.OP_Tuple2 x4 x5 -> Curry_Prelude.d_OP_gt_gt_eq
    (d_C_readAndProcessSourceFileOptions x2 x5 cd cs) (Curry_Prelude.d_C_maybe
    (Curry_Prelude.d_C_return Curry_Prelude.C_Nothing cd cs)
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152_dot_uscore_hash_lambda153
    x1)) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152
    x1 x2 l cd cs)
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152
    x1 x2 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152
    x1 x2 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152
    x1 x2 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processLoad._#lambda149._#lambda150._#lambda151._#lambda152" [show x1
    , show x2, show x3] info)
  _ -> failCons cd (consFail
    "REPL.processLoad._#lambda149._#lambda150._#lambda151._#lambda152" (showCons
    x3))

d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152_dot_uscore_hash_lambda153 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150_dot_uscore_hash_lambda151_dot_uscore_hash_lambda152_dot_uscore_hash_lambda153 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (d_C_compileCurryProgram x2 x1 cd cs)
  (Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_110 x1 x2 cd cs))
  cd cs) cd cs

d_C_processReload :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processReload x1 x2 cd cs = d_C__case_109 x1 x2 (Curry_Prelude.d_OP_eq_eq
  (Curry_Linker.d_C_mainMod x1 cd cs) (Curry_Linker.d_C_preludeName x1 cd cs) cd
  cs) cd cs

d_C_processAdd :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processAdd x1 x2 cd cs = d_C__case_106 x2 x1 (Curry_Prelude.d_C_null x2 cd
  cs) cd cs

d_OP_processAdd_dot_insert_dot_350 :: forall t0 . (Curry_Prelude.Curry t0) => t0
  -> Curry_Prelude.OP_List t0 -> Cover -> ConstStore -> Curry_Prelude.OP_List t0
d_OP_processAdd_dot_insert_dot_350 x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_Cons x1 Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x3 x4 -> d_C__case_104 x3 x1 x4 x2
    (Curry_Prelude.d_OP_lt x1 x3 cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_processAdd_dot_insert_dot_350 x1 l cd cs)
    (d_OP_processAdd_dot_insert_dot_350 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_processAdd_dot_insert_dot_350 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_processAdd_dot_insert_dot_350 x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.processAdd.insert.350" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.processAdd.insert.350" (showCons x2))

d_OP_processAdd_dot_add_dot_350 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_OP_processAdd_dot_add_dot_350 x1 x2 cd cs =
  let x3 = Curry_Distribution.d_C_stripCurrySuffix x2 cd cs
  in d_C__case_101 x3 x1 (Curry_Prelude.d_C_apply (d_C_validModuleName cd cs) x3
  cd cs) cd cs

d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 x1 x2 x3 cd cs =
  case x3 of
  Curry_Prelude.C_Nothing -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    d_C_writeErrorMsg (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Source file of module '") (Curry_Prelude.d_OP_plus_plus x1
    (Curry_Prelude.toCurryString "' not found") cd cs) cd cs) cd cs)
    (Curry_Prelude.d_C_return x2 cd cs) cd cs
  Curry_Prelude.C_Just x4 -> Curry_Prelude.d_C_return (d_C__case_100 x1 x2 cd
    cs) cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i
    (d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 x1 x2 l cd cs)
    (d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z ->
    d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 x1 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c
    (d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail
    "REPL.processAdd.add.350._#lambda186" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.processAdd.add.350._#lambda186" (showCons
    x3))

d_C_validModuleName :: Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_C_validModuleName cd cs = Curry_Prelude.d_C_all
  d_OP_validModuleName_dot_uscore_hash_lambda220 cd cs

d_OP_validModuleName_dot_uscore_hash_lambda220 :: Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_OP_validModuleName_dot_uscore_hash_lambda220 x1 cd cs =
  Curry_Prelude.d_OP_bar_bar (Curry_Char.d_C_isAlphaNum x1 cd cs)
  (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_eq_eq x1 (Curry_Prelude.C_Char
  '_'#) cd cs) (Curry_Prelude.d_OP_eq_eq x1 (Curry_Prelude.C_Char '.'#) cd cs)
  cd cs) cd cs

d_C_processEval :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processEval x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_evalExpression x1
  x2 cd cs) (Curry_Prelude.d_OP_dot Curry_Prelude.d_C_return (acceptCs id
  Curry_Prelude.C_Just) cd cs) cd cs

d_C_processType :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processType x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_showTypeOfGoal x1
  x2 cd cs) (d_OP_processType_dot_uscore_hash_lambda221 x1) cd cs

d_OP_processType_dot_uscore_hash_lambda221 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processType_dot_uscore_hash_lambda221 x1 x2 cd cs =
  Curry_Prelude.d_C_return (d_C__case_99 x1 x2 cd cs) cd cs

d_C_processCd :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processCd x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_Directory.d_C_getAbsolutePath x2 cd cs)
  (d_OP_processCd_dot_uscore_hash_lambda222 x1) cd cs

d_OP_processCd_dot_uscore_hash_lambda222 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processCd_dot_uscore_hash_lambda222 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Directory.d_C_doesDirectoryExist x2 cd cs)
  (d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223 x2 x1) cd
  cs

d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223 x1 x2 x3 cd cs =
  case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt
    (Curry_Directory.d_C_setCurrentDirectory x1 cd cs) (Curry_Prelude.d_C_return
    (Curry_Prelude.C_Just x2) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_dollar d_C_skipCommand
    (Curry_Prelude.toCurryString "directory does not exist") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223 x1 x2 l
    cd cs) (d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223
    x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223 x1 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_processCd_dot_uscore_hash_lambda222_dot_uscore_hash_lambda223 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.processCd._#lambda222._#lambda223" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.processCd._#lambda222._#lambda223" (showCons
    x3))

d_C_processPrograms :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processPrograms x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt
  (d_C_printAllLoadPathPrograms x1 cd cs) (Curry_Prelude.d_C_return
  (Curry_Prelude.C_Just x1) cd cs) cd cs

d_C_processEdit :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processEdit x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_getModuleName x1
  x2 cd cs) (d_OP_processEdit_dot_uscore_hash_lambda224 x1) cd cs

d_OP_processEdit_dot_uscore_hash_lambda224 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processEdit_dot_uscore_hash_lambda224 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Files.d_C_lookupFileInPath
  (Curry_Prelude.d_C_apply (Curry_Names.d_C_moduleNameToPath cd cs) x2 cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString ".curry")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString ".lcurry")
  Curry_Prelude.OP_List)) (Curry_Linker.d_C_loadPaths x1 cd cs) cd cs)
  (d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225 x1) cd
  cs

d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_System.d_C_getEnviron
  (Curry_Prelude.toCurryString "EDITOR") cd cs)
  (d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225_dot_uscore_hash_lambda226
  x2 x1) cd cs

d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225_dot_uscore_hash_lambda226 :: Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225_dot_uscore_hash_lambda226 x1 x2 x3 cd cs =
  let x4 = Curry_RCFile.d_C_rcValue (Curry_Linker.d_C_rcvars x2 cd cs)
        (Curry_Prelude.toCurryString "editcommand") cd cs
      x5 = d_C__case_97 x4 x3 (Curry_Prelude.d_C_null x4 cd cs) cd cs
  in d_C__case_98 x4 x3 x1 x2 x5 (Curry_Prelude.d_OP_amp_amp
  (Curry_Prelude.d_C_null x3 cd cs) (Curry_Prelude.d_C_null x4 cd cs) cd cs) cd
  cs

d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225_dot_uscore_hash_lambda226_dot_uscore_hash_lambda227 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225_dot_uscore_hash_lambda226_dot_uscore_hash_lambda227 x1 x2 x3 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_System.d_C_system
  (Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString " ") (Curry_Prelude.d_OP_plus_plus x3
  (Curry_Prelude.toCurryString "& ") cd cs) cd cs) cd cs) cd cs)
  (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x2) cd cs) cd cs

d_C_processSource :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processSource x1 x2 cd cs = let x3 = Curry_Prelude.d_C_apply
                                      (Curry_Prelude.d_C_break
                                      (Curry_Prelude.d_C_flip (acceptCs id
                                      Curry_Prelude.d_OP_eq_eq)
                                      (Curry_Prelude.C_Char '.'#)) cd cs) x2 cd
                                      cs
                                    x4 = d_OP_processSource_dot_uscore_hash_selFP24_hash_mod
                                      x3 cd cs
                                    x5 = d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun
                                      x3 cd cs
  in d_C__case_96 x2 x5 x4 x1 (Curry_Prelude.d_C_null x2 cd cs) cd cs

d_OP_processSource_dot_uscore_hash_selFP24_hash_mod :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processSource_dot_uscore_hash_selFP24_hash_mod x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processSource_dot_uscore_hash_selFP24_hash_mod l cd cs)
    (d_OP_processSource_dot_uscore_hash_selFP24_hash_mod r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processSource_dot_uscore_hash_selFP24_hash_mod z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processSource_dot_uscore_hash_selFP24_hash_mod e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processSource._#selFP24#mod" [show x1] info)
  _ -> failCons cd (consFail "REPL.processSource._#selFP24#mod" (showCons x1))

d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun l cd cs)
    (d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processSource_dot_uscore_hash_selFP25_hash_dotfun e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processSource._#selFP25#dotfun" [show x1] info)
  _ -> failCons cd (consFail "REPL.processSource._#selFP25#dotfun" (showCons
    x1))

d_OP_processSource_dot_uscore_hash_lambda228 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processSource_dot_uscore_hash_lambda228 x1 x2 x3 cd cs = d_C__case_93 x3 x1
  x2 (Curry_Prelude.d_C_null x3 cd cs) cd cs

d_C_getModuleName :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C_getModuleName x1 x2 cd cs = d_C__case_92 x2 x1 (Curry_Prelude.d_C_null x2 cd
  cs) cd cs

d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname l cd cs)
    (d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.getModuleName._#selFP27#dirname" [show x1] info)
  _ -> failCons cd (consFail "REPL.getModuleName._#selFP27#dirname" (showCons
    x1))

d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname l cd cs)
    (d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.getModuleName._#selFP28#mname" [show x1] info)
  _ -> failCons cd (consFail "REPL.getModuleName._#selFP28#mname" (showCons x1))

d_C_processShow :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processShow x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C_getModuleName x1
  x2 cd cs) (d_OP_processShow_dot_uscore_hash_lambda229 x1) cd cs

d_OP_processShow_dot_uscore_hash_lambda229 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processShow_dot_uscore_hash_lambda229 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_Files.d_C_lookupFileInPath
  (Curry_Prelude.d_C_apply (Curry_Names.d_C_moduleNameToPath cd cs) x2 cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString ".curry")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString ".lcurry")
  Curry_Prelude.OP_List)) (Curry_Linker.d_C_loadPaths x1 cd cs) cd cs)
  (d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230 x1) cd
  cs

d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230 x1 x2 cd cs =
  case x2 of
  Curry_Prelude.C_Nothing -> d_C_skipCommand (Curry_Prelude.toCurryString
    "source file not found") cd cs
  Curry_Prelude.C_Just x3 -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_System.d_C_getEnviron (Curry_Prelude.toCurryString "PAGER") cd cs)
    (d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230_dot_uscore_hash_lambda232
    x3 x1) cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i
    (d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230 x1 l
    cd cs) (d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230
    x1 r cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z ->
    d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230 x1 z cd
    cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c
    (d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail
    "REPL.processShow._#lambda229._#lambda230" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.processShow._#lambda229._#lambda230"
    (showCons x2))

d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230_dot_uscore_hash_lambda232 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processShow_dot_uscore_hash_lambda229_dot_uscore_hash_lambda230_dot_uscore_hash_lambda232 x1 x2 x3 cd cs =
  let x4 = Curry_RCFile.d_C_rcValue (Curry_Linker.d_C_rcvars x2 cd cs)
        (Curry_Prelude.toCurryString "showcommand") cd cs
      x5 = d_C__case_90 x4 x3 (Curry_Prelude.d_C_not (Curry_Prelude.d_C_null x4
        cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar Curry_System.d_C_system
  (Curry_Prelude.d_OP_plus_plus x5 (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char
  ' '#) x1) cd cs) cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_putStrLn
  Curry_Prelude.OP_List cd cs) (Curry_Prelude.d_C_return (Curry_Prelude.C_Just
  x2) cd cs) cd cs) cd cs

d_C_processInterface :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processInterface x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_getModuleName x1 x2 cd cs)
  (d_OP_processInterface_dot_uscore_hash_lambda233 x1) cd cs

d_OP_processInterface_dot_uscore_hash_lambda233 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processInterface_dot_uscore_hash_lambda233 x1 x2 cd cs =
  d_C_checkAndCallCpmTool (Curry_Prelude.toCurryString "curry-showflat")
  (Curry_Prelude.toCurryString "showflatcurry")
  (d_OP_processInterface_dot_uscore_hash_lambda233_dot_uscore_hash_lambda234 x2
  x1) cd cs

d_OP_processInterface_dot_uscore_hash_lambda233_dot_uscore_hash_lambda234 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processInterface_dot_uscore_hash_lambda233_dot_uscore_hash_lambda234 x1 x2 x3 cd cs =
  d_C_execCommandWithPath x2 x3 (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "-int") (Curry_Prelude.OP_Cons x1
  Curry_Prelude.OP_List)) cd cs

d_C_processBrowse :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processBrowse x1 x2 cd cs = d_C__case_88 x2 x1 (Curry_Prelude.d_OP_dollar
  (Curry_Utils.d_C_notNull cd cs) (Curry_Distribution.d_C_stripCurrySuffix x2 cd
  cs) cd cs) cd cs

d_OP_processBrowse_dot_uscore_hash_lambda235 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processBrowse_dot_uscore_hash_lambda235 x1 x2 cd cs =
  d_C_execCommandWithPath x1 x2 (Curry_Prelude.OP_Cons (Curry_Linker.d_C_mainMod
  x1 cd cs) Curry_Prelude.OP_List) cd cs

d_C_processUsedImports :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processUsedImports x1 x2 cd cs = let x3 = d_C__case_86 x2 x1
                                           (Curry_Prelude.d_C_null x2 cd cs) cd
                                           cs
  in d_C_checkAndCallCpmTool (Curry_Prelude.toCurryString "curry-usedimports")
  (Curry_Prelude.toCurryString "importusage")
  (d_OP_processUsedImports_dot_uscore_hash_lambda236 x3 x1) cd cs

d_OP_processUsedImports_dot_uscore_hash_lambda236 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processUsedImports_dot_uscore_hash_lambda236 x1 x2 x3 cd cs =
  d_C_execCommandWithPath x2 x3 (Curry_Prelude.OP_Cons x1 Curry_Prelude.OP_List)
  cd cs

d_C_processSave :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processSave x1 x2 cd cs = d_C__case_85 x1 x2 (Curry_Prelude.d_OP_eq_eq
  (Curry_Linker.d_C_mainMod x1 cd cs) (Curry_Linker.d_C_preludeName x1 cd cs) cd
  cs) cd cs

d_OP_processSave_dot_uscore_hash_lambda237 :: Curry_Prelude.OP_Tuple2
  Curry_Linker.C_ReplState Curry_Linker.C_MainCompile -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processSave_dot_uscore_hash_lambda237 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.d_OP_gt_gt
    (Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_unless
    (Curry_Prelude.d_OP_eq_eq x3 Curry_Linker.C_MainError cd cs))
    (Curry_Prelude.d_OP_gt_gt (Curry_Directory.d_C_renameFile
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString ".") cd
    cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
    (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Linker.d_C_outputSubdir x2 cd
    cs) cd cs) (Curry_Prelude.toCurryString "Main") cd cs) cd cs)
    (Curry_Linker.d_C_mainMod x2 cd cs) cd cs)
    (Curry_Linker.d_C_writeVerboseInfo x2 (Curry_Prelude.C_Int 1#)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Executable saved in '") (Curry_Prelude.d_OP_plus_plus
    (Curry_Linker.d_C_mainMod x2 cd cs) (Curry_Prelude.toCurryString "'") cd cs)
    cd cs) cd cs) cd cs) cd cs) (Curry_Prelude.d_OP_gt_gt (d_C_cleanMainGoalFile
    x2 cd cs) (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x2) cd cs) cd cs)
    cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processSave_dot_uscore_hash_lambda237 l cd cs)
    (d_OP_processSave_dot_uscore_hash_lambda237 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processSave_dot_uscore_hash_lambda237 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processSave_dot_uscore_hash_lambda237 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processSave._#lambda237" [show x1] info)
  _ -> failCons cd (consFail "REPL.processSave._#lambda237" (showCons x1))

d_C_processFork :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processFork x1 x2 cd cs = d_C__case_82 x1 x2 (Curry_Prelude.d_OP_eq_eq
  (Curry_Linker.d_C_mainMod x1 cd cs) (Curry_Linker.d_C_preludeName x1 cd cs) cd
  cs) cd cs

d_OP_processFork_dot_uscore_hash_lambda238 :: Curry_Prelude.OP_Tuple2
  Curry_Linker.C_ReplState Curry_Linker.C_MainCompile -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processFork_dot_uscore_hash_lambda238 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> Curry_Prelude.d_OP_gt_gt
    (Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_unless
    (Curry_Prelude.d_OP_eq_eq x3 Curry_Linker.C_MainError cd cs))
    (Curry_Prelude.d_OP_gt_gt_eq (Curry_System.d_C_getPID cd cs)
    (d_OP_processFork_dot_uscore_hash_lambda238_dot_uscore_hash_lambda239 x2) cd
    cs) cd cs) (Curry_Prelude.d_OP_gt_gt (d_C_cleanMainGoalFile x2 cd cs)
    (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x2) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processFork_dot_uscore_hash_lambda238 l cd cs)
    (d_OP_processFork_dot_uscore_hash_lambda238 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processFork_dot_uscore_hash_lambda238 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processFork_dot_uscore_hash_lambda238 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processFork._#lambda238" [show x1] info)
  _ -> failCons cd (consFail "REPL.processFork._#lambda238" (showCons x1))

d_OP_processFork_dot_uscore_hash_lambda238_dot_uscore_hash_lambda239 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_OP_processFork_dot_uscore_hash_lambda238_dot_uscore_hash_lambda239 x1 x2 cd cs =
  let x3 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString
        ".") cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Linker.d_C_outputSubdir
        x1 cd cs) cd cs) (Curry_Prelude.d_OP_plus_plus
        (Curry_Prelude.toCurryString "kics2fork") (Curry_Prelude.d_C_show x2 cd
        cs) cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt (Curry_Directory.d_C_renameFile
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString ".") cd
  cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
  (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Linker.d_C_outputSubdir x1 cd
  cs) cd cs) (Curry_Prelude.toCurryString "Main") cd cs) cd cs) x3 cd cs)
  (Curry_Prelude.d_OP_gt_gt (Curry_Linker.d_C_writeVerboseInfo x1
  (Curry_Prelude.C_Int 3#) (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "Starting executable '")
  (Curry_Prelude.d_OP_plus_plus x3 (Curry_Prelude.toCurryString "'...") cd cs)
  cd cs) cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_System.d_C_system
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "( ")
  (Curry_Prelude.d_OP_plus_plus x3 (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString " && rm -f ") (Curry_Prelude.d_OP_plus_plus x3
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString ") ")
  (Curry_Prelude.toCurryString "> /dev/null 2> /dev/null &") cd cs) cd cs) cd
  cs) cd cs) cd cs) cd cs) (Curry_Prelude.d_C_done cd cs) cd cs) cd cs) cd cs

d_C_processSetOption :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processSetOption x1 x2 cd cs = let x3 = Curry_Prelude.d_C_apply
                                         (Curry_Prelude.d_C_break
                                         (Curry_Prelude.d_C_flip (acceptCs id
                                         Curry_Prelude.d_OP_eq_eq)
                                         (Curry_Prelude.C_Char ' '#)) cd cs) x2
                                         cd cs
                                       x4 = d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt
                                         x3 cd cs
                                       x5 = d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args
                                         x3 cd cs
                                       x6 = Curry_Prelude.d_C_filter
                                         (Curry_Prelude.d_OP_dot
                                         (Curry_List.d_C_isPrefixOf
                                         (Curry_Prelude.d_C_map
                                         Curry_Char.d_C_toLower x4 cd cs))
                                         Curry_Prelude.d_C_fst cd cs)
                                         (d_C_availOptions x1 cd cs) cd cs
  in d_C__case_79 x2 x6 x5 x1 (Curry_Prelude.d_C_null (Curry_Prelude.d_C_apply
  (Curry_Utils.d_C_strip cd cs) x2 cd cs) cd cs) cd cs

d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt l cd cs)
    (d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processSetOption_dot_uscore_hash_selFP30_hash_opt e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processSetOption._#selFP30#opt" [show x1] info)
  _ -> failCons cd (consFail "REPL.processSetOption._#selFP30#opt" (showCons
    x1))

d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args l cd cs)
    (d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_processSetOption_dot_uscore_hash_selFP31_hash_args e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.processSetOption._#selFP31#args" [show x1] info)
  _ -> failCons cd (consFail "REPL.processSetOption._#selFP31#args" (showCons
    x1))

d_C_availOptions :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
d_C_availOptions x1 cd cs = Curry_Prelude.d_C_filter
  (d_OP_availOptions_dot_installOpts_dot_446 x1) (d_C_replOptions cd cs) cd cs

nd_C_availOptions :: Curry_Linker.C_ReplState -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))))
nd_C_availOptions x1 s cd cs = let s2 = s
  in s2 `seq` (let s1 = leftSupply s2
                   s0 = rightSupply s2
  in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_filter (wrapDX id
  (d_OP_availOptions_dot_installOpts_dot_446 x1)) (nd_C_replOptions s0 cd cs) s1
  cd cs))

d_OP_availOptions_dot_installOpts_dot_446 :: forall t0 . (Curry_Prelude.Curry
  t0) => Curry_Linker.C_ReplState -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) t0 -> Cover -> ConstStore
  -> Curry_Prelude.C_Bool
d_OP_availOptions_dot_installOpts_dot_446 x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> Curry_Prelude.d_OP_bar_bar
    (Curry_Linker.d_C_localCompile x1 cd cs) (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_notElem x3 cd cs) (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "supply") Curry_Prelude.OP_List) cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_availOptions_dot_installOpts_dot_446 x1 l cd cs)
    (d_OP_availOptions_dot_installOpts_dot_446 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_availOptions_dot_installOpts_dot_446 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_availOptions_dot_installOpts_dot_446 x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.availOptions.installOpts.446" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.availOptions.installOpts.446" (showCons x2))

d_C_replOptions :: Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
d_C_replOptions cd cs = Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "paths") (acceptCs id d_C_setOptionPath))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "bfs") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda241))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "dfs") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda274))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "prdfs") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda307))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "debugsearch") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda340))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "choices") (acceptCs id (d_C_setOptionNDMode (acceptCs id
  Curry_Linker.C_PrtChoices) (Curry_Prelude.C_Int 10#)))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "ids") (acceptCs id
  (d_C_setOptionNDMode (acceptCs id Curry_Linker.C_IDS) (Curry_Prelude.C_Int
  100#)))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "parallel") (acceptCs id (d_C_setOptionNDMode
  (acceptCs id Curry_Linker.C_Par) (Curry_Prelude.C_Int 0#))))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "supply") (acceptCs id d_C_setOptionSupply)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v0") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda373)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v1") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda406)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v2") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda439)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v3") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda472)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v4") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda505)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "prompt") (acceptCs id
  d_C_setPrompt)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "+interactive") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda538)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "-interactive")
  (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda571))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+first") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda604))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-first") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda637))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+optimize") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda670))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-optimize") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda703))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+bindings") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda736))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-bindings") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda769))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+time") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda802))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-time") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda835))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+trace") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda868))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-trace") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda901))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+profile") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda934))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-profile") (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda967))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+local") (acceptCs id d_C_setLocalMode)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "-local") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1000)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+ghci") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1033)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "-ghci") (acceptCs id
  d_C_setNoGhci)) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "safe") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1066)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "prelude") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1099)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "parser") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1132)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "cmp") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1165)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "ghc") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1198)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "rts") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1231)) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "args") (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1264))
  Curry_Prelude.OP_List)))))))))))))))))))))))))))))))))))))))

nd_C_replOptions :: IDSupply -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func
  Curry_Linker.C_ReplState (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))))
nd_C_replOptions s cd cs = Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "paths") (wrapDX (wrapDX id) (acceptCs id
  d_C_setOptionPath))) (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.toCurryString "bfs") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda241))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "dfs") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda274)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "prdfs") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda307))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "debugsearch") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda340)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "choices") (wrapDX (wrapNX id) (acceptCs id (nd_C_setOptionNDMode (wrapDX id
  (acceptCs id Curry_Linker.C_PrtChoices)) (Curry_Prelude.C_Int 10#)))))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "ids") (wrapDX (wrapNX id) (acceptCs id (nd_C_setOptionNDMode (wrapDX id
  (acceptCs id Curry_Linker.C_IDS)) (Curry_Prelude.C_Int 100#)))))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "parallel") (wrapDX (wrapNX id) (acceptCs id (nd_C_setOptionNDMode (wrapDX id
  (acceptCs id Curry_Linker.C_Par)) (Curry_Prelude.C_Int 0#)))))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "supply") (wrapDX (wrapDX id) (acceptCs id d_C_setOptionSupply)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "v0") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda373))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v1") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda406)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "v2") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda439))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "v3") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda472)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "v4") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda505))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "prompt") (wrapDX
  (wrapDX id) (acceptCs id d_C_setPrompt))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+interactive") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda538)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-interactive") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda571))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+first") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda604)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-first") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda637))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+optimize") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda670)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-optimize") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda703))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+bindings") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda736)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-bindings") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda769))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+time") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda802)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-time") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda835))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+trace") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda868)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-trace") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda901))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+profile") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda934)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "-profile") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda967))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "+local") (wrapDX
  (wrapDX id) (acceptCs id d_C_setLocalMode))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "-local") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda1000)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "+ghci") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1033))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "-ghci") (wrapDX (wrapDX
  id) (acceptCs id d_C_setNoGhci))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "safe") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda1066)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "prelude") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1099))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "parser") (wrapDX
  (wrapDX id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda1132)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "cmp") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1165))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "ghc") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda1198)))
  (Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString
  "rts") (wrapDX (wrapDX id) (acceptCs id
  d_OP_replOptions_dot_uscore_hash_lambda1231))) (Curry_Prelude.OP_Cons
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.toCurryString "args") (wrapDX (wrapDX
  id) (acceptCs id d_OP_replOptions_dot_uscore_hash_lambda1264)))
  Curry_Prelude.OP_List)))))))))))))))))))))))))))))))))))))))

d_OP_replOptions_dot_uscore_hash_lambda241 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda241 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_74 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda274 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda274 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_73 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda307 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda307 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_72 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda340 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda340 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_71 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda373 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda373 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_70 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda406 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda406 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_69 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda439 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda439 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_68 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda472 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda472 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_67 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda505 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda505 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_66 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda538 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda538 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_65 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda571 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda571 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_64 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda604 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda604 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_63 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda637 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda637 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_62 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda670 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda670 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_61 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda703 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda703 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_60 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda736 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda736 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_59 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda769 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda769 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_58 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda802 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda802 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_57 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda835 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda835 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_56 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda868 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda868 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_55 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda901 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda901 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_54 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda934 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda934 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_53 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda967 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda967 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_52 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda1000 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1000 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_51 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda1033 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1033 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_50 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda1066 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1066 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_49 x1 cd cs)) cd cs

d_OP_replOptions_dot_uscore_hash_lambda1099 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1099 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_48 x2 x1 cd cs)) cd
  cs

d_OP_replOptions_dot_uscore_hash_lambda1132 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1132 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_47 x2 x1 cd cs)) cd
  cs

d_OP_replOptions_dot_uscore_hash_lambda1165 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1165 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_46 x2 x1 cd cs)) cd
  cs

d_OP_replOptions_dot_uscore_hash_lambda1198 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1198 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_45 x2 x1 cd cs)) cd
  cs

d_OP_replOptions_dot_uscore_hash_lambda1231 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1231 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_44 x2 x1 cd cs)) cd
  cs

d_OP_replOptions_dot_uscore_hash_lambda1264 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_replOptions_dot_uscore_hash_lambda1264 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_43 x2 x1 cd cs)) cd
  cs

d_C_setLocalMode :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_setLocalMode x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_System.d_C_getPID cd cs) (d_OP_setLocalMode_dot_uscore_hash_lambda1297
  x1) cd cs

d_OP_setLocalMode_dot_uscore_hash_lambda1297 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_setLocalMode_dot_uscore_hash_lambda1297 x1 x2 cd cs =
  let x3 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs)
        (Curry_Distribution.d_C_installDir cd cs) cd cs)
        (Curry_Prelude.toCurryString "lib") cd cs
      x4 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs) x3 cd cs)
        (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "xxx")
        (Curry_Prelude.d_C_show x2 cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_catch (Curry_Prelude.d_OP_gt_gt
  (Curry_Prelude.d_C_writeFile x4 Curry_Prelude.OP_List cd cs)
  (Curry_Directory.d_C_removeFile x4 cd cs) cd cs)
  (d_OP_setLocalMode_dot_uscore_hash_lambda1297_dot_uscore_hash_lambda1298 x3)
  cd cs) (Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_return
  (Curry_Prelude.C_Just (d_C__case_42 x1 cd cs)) cd cs) cd cs

d_OP_setLocalMode_dot_uscore_hash_lambda1297_dot_uscore_hash_lambda1298 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_IOError -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_setLocalMode_dot_uscore_hash_lambda1297_dot_uscore_hash_lambda1298 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_putStrLn
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "Warning: no write permission on `") (Curry_Prelude.d_OP_plus_plus x1
  (Curry_Prelude.toCurryString "'") cd cs) cd cs) cd cs)
  (Curry_Prelude.d_C_putStrLn (Curry_Prelude.toCurryString
  "Local compilation mode may not work!") cd cs) cd cs

d_C_setPrompt :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_setPrompt x1 x2 cd cs = let x3 = Curry_Prelude.d_C_apply
                                  (Curry_Utils.d_C_strip cd cs) x2 cd cs
  in d_C__case_41 x3 x1 (Curry_Prelude.d_C_null x3 cd cs) cd cs

d_C_setNoGhci :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_setNoGhci x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_maybe
  (Curry_Prelude.d_C_done cd cs) Curry_GhciComm.d_C_stopGhciComm
  (Curry_Linker.d_C_ghcicomm x1 cd cs) cd cs) (Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_32 x1 cd cs)) cd cs)
  cd cs

d_C_setOptionPath :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_setOptionPath x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq (d_C__case_31 x2 x1
  (Curry_Prelude.d_C_null x2 cd cs) cd cs)
  (d_OP_setOptionPath_dot_uscore_hash_lambda1429 x1) cd cs

d_OP_setOptionPath_dot_uscore_hash_lambda1429 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_setOptionPath_dot_uscore_hash_lambda1429 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.C_Just (d_C__case_30 x2 x1 cd cs)) cd
  cs

d_C_setOptionNDMode :: (Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Linker.C_NonDetMode) -> Curry_Prelude.C_Int
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C_setOptionNDMode x1 x2 x3 x4 cd cs = d_C__case_29 x4 x3 x1 x2
  (Curry_Prelude.d_C_null x4 cd cs) cd cs

nd_C_setOptionNDMode :: Func Curry_Prelude.C_Int Curry_Linker.C_NonDetMode
  -> Curry_Prelude.C_Int -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C_setOptionNDMode x1 x2 x3 x4 s cd cs = let s0 = s
  in s0 `seq` nd_C__case_29 x4 x3 x1 x2 (Curry_Prelude.d_C_null x4 cd cs) s0 cd
  cs

d_C_setOptionSupply :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_setOptionSupply x1 x2 cd cs = let x3 = Curry_Prelude.OP_Cons
                                        (Curry_Prelude.toCurryString "integer")
                                        (Curry_Prelude.OP_Cons
                                        (Curry_Prelude.toCurryString "ghc")
                                        (Curry_Prelude.OP_Cons
                                        (Curry_Prelude.toCurryString "ioref")
                                        (Curry_Prelude.OP_Cons
                                        (Curry_Prelude.toCurryString "pureio")
                                        (Curry_Prelude.OP_Cons
                                        (Curry_Prelude.toCurryString "giants")
                                        Curry_Prelude.OP_List))))
  in d_C__case_22 x3 x2 x1 (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem x2
  cd cs) x3 cd cs) cd cs

d_C_printOptions :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_printOptions x1 cd cs = Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_putStrLn
  (Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_unlines (Curry_Prelude.d_C_filter
  (Curry_Utils.d_C_notNull cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "Options for ':set' command:")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "path <paths>    - set additional search paths for imported modules")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "prdfs           - set search mode to primitive depth-first search")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "dfs             - set search mode to depth-first search")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "bfs             - set search mode to breadth-first search")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "ids [<n>]       - set search mode to iterative deepening (initial depth <n>)")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "parallel [<n>]  - set search mode to parallel search with <n> threads")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "choices [<n>]   - set search mode to print the choice structure as a tree")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "                  (up to level <n>)") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "debugsearch     - set search mode to print debugging information")
  (Curry_Prelude.OP_Cons (d_C_ifLocal x1 (Curry_Prelude.toCurryString
  "supply <I>      - set idsupply implementation (ghc|giants|integer|ioref|pureio)")
  cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "v<n>            - verbosity level") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "                    0: quiet (errors and warnings only)")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "                    1: frontend status messages (default)")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "                    2: kics2c status messages") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "                    3: ghc status messages")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "                    4: analysis information") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString "prompt <prompt> - set the user prompt")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-interactive  - turn on/off interactive execution of main goal")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-first        - turn on/off printing only first solution")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-optimize     - turn on/off optimization") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "+/-bindings     - show bindings of free variables in initial goal")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-time         - show compilation and execution time")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-trace        - trace failure in deterministic expression")
  (Curry_Prelude.OP_Cons (d_C_ifProfiling (Curry_Prelude.toCurryString
  "+/-profile      - compile with GHC's profiling capabilities") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-local        - use local libraries instead of cabal packages")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "+/-ghci         - use ghci instead of ghc to evaluate main expression")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "safe            - safe execution mode without I/O actions")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "prelude <name>  - name of the standard prelude") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "parser  <opts>  - additional options passed to parser (front end)")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "cmp     <opts>  - additional options passed to KiCS2 compiler")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "ghc     <opts>  - additional options passed to GHC") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "rts     <opts>  - run-time options for ghc (+RTS <opts> -RTS)")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  "args    <args>  - run-time arguments passed to main program")
  (Curry_Prelude.OP_Cons (d_C_showCurrentOptions x1 cd cs)
  Curry_Prelude.OP_List))))))))))))))))))))))))))))))))))) cd cs) cd cs) cd cs

d_C_ifLocal :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C_ifLocal x1 x2 cd cs = d_C__case_19 x1 x2 (Curry_Linker.d_C_localCompile x1
  cd cs) cd cs

d_C_ifProfiling :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_ifProfiling x1 cd cs = d_C__case_18 x1 (Curry_Installation.d_C_withProfiling
  cd cs) cd cs

d_C_showCurrentOptions :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C_showCurrentOptions x1 cd cs = Curry_Prelude.d_OP_dollar
  (Curry_List.d_C_intercalate (Curry_Prelude.toCurryString "\n"))
  (Curry_Prelude.d_C_filter (Curry_Utils.d_C_notNull cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "\nCurrent settings:")
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "import paths      : ")
  (Curry_List.d_C_intercalate (Curry_Prelude.OP_Cons
  (Curry_FilePath.d_C_searchPathSeparator cd cs) Curry_Prelude.OP_List)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString ".")
  (Curry_Linker.d_C_importPaths x1 cd cs)) cd cs) cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "search mode       : ") (d_C__case_17 x1 (Curry_Linker.d_C_ndMode x1 cd cs) cd
  cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_dollar (d_C_ifLocal x1)
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "idsupply          : ") (Curry_Linker.d_C_idSupply x1 cd cs) cd cs) cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "prelude           : ")
  (Curry_Linker.d_C_preludeName x1 cd cs) cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "parser options    : ") (Curry_Linker.d_C_parseOpts x1 cd cs) cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "compiler options  : ") (Curry_Linker.d_C_cmpOpts
  x1 cd cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "ghc options       : ") (Curry_Linker.d_C_ghcOpts
  x1 cd cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "run-time options  : ") (Curry_Linker.d_C_rtsOpts
  x1 cd cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "run-time arguments: ") (Curry_Linker.d_C_rtsArgs
  x1 cd cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "verbosity         : ") (Curry_Prelude.d_C_show
  (Curry_Linker.d_C_verbose x1 cd cs) cd cs) cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "prompt            : ") (Curry_Prelude.d_C_show (Curry_Linker.d_C_prompt x1 cd
  cs) cd cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_unwords (Curry_Prelude.d_C_filter (Curry_Utils.d_C_notNull
  cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_interactive
  x1 cd cs) cd cs) (Curry_Prelude.toCurryString "interactive") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_firstSol x1
  cd cs) cd cs) (Curry_Prelude.toCurryString "first") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_optim x1 cd
  cs) cd cs) (Curry_Prelude.toCurryString "optimize") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_showBindings
  x1 cd cs) cd cs) (Curry_Prelude.toCurryString "bindings") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_showTime x1
  cd cs) cd cs) (Curry_Prelude.toCurryString "time") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_traceFailure
  x1 cd cs) cd cs) (Curry_Prelude.toCurryString "trace") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_dollar d_C_ifProfiling
  (Curry_Prelude.d_OP_plus_plus (d_OP_showCurrentOptions_dot_showOnOff_dot_562
  (Curry_Linker.d_C_profile x1 cd cs) cd cs) (Curry_Prelude.toCurryString
  "profile") cd cs) cd cs) (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_localCompile
  x1 cd cs) cd cs) (Curry_Prelude.toCurryString "local") cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
  (d_OP_showCurrentOptions_dot_showOnOff_dot_562 (Curry_Linker.d_C_useGhci x1 cd
  cs) cd cs) (Curry_Prelude.toCurryString "ghci") cd cs)
  Curry_Prelude.OP_List))))))))) cd cs) cd cs)
  Curry_Prelude.OP_List))))))))))))) cd cs) cd cs

d_OP_showCurrentOptions_dot_showOnOff_dot_562 :: Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_OP_showCurrentOptions_dot_showOnOff_dot_562 x1 cd cs = case x1 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "+"
  Curry_Prelude.C_False -> Curry_Prelude.toCurryString "-"
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_showCurrentOptions_dot_showOnOff_dot_562 l cd cs)
    (d_OP_showCurrentOptions_dot_showOnOff_dot_562 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_showCurrentOptions_dot_showOnOff_dot_562 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_showCurrentOptions_dot_showOnOff_dot_562 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.showCurrentOptions.showOnOff.562" [show x1] info)
  _ -> failCons cd (consFail "REPL.showCurrentOptions.showOnOff.562" (showCons
    x1))

d_C_printHelpOnCommands :: Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C_printHelpOnCommands cd cs = Curry_Prelude.d_OP_dollar
  Curry_Prelude.d_C_putStrLn (Curry_Prelude.d_C_unlines (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  "Commands (can be abbreviated to a prefix if unique)") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":load <prog>       - load program '<prog>.[l]curry' as main module")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":add  <m1> .. <mn> - add modules '<m1>' to '<mn>' to currently loaded modules")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":reload            - recompile currently loaded modules")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":compile <prog>    - like ':load <prog>' but also compile Haskell code")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":eval <expr>       - evaluate expression <expr>") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":type <expr>       - show type of expression <expr>") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":programs          - show names of all Curry programs available in load path")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":cd <dir>          - change current directory to <dir>")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":edit              - load source of currently loaded module into editor")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":edit <m>          - load source of module <m> into editor")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":show              - show currently loaded source program")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":show <m>          - show source of module <m>") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":source <f>        - show source of (visible!) function <f>")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":source <m>.<f>    - show source of function <f> in module <m>")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":browse            - browse program and its imported modules")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":interface         - show interface of currently loaded module")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":interface <m>     - show interface of module <m>") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":usedimports       - show all used imported functions/constructors")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":set <option>      - set an option") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":set               - see help on options and current options")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":save              - save executable with main expression 'main'")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":save <expr>       - save executable with main expression <expr>")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":fork <expr>       - fork new process evaluating <expr>")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
  ":help              - show this message") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString
  ":!<command>        - execute <command> in shell") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString ":quit              - leave the system")
  Curry_Prelude.OP_List))))))))))))))))))))))))))) cd cs) cd cs

d_C_printAllLoadPathPrograms :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C_printAllLoadPathPrograms x1 cd cs = Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_mapIO_
  d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582 cd cs)
  (Curry_Linker.d_C_loadPaths x1 cd cs) cd cs

d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582 x1 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_putStrLn
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "Curry programs in directory ") (Curry_Prelude.d_OP_plus_plus x1
  (Curry_Prelude.toCurryString ":") cd cs) cd cs) cd cs)
  (Curry_Prelude.d_OP_gt_gt_eq (Curry_Directory.d_C_getDirectoryContents x1 cd
  cs)
  d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560
  cd cs) cd cs

d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560 x1 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_putStrLn
  (Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_unwords
  (Curry_Prelude.d_OP_dollar (Curry_Sort.d_C_mergeSort cd cs)
  (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_concatMap
  d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561
  cd cs) x1 cd cs) cd cs) cd cs) cd cs) (Curry_Prelude.d_C_putStrLn
  Curry_Prelude.OP_List cd cs) cd cs

d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561 x1 cd cs =
  let x2 = Curry_FilePath.d_C_splitExtension x1 cd cs
      x3 = d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base
        x2 cd cs
      x4 = d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx
        x2 cd cs
  in d_C__case_16 x3 x4 (Curry_Prelude.d_OP_amp_amp (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_elem x4 cd cs) (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString ".curry") (Curry_Prelude.OP_Cons
  (Curry_Prelude.toCurryString ".lcurry") Curry_Prelude.OP_List)) cd cs)
  (Curry_Prelude.d_C_apply (Curry_Utils.d_C_notNull cd cs) x3 cd cs) cd cs) cd
  cs

d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base
    l cd cs)
    (d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP33_hash_base
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.printAllLoadPathPrograms.printDirPrograms.582._#lambda1560._#lambda1561._#selFP33#base"
    [show x1] info)
  _ -> failCons cd (consFail
    "REPL.printAllLoadPathPrograms.printDirPrograms.582._#lambda1560._#lambda1561._#selFP33#base"
    (showCons x1))

d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x3
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx
    l cd cs)
    (d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_printAllLoadPathPrograms_dot_printDirPrograms_dot_582_dot_uscore_hash_lambda1560_dot_uscore_hash_lambda1561_dot_uscore_hash_selFP34_hash_sfx
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.printAllLoadPathPrograms.printDirPrograms.582._#lambda1560._#lambda1561._#selFP34#sfx"
    [show x1] info)
  _ -> failCons cd (consFail
    "REPL.printAllLoadPathPrograms.printDirPrograms.582._#lambda1560._#lambda1561._#selFP34#sfx"
    (showCons x1))

d_C_showFunctionInModule :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C_showFunctionInModule x1 x2 x3 cd cs = Curry_Prelude.d_OP_dollar
  (d_C_checkForWish cd cs) (Curry_Prelude.d_OP_dollar (d_C_checkAndCallCpmTool
  (Curry_Prelude.toCurryString "curry-showsource") (Curry_Prelude.toCurryString
  "sourceproggui")) (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562 x3 x2
  x1) cd cs) cd cs

d_OP_showFunctionInModule_dot_updateFun_dot_590 :: forall t0 t1
  t2 . (Curry_Prelude.Curry t0, Curry_Prelude.Curry t1, Curry_Prelude.Curry
  t2) => Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 t0
  (Curry_Prelude.OP_Tuple2 t1 t2)) -> t0 -> t1 -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2
  t1 t2))
d_OP_showFunctionInModule_dot_updateFun_dot_590 x1 x2 x3 cd cs = case x1 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x4 x5 -> d_C__case_15 x2 x3 x5 x4 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_showFunctionInModule_dot_updateFun_dot_590 l x2 x3 cd cs)
    (d_OP_showFunctionInModule_dot_updateFun_dot_590 r x2 x3 cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_showFunctionInModule_dot_updateFun_dot_590 z x2 x3 cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_showFunctionInModule_dot_updateFun_dot_590 e x2 x3 cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.showFunctionInModule.updateFun.590" [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL.showFunctionInModule.updateFun.590" (showCons
    x1))

d_OP_showFunctionInModule_dot_uscore_hash_lambda1562 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_OP_showFunctionInModule_dot_uscore_hash_lambda1562 x1 x2 x3 x4 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
  (Curry_Linker.d_C_writeVerboseInfo x3 (Curry_Prelude.C_Int 1#))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "Showing source code of function '") (Curry_Prelude.d_OP_plus_plus x2
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString ".")
  (Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.toCurryString
  "' in separate window...") cd cs) cd cs) cd cs) cd cs) cd cs)
  (let x5 = Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
         "CURRYPATH=") (Curry_Prelude.d_OP_plus_plus (Curry_List.d_C_intercalate
         (Curry_Prelude.OP_Cons (Curry_FilePath.d_C_searchPathSeparator cd cs)
         Curry_Prelude.OP_List) (Curry_Prelude.d_OP_plus_plus
         (Curry_Linker.d_C_importPaths x3 cd cs)
         (Curry_Distribution.d_C_sysLibPath cd cs) cd cs) cd cs)
         (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
         " && export CURRYPATH && ") (Curry_Prelude.d_OP_plus_plus x4
         (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString " ") x2 cd
         cs) cd cs) cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
  (Curry_Linker.d_C_writeVerboseInfo x3 (Curry_Prelude.C_Int 2#))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "Executing: ") x5
  cd cs) cd cs) (Curry_Prelude.d_OP_gt_gt_eq (Curry_Prelude.d_C_maybe
  (Curry_Prelude.d_OP_gt_gt_eq (Curry_IOExts.d_C_connectToCommand x5 cd cs)
  (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1563
  x1 x2 x3) cd cs)
  (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596
  x1 x2 x3) (Curry_Prelude.d_C_lookup x2 (Curry_Linker.d_C_sourceguis x3 cd cs)
  cd cs) cd cs)
  (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629
  x1) cd cs) cd cs) cd cs

d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1563 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_IO.C_Handle -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_IO.C_Handle)
d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1563 x1 x2 x3 x4 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2 (d_C__case_12 x4 x1 x2 x3 cd
  cs) x4) cd cs

d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) Curry_IO.C_Handle -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_IO.C_Handle)
d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596 x1 x2 x3 x4 cd cs =
  case x4 of
  Curry_Prelude.OP_Tuple2 x5 x6 -> Curry_Prelude.d_OP_gt_gt
    (Curry_IO.d_C_hPutStrLn x6 (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char
    '-'#) x5) cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_IO.d_C_hFlush x6 cd cs)
    (Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2 (d_C__case_11 x1 x2 x3 cd
    cs) x6) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596
    x1 x2 x3 l cd cs)
    (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596
    x1 x2 x3 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596
    x1 x2 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1596
    x1 x2 x3 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.showFunctionInModule._#lambda1562._#lambda1596" [show x1, show x2
    , show x3, show x4] info)
  _ -> failCons cd (consFail
    "REPL.showFunctionInModule._#lambda1562._#lambda1596" (showCons x4))

d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_IO.C_Handle -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629 x1 x2 cd cs =
  case x2 of
  Curry_Prelude.OP_Tuple2 x3 x4 -> Curry_Prelude.d_OP_gt_gt
    (Curry_IO.d_C_hPutStrLn x4 (Curry_Prelude.OP_Cons (Curry_Prelude.C_Char
    '+'#) x1) cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_IO.d_C_hFlush x4 cd cs)
    (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x3) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629
    x1 l cd cs)
    (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629
    x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629
    x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_showFunctionInModule_dot_uscore_hash_lambda1562_dot_uscore_hash_lambda1629
    x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.showFunctionInModule._#lambda1562._#lambda1629" [show x1, show x2]
    info)
  _ -> failCons cd (consFail
    "REPL.showFunctionInModule._#lambda1562._#lambda1629" (showCons x2))

d_C_checkAndCallCpmTool :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> (Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_checkAndCallCpmTool x1 x2 x3 cd cs = let x4 = Curry_Prelude.d_OP_plus_plus
                                               (Curry_Prelude.toCurryString "'")
                                               (Curry_Prelude.d_OP_plus_plus x1
                                               (Curry_Prelude.d_OP_plus_plus
                                               (Curry_Prelude.toCurryString
                                               "' not found. Install it by: 'cypm install ")
                                               (Curry_Prelude.d_OP_plus_plus x2
                                               (Curry_Prelude.toCurryString
                                               "'!") cd cs) cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_Prelude.d_OP_dollar
  Curry_System.d_C_system (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "which ") (Curry_Prelude.d_OP_plus_plus x1
  (Curry_Prelude.toCurryString " > /dev/null") cd cs) cd cs) cd cs)
  (d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630 x3 x4 x1) cd cs

nd_C_checkAndCallCpmTool :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Func (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)) -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C_checkAndCallCpmTool x1 x2 x3 s cd cs = let s2 = s
  in s2 `seq` (let x4 = Curry_Prelude.d_OP_plus_plus
                     (Curry_Prelude.toCurryString "'")
                     (Curry_Prelude.d_OP_plus_plus x1
                     (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
                     "' not found. Install it by: 'cypm install ")
                     (Curry_Prelude.d_OP_plus_plus x2
                     (Curry_Prelude.toCurryString "'!") cd cs) cd cs) cd cs) cd
                     cs
  in let s1 = leftSupply s2
         s0 = rightSupply s2
  in s1 `seq` (s0 `seq` Curry_Prelude.nd_OP_gt_gt_eq (Curry_Prelude.nd_OP_dollar
  (wrapDX id Curry_System.d_C_system) (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "which ") (Curry_Prelude.d_OP_plus_plus x1
  (Curry_Prelude.toCurryString " > /dev/null") cd cs) cd cs) s0 cd cs) (wrapNX
  id (nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630 x3 x4 x1)) s1 cd cs))

d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630 :: (Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Int -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630 x1 x2 x3 x4 cd cs =
  d_C__case_10 x4 x3 x2 x1 (Curry_Prelude.d_OP_eq_eq x4 (Curry_Prelude.C_Int 0#)
  cd cs) cd cs

nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630 :: Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Int -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630 x1 x2 x3 x4 s cd cs =
  let s0 = s
  in s0 `seq` nd_C__case_10 x4 x3 x2 x1 (Curry_Prelude.d_OP_eq_eq x4
  (Curry_Prelude.C_Int 0#) cd cs) s0 cd cs

d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631 :: (Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631 x1 x2 x3 x4 cd cs =
  let x5 = Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs) x4 cd cs)
        (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString
        ".cpm") cd cs) (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply
        (Curry_FilePath.d_OP_lt_slash_gt cd cs) (Curry_Prelude.toCurryString
        "bin") cd cs) x3 cd cs) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt_eq (Curry_Directory.d_C_doesFileExist x5 cd cs)
  (d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
  x1 x5 x2) cd cs

nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631 :: Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631 x1 x2 x3 x4 s cd cs =
  let s12 = s
  in s12 `seq` (let s9 = leftSupply s12
                    s11 = rightSupply s12
  in s9 `seq` (s11 `seq` (let x5 = let s8 = leftSupply s9
                                       s10 = rightSupply s9
                                       s0 = leftSupply s10
                                       s6 = rightSupply s10
                                in s8 `seq` (s10 `seq` (s0 `seq` (s6 `seq`
                                Curry_Prelude.nd_C_apply
                                (Curry_Prelude.nd_C_apply (wrapDX (wrapDX id)
                                (Curry_FilePath.d_OP_lt_slash_gt cd cs)) x4 s0
                                cd cs) (let s5 = leftSupply s6
                                            s7 = rightSupply s6
                                            s1 = leftSupply s7
                                            s4 = rightSupply s7
                                in s5 `seq` (s7 `seq` (s1 `seq` (s4 `seq`
                                Curry_Prelude.nd_C_apply
                                (Curry_Prelude.nd_C_apply (wrapDX (wrapDX id)
                                (Curry_FilePath.d_OP_lt_slash_gt cd cs))
                                (Curry_Prelude.toCurryString ".cpm") s1 cd cs)
                                (let s3 = leftSupply s4
                                     s2 = rightSupply s4
                                in s3 `seq` (s2 `seq` Curry_Prelude.nd_C_apply
                                (Curry_Prelude.nd_C_apply (wrapDX (wrapDX id)
                                (Curry_FilePath.d_OP_lt_slash_gt cd cs))
                                (Curry_Prelude.toCurryString "bin") s2 cd cs) x3
                                s3 cd cs)) s5 cd cs)))) s8 cd cs)))
  in Curry_Prelude.nd_OP_gt_gt_eq (Curry_Directory.d_C_doesFileExist x5 cd cs)
  (wrapNX id
  (nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
  x1 x5 x2)) s11 cd cs)))

d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632 :: (Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632 x1 x2 x3 x4 cd cs =
  case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_apply x1 x2 cd cs
  Curry_Prelude.C_False -> d_C_skipCommand x3 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 l cd cs)
    (d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.checkAndCallCpmTool._#lambda1630._#lambda1631._#lambda1632" [show x1
    , show x2, show x3, show x4] info)
  _ -> failCons cd (consFail
    "REPL.checkAndCallCpmTool._#lambda1630._#lambda1631._#lambda1632" (showCons
    x4))

nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632 :: Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632 x1 x2 x3 x4 s cd cs =
  case x4 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_C_apply x1 x2 s0 cd cs
  Curry_Prelude.C_False -> d_C_skipCommand x3 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 l s cd cs)
    (nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631_dot_uscore_hash_lambda1632
    x1 x2 x3 e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.checkAndCallCpmTool._#lambda1630._#lambda1631._#lambda1632" [show x1
    , show x2, show x3, show x4] info)
  _ -> failCons cd (consFail
    "REPL.checkAndCallCpmTool._#lambda1630._#lambda1631._#lambda1632" (showCons
    x4))

d_C_execCommandWithPath :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_execCommandWithPath x1 x2 x3 cd cs = let x4 = Curry_Prelude.d_OP_plus_plus
                                               (Curry_Prelude.toCurryString
                                               "CURRYPATH=")
                                               (Curry_Prelude.d_OP_plus_plus
                                               (Curry_List.d_C_intercalate
                                               (Curry_Prelude.OP_Cons
                                               (Curry_FilePath.d_C_searchPathSeparator
                                               cd cs) Curry_Prelude.OP_List)
                                               (Curry_Prelude.d_OP_plus_plus
                                               (Curry_Linker.d_C_importPaths x1
                                               cd cs)
                                               (Curry_Distribution.d_C_sysLibPath
                                               cd cs) cd cs) cd cs)
                                               (Curry_Prelude.toCurryString
                                               " && export CURRYPATH && ") cd
                                               cs) cd cs
                                             x5 = Curry_Prelude.d_OP_plus_plus
                                               x4 (Curry_Prelude.d_OP_plus_plus
                                               x2 (Curry_Prelude.OP_Cons
                                               (Curry_Prelude.C_Char ' '#)
                                               (Curry_Prelude.d_C_unwords x3 cd
                                               cs)) cd cs) cd cs
  in Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
  (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 2#))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "Executing: ") x5
  cd cs) cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_System.d_C_system x5 cd cs)
  (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd cs) cd cs) cd cs

d_C_checkForCommand :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_checkForCommand x1 x2 x3 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_Prelude.d_OP_dollar Curry_System.d_C_system
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString "which ")
  (Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.toCurryString " > /dev/null")
  cd cs) cd cs) cd cs) (d_OP_checkForCommand_dot_uscore_hash_lambda1633 x3 x2)
  cd cs

nd_C_checkForCommand :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C_checkForCommand x1 x2 x3 s cd cs = let s2 = s
  in s2 `seq` (let s1 = leftSupply s2
                   s0 = rightSupply s2
  in s1 `seq` (s0 `seq` Curry_Prelude.nd_OP_gt_gt_eq (Curry_Prelude.nd_OP_dollar
  (wrapDX id Curry_System.d_C_system) (Curry_Prelude.d_OP_plus_plus
  (Curry_Prelude.toCurryString "which ") (Curry_Prelude.d_OP_plus_plus x1
  (Curry_Prelude.toCurryString " > /dev/null") cd cs) cd cs) s0 cd cs) (wrapNX
  id (nd_OP_checkForCommand_dot_uscore_hash_lambda1633 x3 x2)) s1 cd cs))

d_OP_checkForCommand_dot_uscore_hash_lambda1633 :: Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_checkForCommand_dot_uscore_hash_lambda1633 x1 x2 x3 cd cs = d_C__case_9 x3
  x1 x2 (Curry_Prelude.d_OP_gt x3 (Curry_Prelude.C_Int 0#) cd cs) cd cs

nd_OP_checkForCommand_dot_uscore_hash_lambda1633 :: Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Int -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_OP_checkForCommand_dot_uscore_hash_lambda1633 x1 x2 x3 s cd cs = let s0 = s
  in s0 `seq` nd_C__case_9 x3 x1 x2 (Curry_Prelude.d_OP_gt x3
  (Curry_Prelude.C_Int 0#) cd cs) s0 cd cs

d_C_checkForWish :: Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_checkForWish cd cs = d_C_checkForCommand (Curry_Prelude.toCurryString
  "wish") (Curry_Prelude.toCurryString
  "Windowing shell `wish' not found. Please install package `tk'!")

nd_C_checkForWish :: IDSupply -> Cover -> ConstStore -> Func (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))
nd_C_checkForWish s cd cs = wrapNX id (nd_C_checkForCommand
  (Curry_Prelude.toCurryString "wish") (Curry_Prelude.toCurryString
  "Windowing shell `wish' not found. Please install package `tk'!"))

d_C_readAndProcessSourceFileOptions :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_readAndProcessSourceFileOptions x1 x2 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (d_C_readSourceFileOptions x2 cd cs)
  (d_OP_readAndProcessSourceFileOptions_dot_uscore_hash_lambda1634 x1) cd cs

d_OP_readAndProcessSourceFileOptions_dot_uscore_hash_lambda1634 :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_readAndProcessSourceFileOptions_dot_uscore_hash_lambda1634 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar (Curry_Prelude.d_C_unless
  (Curry_Prelude.d_C_null x2 cd cs)) (Curry_Prelude.d_OP_dollar
  (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 1#))
  (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
  "Source file options: ") (Curry_List.d_C_intercalate
  (Curry_Prelude.toCurryString " | ") (Curry_Prelude.d_C_map
  Curry_Prelude.d_C_unwords x2 cd cs) cd cs) cd cs) cd cs) cd cs)
  (d_C_processSourceFileOptions x1 x2 cd cs) cd cs

d_C_processSourceFileOptions :: Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C_processSourceFileOptions x1 x2 cd cs = case x2 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd
    cs
  Curry_Prelude.OP_Cons x3 x4 -> Curry_Prelude.d_OP_gt_gt_eq
    (d_C_processSetOption x1 (Curry_Prelude.d_C_unwords x3 cd cs) cd cs)
    (Curry_Prelude.d_C_maybe (Curry_Prelude.d_C_return Curry_Prelude.C_Nothing
    cd cs) (d_OP_processSourceFileOptions_dot_uscore_hash_lambda1635 x4)) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_C_processSourceFileOptions x1 l cd cs) (d_C_processSourceFileOptions x1 r
    cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_C_processSourceFileOptions x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_C_processSourceFileOptions x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.processSourceFileOptions" [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL.processSourceFileOptions" (showCons x2))

d_OP_processSourceFileOptions_dot_uscore_hash_lambda1635 :: Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_OP_processSourceFileOptions_dot_uscore_hash_lambda1635 x1 x2 cd cs =
  d_C_processSourceFileOptions x2 x1 cd cs

d_C_readSourceFileOptions :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_C_readSourceFileOptions x1 cd cs = Curry_Prelude.d_OP_gt_gt_eq
  (Curry_IO.d_C_openFile x1 Curry_IO.C_ReadMode cd cs)
  d_OP_readSourceFileOptions_dot_uscore_hash_lambda1640 cd cs

d_OP_readSourceFileOptions_dot_isOptionComment_dot_636 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_readSourceFileOptions_dot_isOptionComment_dot_636 x1 cd cs =
  Curry_Prelude.d_OP_eq_eq (Curry_Prelude.d_C_take (Curry_Prelude.C_Int 3#) x1
  cd cs) (Curry_Prelude.toCurryString "{-#") cd cs

d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 x1 cd cs = case x1 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x2 x3 -> d_C__case_8 x2 x3 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i
    (d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 l cd cs)
    (d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z ->
    d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c
    (d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 e cd $! addCs c
    cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail
    "REPL.readSourceFileOptions.extractOptionString.636" [show x1] info)
  _ -> failCons cd (consFail
    "REPL.readSourceFileOptions.extractOptionString.636" (showCons x1))

d_OP_readSourceFileOptions_dot_getOptions_dot_636 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_OP_readSourceFileOptions_dot_getOptions_dot_636 x1 cd cs =
  let x2 = Curry_Prelude.d_C_words
        (d_OP_readSourceFileOptions_dot_extractOptionString_dot_636
        (Curry_Prelude.d_C_drop (Curry_Prelude.C_Int 3#) x1 cd cs) cd cs) cd cs
  in d_C__case_5 x2 (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_null x2 cd
  cs) (Curry_Prelude.d_OP_slash_eq (Curry_Prelude.d_C_map Curry_Char.d_C_toLower
  (Curry_Prelude.d_C_head x2 cd cs) cd cs) (Curry_Prelude.toCurryString
  "kics2_option") cd cs) cd cs) cd cs

d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636 :: Curry_IO.C_Handle
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636 x1 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq (Curry_IO.d_C_hIsEOF x1 cd cs)
  (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637
  x1) cd cs

d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_Bool
d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659 x1 cd cs =
  Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_elem
  (Curry_Prelude.d_C_take (Curry_Prelude.C_Int 6#) x1 cd cs) cd cs)
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "module")
  (Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString "import")
  Curry_Prelude.OP_List)) cd cs) (let x2 = Curry_Prelude.d_C_apply
                                        (Curry_Prelude.d_C_break
                                        Curry_Char.d_C_isSpace cd cs) x1 cd cs
                                      x3 = d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w
                                        x2 cd cs
  in Curry_Prelude.d_OP_amp_amp (Curry_Prelude.d_C_apply
  (Curry_Utils.d_C_notNull cd cs) x3 cd cs) (Curry_Prelude.d_C_apply
  (Curry_Prelude.d_C_all Curry_Char.d_C_isAlphaNum cd cs) x3 cd cs) cd cs) cd cs

d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w x1 cd cs =
  case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> x2
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w
    l cd cs)
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w
    r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w
    z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659_dot_uscore_hash_selFP36_hash_w
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.readSourceFileOptions.readHeaderLines.636.isModuleStart.659._#selFP36#w"
    [show x1] info)
  _ -> failCons cd (consFail
    "REPL.readSourceFileOptions.readHeaderLines.636.isModuleStart.659._#selFP36#w"
    (showCons x1))

d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637 :: Curry_IO.C_Handle
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637 x1 x2 cd cs =
  case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return Curry_Prelude.OP_List cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt_eq (Curry_IO.d_C_hGetLine x1
    cd cs)
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637_dot_uscore_hash_lambda1638
    x1) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637
    x1 l cd cs)
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637
    x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z ->
    d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637
    x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail
    "REPL.readSourceFileOptions.readHeaderLines.636._#lambda1637" [show x1, show
    x2] info)
  _ -> failCons cd (consFail
    "REPL.readSourceFileOptions.readHeaderLines.636._#lambda1637" (showCons x2))

d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637_dot_uscore_hash_lambda1638 :: Curry_IO.C_Handle
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637_dot_uscore_hash_lambda1638 x1 x2 cd cs =
  d_C__case_4 x2 x1
  (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_isModuleStart_dot_659
  x2 cd cs) cd cs

d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637_dot_uscore_hash_lambda1638_dot_uscore_hash_lambda1639 :: Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637_dot_uscore_hash_lambda1638_dot_uscore_hash_lambda1639 x1 x2 cd cs =
  Curry_Prelude.d_C_return (Curry_Prelude.OP_Cons (Curry_Prelude.d_C_apply
  (Curry_Utils.d_C_strip cd cs) x1 cd cs) x2) cd cs

d_OP_readSourceFileOptions_dot_uscore_hash_lambda1640 :: Curry_IO.C_Handle
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_OP_readSourceFileOptions_dot_uscore_hash_lambda1640 x1 cd cs =
  Curry_Prelude.d_OP_gt_gt_eq
  (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636 x1 cd cs)
  (d_OP_readSourceFileOptions_dot_uscore_hash_lambda1640_dot_uscore_hash_lambda1641
  x1) cd cs

d_OP_readSourceFileOptions_dot_uscore_hash_lambda1640_dot_uscore_hash_lambda1641 :: Curry_IO.C_Handle
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.OP_List
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)))
d_OP_readSourceFileOptions_dot_uscore_hash_lambda1640_dot_uscore_hash_lambda1641 x1 x2 cd cs =
  Curry_Prelude.d_OP_gt_gt (Curry_IO.d_C_hClose x1 cd cs)
  (Curry_Prelude.d_C_return (Curry_Prelude.d_C_filter (Curry_Utils.d_C_notNull
  cd cs) (Curry_Prelude.d_C_map
  d_OP_readSourceFileOptions_dot_getOptions_dot_636 (Curry_Prelude.d_C_filter
  d_OP_readSourceFileOptions_dot_isOptionComment_dot_636 x2 cd cs) cd cs) cd cs)
  cd cs) cd cs

d_C_terminateSourceProgGUIs :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_C_terminateSourceProgGUIs x1 cd cs = let x2 = Curry_Linker.d_C_sourceguis x1
                                             cd cs
  in d_C__case_3 x2 x1 (Curry_Prelude.d_C_null x2 cd cs) cd cs

d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 :: Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) Curry_IO.C_Handle) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 x1 cd cs = case x1 of
  Curry_Prelude.OP_Tuple2 x2 x3 -> d_C__case_0 x3 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i
    (d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 l cd cs)
    (d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z ->
    d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c
    (d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail
    "REPL.terminateSourceProgGUIs._#lambda1642" [show x1] info)
  _ -> failCons cd (consFail "REPL.terminateSourceProgGUIs._#lambda1642"
    (showCons x1))

d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1643 :: Curry_Prelude.C_IOError
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1643 x1 cd cs =
  Curry_Prelude.d_C_done cd cs

d_C__case_0 :: Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) Curry_IO.C_Handle -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_0 x3 cd cs = case x3 of
  Curry_Prelude.OP_Tuple2 x4 x5 -> Curry_Prelude.d_OP_gt_gt
    (Curry_Prelude.d_OP_gt_gt (Curry_IO.d_C_hPutStrLn x5
    (Curry_Prelude.toCurryString "q") cd cs) (Curry_IO.d_C_hFlush x5 cd cs) cd
    cs) (Curry_IO.d_C_hClose x5 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_0 l cd cs)
    (d_C__case_0 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_0 z
    cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_0 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_0"
    [show x3] info)
  _ -> failCons cd (consFail "REPL._case_0" (showCons x3))

d_C__case_3 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) Curry_IO.C_Handle))
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_C__case_3 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return x1 cd cs
  Curry_Prelude.C_False -> d_C__case_2 x1 x2 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_3 x2 x1 l cd cs)
    (d_C__case_3 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_3 x2 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_3 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_3" [show
    x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_3" (showCons x3))

d_C__case_2 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  Curry_IO.C_Handle)) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_C__case_2 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt
    (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 1#)
    (Curry_Prelude.toCurryString "Terminating source program GUIs...") cd cs)
    (Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_catch (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_mapIO_
    d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1642 cd cs) x2 cd cs)
    d_OP_terminateSourceProgGUIs_dot_uscore_hash_lambda1643 cd cs)
    (Curry_Prelude.d_C_return (d_C__case_1 x1 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_2 x1 x2 l cd cs)
    (d_C__case_2 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_2 x1 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_2 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_2" [show
    x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_2" (showCons x3))

d_C__case_1 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_1 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x29 x30 x31 Curry_Prelude.OP_List x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_1 l cd cs)
    (d_C__case_1 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_1 z
    cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_1 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_1"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_1" (showCons x1))

d_C__case_4 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_IO.C_Handle
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char))
d_C__case_4 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return Curry_Prelude.OP_List cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt_eq
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636 x1 cd cs)
    (d_OP_readSourceFileOptions_dot_readHeaderLines_dot_636_dot_uscore_hash_lambda1637_dot_uscore_hash_lambda1638_dot_uscore_hash_lambda1639
    x2) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_4 x2 x1 l cd cs)
    (d_C__case_4 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_4 x2 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_4 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_4" [show
    x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_4" (showCons x3))

d_C__case_5 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_5 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_C_tail x2 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_5 x2 l cd cs)
    (d_C__case_5 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_5 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_5 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_5" [show
    x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_5" (showCons x3))

d_C__case_8 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_8 x2 x3 cd cs = case x3 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x4 x5 -> d_C__case_7 x3 x2 x5 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_8 x2 l cd cs)
    (d_C__case_8 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_8 x2 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_8 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_8"
    [show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_8" (showCons x3))

d_C__case_7 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_7 x3 x2 x5 cd cs = case x5 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x6 x7 -> d_C__case_6 x3 x2 (Curry_Prelude.d_OP_eq_eq
    (Curry_Prelude.OP_Cons x2 (Curry_Prelude.d_C_take (Curry_Prelude.C_Int 2#)
    x3 cd cs)) (Curry_Prelude.toCurryString "#-}") cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_7 x3 x2 l cd cs)
    (d_C__case_7 x3 x2 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_7 x3
    x2 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_7 x3 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_7"
    [show x3, show x2, show x5] info)
  _ -> failCons cd (consFail "REPL._case_7" (showCons x5))

d_C__case_6 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_6 x3 x2 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.OP_Cons x2
    (d_OP_readSourceFileOptions_dot_extractOptionString_dot_636 x3 cd cs)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_6 x3 x2 l cd cs)
    (d_C__case_6 x3 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_6 x3 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_6 x3 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_6" [show
    x3, show x2, show x4] info)
  _ -> failCons cd (consFail "REPL._case_6" (showCons x4))

d_C__case_9 :: Curry_Prelude.C_Int -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_9 x3 x1 x2 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> d_C_skipCommand x2 cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_9 x3 x1 x2 l cd
    cs) (d_C__case_9 x3 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_9 x3 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_9 x3 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_9" [show
    x3, show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "REPL._case_9" (showCons x4))

nd_C__case_9 :: Curry_Prelude.C_Int -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_9 x3 x1 x2 x4 s cd cs = case x4 of
  Curry_Prelude.C_True -> d_C_skipCommand x2 cd cs
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_9 x3 x1 x2 l s
    cd cs) (nd_C__case_9 x3 x1 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_9 x3
    x1 x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_9 x3 x1 x2 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_9" [show
    x3, show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "REPL._case_9" (showCons x4))

d_C__case_10 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> (Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_10 x4 x3 x2 x1 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_apply x1 x3 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_Directory.d_C_getHomeDirectory cd cs)
    (d_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631
    x1 x2 x3) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_10 x4 x3 x2 x1 l
    cd cs) (d_C__case_10 x4 x3 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_10 x4
    x3 x2 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_10 x4 x3 x2 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_10"
    [show x4, show x3, show x2, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_10" (showCons x5))

nd_C__case_10 :: Curry_Prelude.C_Int -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_10 x4 x3 x2 x1 x5 s cd cs = case x5 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_C_apply x1 x3 s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt_eq
    (Curry_Directory.d_C_getHomeDirectory cd cs) (wrapNX id
    (nd_OP_checkAndCallCpmTool_dot_uscore_hash_lambda1630_dot_uscore_hash_lambda1631
    x1 x2 x3)) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_10 x4 x3 x2 x1 l
    s cd cs) (nd_C__case_10 x4 x3 x2 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_10 x4
    x3 x2 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_10 x4 x3 x2 x1 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_10"
    [show x4, show x3, show x2, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_10" (showCons x5))

d_C__case_11 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_11 x1 x2 x3 cd cs = case x3 of
  Curry_Linker.C_ReplState x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 x36 x37 -> Curry_Linker.C_ReplState
    x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26
    x27 x28 x29 x30 x31 x32 x33 x34 x35
    (d_OP_showFunctionInModule_dot_updateFun_dot_590
    (Curry_Linker.d_C_sourceguis x3 cd cs) x2 x1 cd cs) x37
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_11 x1 x2 l cd
    cs) (d_C__case_11 x1 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_11
    x1 x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_11 x1 x2 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_11"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_11" (showCons x3))

d_C__case_12 :: Curry_IO.C_Handle -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_12 x4 x1 x2 x3 cd cs = case x3 of
  Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 -> Curry_Linker.C_ReplState
    x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24
    x25 x26 x27 x28 x29 x30 x31 x32 x33 (Curry_Prelude.OP_Cons
    (Curry_Prelude.OP_Tuple2 x2 (Curry_Prelude.OP_Tuple2 x1 x4))
    (Curry_Linker.d_C_sourceguis x3 cd cs)) x35
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_12 x4 x1 x2 l
    cd cs) (d_C__case_12 x4 x1 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_12
    x4 x1 x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_12 x4 x1 x2 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_12"
    [show x4, show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_12" (showCons x3))

d_C__case_15 :: forall t0 t1 t2 . (Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1, Curry_Prelude.Curry t2) => t0 -> t1 -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2 t1 t2))
  -> Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2 t1 t2) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 t0
  (Curry_Prelude.OP_Tuple2 t1 t2))
d_C__case_15 x2 x3 x5 x4 cd cs = case x4 of
  Curry_Prelude.OP_Tuple2 x6 x7 -> d_C__case_14 x2 x6 x3 x5 x7 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_15 x2 x3 x5 l
    cd cs) (d_C__case_15 x2 x3 x5 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_15
    x2 x3 x5 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_15 x2 x3 x5 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_15"
    [show x2, show x3, show x5, show x4] info)
  _ -> failCons cd (consFail "REPL._case_15" (showCons x4))

d_C__case_14 :: forall t0 t1 t2 . (Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1, Curry_Prelude.Curry t2) => t0 -> t0 -> t1 -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2 t1 t2))
  -> Curry_Prelude.OP_Tuple2 t1 t2 -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2
  t1 t2))
d_C__case_14 x2 x6 x3 x5 x7 cd cs = case x7 of
  Curry_Prelude.OP_Tuple2 x8 x9 -> d_C__case_13 x2 x6 x3 x5 x9 x8
    (Curry_Prelude.d_OP_eq_eq x6 x2 cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_14 x2 x6 x3 x5
    l cd cs) (d_C__case_14 x2 x6 x3 x5 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_14
    x2 x6 x3 x5 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_14 x2 x6 x3 x5
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_14"
    [show x2, show x6, show x3, show x5, show x7] info)
  _ -> failCons cd (consFail "REPL._case_14" (showCons x7))

d_C__case_13 :: forall t0 t1 t2 . (Curry_Prelude.Curry t0, Curry_Prelude.Curry
  t1, Curry_Prelude.Curry t2) => t0 -> t0 -> t1 -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2 t1 t2)) -> t2 -> t1
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 t0 (Curry_Prelude.OP_Tuple2 t1 t2))
d_C__case_13 x2 x6 x3 x5 x9 x8 x10 cd cs = case x10 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 x6
    (Curry_Prelude.OP_Tuple2 x3 x9)) x5
  Curry_Prelude.C_False -> Curry_Prelude.OP_Cons (Curry_Prelude.OP_Tuple2 x6
    (Curry_Prelude.OP_Tuple2 x8 x9))
    (d_OP_showFunctionInModule_dot_updateFun_dot_590 x5 x2 x3 cd cs)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_13 x2 x6 x3 x5 x9
    x8 l cd cs) (d_C__case_13 x2 x6 x3 x5 x9 x8 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_13 x2
    x6 x3 x5 x9 x8 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_13 x2 x6 x3 x5 x9
    x8 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_13"
    [show x2, show x6, show x3, show x5, show x9, show x8, show x10] info)
  _ -> failCons cd (consFail "REPL._case_13" (showCons x10))

d_C__case_16 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C__case_16 x3 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons x3 Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_16 x3 x4 l cd cs)
    (d_C__case_16 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_16 x3
    x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_16 x3 x4 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_16"
    [show x3, show x4, show x5] info)
  _ -> failCons cd (consFail "REPL._case_16" (showCons x5))

d_C__case_17 :: Curry_Linker.C_ReplState -> Curry_Linker.C_NonDetMode -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_17 x1 x5 cd cs = case x5 of
  Curry_Linker.C_PrDFS -> Curry_Prelude.toCurryString
    "primitive non-monadic depth-first search"
  Curry_Linker.C_DEBUG -> Curry_Prelude.toCurryString
    "debugging information for search"
  Curry_Linker.C_PrtChoices x2 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "show choice tree structure up to level ")
    (Curry_Prelude.d_C_show x2 cd cs) cd cs
  Curry_Linker.C_DFS -> Curry_Prelude.toCurryString "depth-first search"
  Curry_Linker.C_BFS -> Curry_Prelude.toCurryString "breadth-first search"
  Curry_Linker.C_IDS x3 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "iterative deepening (initial depth: ")
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_show x3 cd cs)
    (Curry_Prelude.toCurryString ")") cd cs) cd cs
  Curry_Linker.C_Par x4 -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "parallel search with ")
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_show x4 cd cs)
    (Curry_Prelude.toCurryString " threads") cd cs) cd cs
  Curry_Linker.Choice_C_NonDetMode d i l r -> narrow d i (d_C__case_17 x1 l cd
    cs) (d_C__case_17 x1 r cd cs)
  Curry_Linker.Choices_C_NonDetMode d i xs -> narrows cs d i (\z -> d_C__case_17
    x1 z cd cs) xs
  Curry_Linker.Guard_C_NonDetMode d c e -> guardCons d c (d_C__case_17 x1 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_NonDetMode d info -> failCons d (traceFail "REPL._case_17"
    [show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_17" (showCons x5))

d_C__case_18 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_18 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_18 x1 l cd cs)
    (d_C__case_18 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_18 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_18 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_18"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_18" (showCons x2))

d_C__case_19 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_19 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> x2
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_19 x1 x2 l cd cs)
    (d_C__case_19 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_19 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_19 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_19"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_19" (showCons x3))

d_C__case_22 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_22 x3 x2 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (d_C__case_21 x2 x1 cd cs)) cd cs
  Curry_Prelude.C_False -> d_C__case_20 (Curry_Prelude.d_C_otherwise cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_22 x3 x2 x1 l cd
    cs) (d_C__case_22 x3 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_22 x3
    x2 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_22 x3 x2 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_22"
    [show x3, show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_22" (showCons x4))

d_C__case_20 :: Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_20 x1 cd cs = case x1 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "unknown identifier supply") cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_20 l cd cs)
    (d_C__case_20 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_20 z cd
    cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_20 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_20"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_20" (showCons x1))

d_C__case_21 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_21 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 -> Curry_Linker.C_ReplState
    x4 x5 x2 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_21 x2 l cd
    cs) (d_C__case_21 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_21
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_21 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_21"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_21" (showCons x1))

d_C__case_29 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> (Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Linker.C_NonDetMode) -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_29 x4 x3 x1 x2 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (d_C__case_28 x2 x1 x3 cd cs)) cd cs
  Curry_Prelude.C_False -> d_C__case_27 x4 x3 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_29 x4 x3 x1 x2 l
    cd cs) (d_C__case_29 x4 x3 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_29 x4
    x3 x1 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_29 x4 x3 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_29"
    [show x4, show x3, show x1, show x2, show x5] info)
  _ -> failCons cd (consFail "REPL._case_29" (showCons x5))

nd_C__case_29 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Prelude.C_Int -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_29 x4 x3 x1 x2 x5 s cd cs = case x5 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.d_C_return (Curry_Prelude.C_Just (nd_C__case_28 x2
    x1 x3 s0 cd cs)) cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_27 x4 x3 x1 (Curry_Prelude.d_C_otherwise cd cs) s0 cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_29 x4 x3 x1 x2 l
    s cd cs) (nd_C__case_29 x4 x3 x1 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_29 x4
    x3 x1 x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_29 x4 x3 x1 x2 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_29"
    [show x4, show x3, show x1, show x2, show x5] info)
  _ -> failCons cd (consFail "REPL._case_29" (showCons x5))

d_C__case_27 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> (Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Linker.C_NonDetMode) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_27 x4 x3 x1 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> d_C__case_26 x4 x3 x1 (Curry_ReadNumeric.d_C_readNat
    x4 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_27 x4 x3 x1 l cd
    cs) (d_C__case_27 x4 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_27 x4
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_27 x4 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_27"
    [show x4, show x3, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_27" (showCons x5))

nd_C__case_27 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_27 x4 x3 x1 x5 s cd cs = case x5 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C__case_26 x4 x3 x1 (Curry_ReadNumeric.d_C_readNat x4 cd cs)
    s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_27 x4 x3 x1 l s
    cd cs) (nd_C__case_27 x4 x3 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_27 x4
    x3 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_27 x4 x3 x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_27"
    [show x4, show x3, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_27" (showCons x5))

d_C__case_26 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> (Curry_Prelude.C_Int -> Cover -> ConstStore
  -> Curry_Linker.C_NonDetMode) -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_26 x4 x3 x1 x37 cd cs = case x37 of
  Curry_Prelude.C_Nothing -> d_C_skipCommand (Curry_Prelude.toCurryString
    "illegal number") cd cs
  Curry_Prelude.C_Just x36 -> d_C__case_25 x3 x1 x36 cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i (d_C__case_26 x4 x3 x1 l cd
    cs) (d_C__case_26 x4 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z -> d_C__case_26 x4
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c (d_C__case_26 x4 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail "REPL._case_26"
    [show x4, show x3, show x1, show x37] info)
  _ -> failCons cd (consFail "REPL._case_26" (showCons x37))

nd_C__case_26 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Prelude.C_Maybe (Curry_Prelude.OP_Tuple2
  Curry_Prelude.C_Int (Curry_Prelude.OP_List Curry_Prelude.C_Char)) -> IDSupply
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_26 x4 x3 x1 x37 s cd cs = case x37 of
  Curry_Prelude.C_Nothing -> d_C_skipCommand (Curry_Prelude.toCurryString
    "illegal number") cd cs
  Curry_Prelude.C_Just x36 -> let s0 = s
    in s0 `seq` nd_C__case_25 x3 x1 x36 s0 cd cs
  Curry_Prelude.Choice_C_Maybe d i l r -> narrow d i (nd_C__case_26 x4 x3 x1 l s
    cd cs) (nd_C__case_26 x4 x3 x1 r s cd cs)
  Curry_Prelude.Choices_C_Maybe d i xs -> narrows cs d i (\z -> nd_C__case_26 x4
    x3 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Maybe d c e -> guardCons d c (nd_C__case_26 x4 x3 x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Maybe d info -> failCons d (traceFail "REPL._case_26"
    [show x4, show x3, show x1, show x37] info)
  _ -> failCons cd (consFail "REPL._case_26" (showCons x37))

d_C__case_25 :: Curry_Linker.C_ReplState -> (Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Linker.C_NonDetMode) -> Curry_Prelude.OP_Tuple2
  Curry_Prelude.C_Int (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_25 x3 x1 x36 cd cs = case x36 of
  Curry_Prelude.OP_Tuple2 x37 x38 -> d_C__case_24 x38 x3 x37 x1
    (Curry_Prelude.d_C_null (Curry_Prelude.d_C_apply (Curry_Utils.d_C_strip cd
    cs) x38 cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_25 x3 x1 l cd
    cs) (d_C__case_25 x3 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_25
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_25 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_25"
    [show x3, show x1, show x36] info)
  _ -> failCons cd (consFail "REPL._case_25" (showCons x36))

nd_C__case_25 :: Curry_Linker.C_ReplState -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Prelude.OP_Tuple2 Curry_Prelude.C_Int
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_25 x3 x1 x36 s cd cs = case x36 of
  Curry_Prelude.OP_Tuple2 x37 x38 -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C__case_24 x38 x3 x37 x1 (Curry_Prelude.d_C_null
    (Curry_Prelude.nd_C_apply (wrapDX id (Curry_Utils.d_C_strip cd cs)) x38 s0
    cd cs) cd cs) s1 cd cs))
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_25 x3 x1 l s
    cd cs) (nd_C__case_25 x3 x1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_25
    x3 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_25 x3 x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_25"
    [show x3, show x1, show x36] info)
  _ -> failCons cd (consFail "REPL._case_25" (showCons x36))

d_C__case_24 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Int -> (Curry_Prelude.C_Int
  -> Cover -> ConstStore -> Curry_Linker.C_NonDetMode) -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_24 x38 x3 x37 x1 x39 cd cs = case x39 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (d_C__case_23 x37 x1 x3 cd cs)) cd cs
  Curry_Prelude.C_False -> d_C_skipCommand (Curry_Prelude.toCurryString
    "illegal number") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_24 x38 x3 x37 x1
    l cd cs) (d_C__case_24 x38 x3 x37 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_24 x38
    x3 x37 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_24 x38 x3 x37 x1
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_24"
    [show x38, show x3, show x37, show x1, show x39] info)
  _ -> failCons cd (consFail "REPL._case_24" (showCons x39))

nd_C__case_24 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Int -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_24 x38 x3 x37 x1 x39 s cd cs = case x39 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.d_C_return (Curry_Prelude.C_Just (nd_C__case_23
    x37 x1 x3 s0 cd cs)) cd cs
  Curry_Prelude.C_False -> d_C_skipCommand (Curry_Prelude.toCurryString
    "illegal number") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_24 x38 x3 x37 x1
    l s cd cs) (nd_C__case_24 x38 x3 x37 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_24 x38
    x3 x37 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_24 x38 x3 x37 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_24"
    [show x38, show x3, show x37, show x1, show x39] info)
  _ -> failCons cd (consFail "REPL._case_24" (showCons x39))

d_C__case_23 :: Curry_Prelude.C_Int -> (Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Linker.C_NonDetMode) -> Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_23 x37 x1 x3 cd cs = case x3 of
  Curry_Linker.C_ReplState x39 x40 x41 x42 x43 x44 x45 x46 x47 x48 x49 x50 x51 x52 x53 x54 x55 x56 x57 x58 x59 x60 x61 x62 x63 x64 x65 x66 x67 x68 x69 -> Curry_Linker.C_ReplState
    x39 x40 x41 x42 x43 x44 x45 x46 x47 x48 x49 x50 x51 (Curry_Prelude.d_C_apply
    x1 x37 cd cs) x53 x54 x55 x56 x57 x58 x59 x60 x61 x62 x63 x64 x65 x66 x67
    x68 x69
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_23 x37 x1 l
    cd cs) (d_C__case_23 x37 x1 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_23
    x37 x1 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_23 x37 x1 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_23"
    [show x37, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_23" (showCons x3))

nd_C__case_23 :: Curry_Prelude.C_Int -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Linker.C_ReplState -> IDSupply -> Cover
  -> ConstStore -> Curry_Linker.C_ReplState
nd_C__case_23 x37 x1 x3 s cd cs = case x3 of
  Curry_Linker.C_ReplState x39 x40 x41 x42 x43 x44 x45 x46 x47 x48 x49 x50 x51 x52 x53 x54 x55 x56 x57 x58 x59 x60 x61 x62 x63 x64 x65 x66 x67 x68 x69 -> let s0 = s
    in s0 `seq` Curry_Linker.C_ReplState x39 x40 x41 x42 x43 x44 x45 x46 x47 x48
    x49 x50 x51 (Curry_Prelude.nd_C_apply x1 x37 s0 cd cs) x53 x54 x55 x56 x57
    x58 x59 x60 x61 x62 x63 x64 x65 x66 x67 x68 x69
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (nd_C__case_23 x37 x1 l
    s cd cs) (nd_C__case_23 x37 x1 r s cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> nd_C__case_23
    x37 x1 z s cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (nd_C__case_23 x37 x1 e
    s cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_23"
    [show x37, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_23" (showCons x3))

d_C__case_28 :: Curry_Prelude.C_Int -> (Curry_Prelude.C_Int -> Cover
  -> ConstStore -> Curry_Linker.C_NonDetMode) -> Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_28 x2 x1 x3 cd cs = case x3 of
  Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 -> Curry_Linker.C_ReplState
    x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 (Curry_Prelude.d_C_apply x1
    x2 cd cs) x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34
    x35
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_28 x2 x1 l cd
    cs) (d_C__case_28 x2 x1 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_28
    x2 x1 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_28 x2 x1 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_28"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_28" (showCons x3))

nd_C__case_28 :: Curry_Prelude.C_Int -> Func Curry_Prelude.C_Int
  Curry_Linker.C_NonDetMode -> Curry_Linker.C_ReplState -> IDSupply -> Cover
  -> ConstStore -> Curry_Linker.C_ReplState
nd_C__case_28 x2 x1 x3 s cd cs = case x3 of
  Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 -> let s0 = s
    in s0 `seq` Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15
    x16 x17 (Curry_Prelude.nd_C_apply x1 x2 s0 cd cs) x19 x20 x21 x22 x23 x24
    x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (nd_C__case_28 x2 x1 l s
    cd cs) (nd_C__case_28 x2 x1 r s cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> nd_C__case_28
    x2 x1 z s cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (nd_C__case_28 x2 x1 e s
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_28"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_28" (showCons x3))

d_C__case_30 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_30 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x2 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_30 x2 l cd
    cs) (d_C__case_30 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_30
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_30 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_30"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_30" (showCons x1))

d_C__case_31 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char))
d_C__case_31 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_defaultImportPaths x1 cd cs
  Curry_Prelude.C_False -> d_C_defaultImportPathsWith x1 x2 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_31 x2 x1 l cd cs)
    (d_C__case_31 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_31 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_31 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_31"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_31" (showCons x3))

d_C__case_32 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_32 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22
    Curry_Prelude.C_False x24 x25 x26 x27 x28 x29 x30 x31 x32
    Curry_Prelude.C_Nothing
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_32 l cd cs)
    (d_C__case_32 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_32
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_32 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_32"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_32" (showCons x1))

d_C__case_41 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_41 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "no prompt specified") cd cs
  Curry_Prelude.C_False -> d_C__case_40 x3 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_41 x3 x1 l cd cs)
    (d_C__case_41 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_41 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_41 x3 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_41"
    [show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_41" (showCons x4))

d_C__case_40 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_40 x3 x1 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> let x4 = Curry_Prelude.d_C_head x3 cd cs
    in d_C__case_39 x4 x1 x3 (Curry_Prelude.d_OP_eq_eq x4 (Curry_Prelude.C_Char
    '"'#) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_40 x3 x1 l cd cs)
    (d_C__case_40 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_40 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_40 x3 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_40"
    [show x3, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_40" (showCons x5))

d_C__case_39 :: Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_39 x4 x1 x3 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> d_C__case_38 x3 x1 (Curry_ReadShowTerm.d_C_readsTerm
    x3 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (d_C__case_33 x3 x1 cd cs)) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_39 x4 x1 x3 l cd
    cs) (d_C__case_39 x4 x1 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_39 x4
    x1 x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_39 x4 x1 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_39"
    [show x4, show x1, show x3, show x5] info)
  _ -> failCons cd (consFail "REPL._case_39" (showCons x5))

d_C__case_33 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_33 x3 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x44 x45 x46 x47 x48 x49 x50 x51 x52 x53 x54 x55 x56 x57 x58 x59 x60 x61 x62 x63 x64 x65 x66 x67 x68 x69 x70 x71 x72 x73 x74 -> Curry_Linker.C_ReplState
    x44 x45 x46 x47 x48 x49 x50 x51 x52 x53 x54 x3 x56 x57 x58 x59 x60 x61 x62
    x63 x64 x65 x66 x67 x68 x69 x70 x71 x72 x73 x74
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_33 x3 l cd
    cs) (d_C__case_33 x3 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_33
    x3 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_33 x3 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_33"
    [show x3, show x1] info)
  _ -> failCons cd (consFail "REPL._case_33" (showCons x1))

d_C__case_38 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_38 x3 x1 x7 cd cs = case x7 of
  Curry_Prelude.OP_Cons x5 x6 -> d_C__case_37 x6 x1 x5 cd cs
  Curry_Prelude.OP_List -> d_C_skipCommand (Curry_Prelude.toCurryString
    "could not parse prompt") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_38 x3 x1 l cd
    cs) (d_C__case_38 x3 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_38 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_38 x3 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_38"
    [show x3, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_38" (showCons x7))

d_C__case_37 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_37 x6 x1 x5 cd cs = case x5 of
  Curry_Prelude.OP_Tuple2 x7 x8 -> d_C__case_36 x6 x1 x7 x8 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_37 x6 x1 l cd
    cs) (d_C__case_37 x6 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_37
    x6 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_37 x6 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_37"
    [show x6, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_37" (showCons x5))

d_C__case_36 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_36 x6 x1 x7 x8 cd cs = case x8 of
  Curry_Prelude.OP_List -> d_C__case_35 x1 x7 x6 cd cs
  Curry_Prelude.OP_Cons x42 x43 -> d_C_skipCommand (Curry_Prelude.toCurryString
    "could not parse prompt") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_36 x6 x1 x7 l cd
    cs) (d_C__case_36 x6 x1 x7 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_36 x6
    x1 x7 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_36 x6 x1 x7 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_36"
    [show x6, show x1, show x7, show x8] info)
  _ -> failCons cd (consFail "REPL._case_36" (showCons x8))

d_C__case_35 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_35 x1 x7 x6 cd cs = case x6 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just
    (d_C__case_34 x7 x1 cd cs)) cd cs
  Curry_Prelude.OP_Cons x40 x41 -> d_C_skipCommand (Curry_Prelude.toCurryString
    "could not parse prompt") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_35 x1 x7 l cd
    cs) (d_C__case_35 x1 x7 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_35 x1
    x7 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_35 x1 x7 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_35"
    [show x1, show x7, show x6] info)
  _ -> failCons cd (consFail "REPL._case_35" (showCons x6))

d_C__case_34 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_34 x7 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 x36 x37 x38 x39 -> Curry_Linker.C_ReplState
    x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x7 x21 x22 x23 x24 x25 x26 x27
    x28 x29 x30 x31 x32 x33 x34 x35 x36 x37 x38 x39
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_34 x7 l cd
    cs) (d_C__case_34 x7 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_34
    x7 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_34 x7 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_34"
    [show x7, show x1] info)
  _ -> failCons cd (consFail "REPL._case_34" (showCons x1))

d_C__case_42 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_42 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 -> Curry_Linker.C_ReplState
    x5 x6 x7 x8 x9 x10 Curry_Prelude.C_True x12 x13 x14 x15 x16 x17 x18 x19 x20
    x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_42 l cd cs)
    (d_C__case_42 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_42
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_42 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_42"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_42" (showCons x1))

d_C__case_43 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_43 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x2 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_43 x2 l cd
    cs) (d_C__case_43 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_43
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_43 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_43"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_43" (showCons x1))

d_C__case_44 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_44 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x2 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_44 x2 l cd
    cs) (d_C__case_44 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_44
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_44 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_44"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_44" (showCons x1))

d_C__case_45 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_45 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x2 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_45 x2 l cd
    cs) (d_C__case_45 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_45
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_45 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_45"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_45" (showCons x1))

d_C__case_46 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_46 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x2 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_46 x2 l cd
    cs) (d_C__case_46 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_46
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_46 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_46"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_46" (showCons x1))

d_C__case_47 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_47 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x2 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_47 x2 l cd
    cs) (d_C__case_47 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_47
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_47 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_47"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_47" (showCons x1))

d_C__case_48 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_48 x2 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x2 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_48 x2 l cd
    cs) (d_C__case_48 x2 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_48
    x2 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_48 x2 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_48"
    [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_48" (showCons x1))

d_C__case_49 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_49 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    Curry_Prelude.C_True x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_49 l cd cs)
    (d_C__case_49 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_49
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_49 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_49"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_49" (showCons x1))

d_C__case_50 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_50 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22
    Curry_Prelude.C_True x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_50 l cd cs)
    (d_C__case_50 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_50
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_50 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_50"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_50" (showCons x1))

d_C__case_51 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_51 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 Curry_Prelude.C_False x10 x11 x12 x13 x14 x15 x16 x17 x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_51 l cd cs)
    (d_C__case_51 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_51
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_51 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_51"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_51" (showCons x1))

d_C__case_52 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_52 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21
    Curry_Prelude.C_False x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_52 l cd cs)
    (d_C__case_52 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_52
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_52 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_52"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_52" (showCons x1))

d_C__case_53 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_53 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21
    Curry_Prelude.C_True x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_53 l cd cs)
    (d_C__case_53 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_53
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_53 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_53"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_53" (showCons x1))

d_C__case_54 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_54 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20
    Curry_Prelude.C_False x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_54 l cd cs)
    (d_C__case_54 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_54
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_54 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_54"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_54" (showCons x1))

d_C__case_55 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_55 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20
    Curry_Prelude.C_True x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_55 l cd cs)
    (d_C__case_55 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_55
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_55 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_55"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_55" (showCons x1))

d_C__case_56 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_56 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19
    Curry_Prelude.C_False x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_56 l cd cs)
    (d_C__case_56 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_56
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_56 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_56"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_56" (showCons x1))

d_C__case_57 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_57 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19
    Curry_Prelude.C_True x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_57 l cd cs)
    (d_C__case_57 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_57
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_57 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_57"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_57" (showCons x1))

d_C__case_58 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_58 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18
    Curry_Prelude.C_False x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32
    x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_58 l cd cs)
    (d_C__case_58 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_58
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_58 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_58"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_58" (showCons x1))

d_C__case_59 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_59 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18
    Curry_Prelude.C_True x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_59 l cd cs)
    (d_C__case_59 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_59
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_59 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_59"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_59" (showCons x1))

d_C__case_60 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_60 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 Curry_Prelude.C_False x16 x17 x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_60 l cd cs)
    (d_C__case_60 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_60
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_60 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_60"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_60" (showCons x1))

d_C__case_61 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_61 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 Curry_Prelude.C_True x16 x17 x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_61 l cd cs)
    (d_C__case_61 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_61
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_61 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_61"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_61" (showCons x1))

d_C__case_62 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_62 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 Curry_Prelude.C_False x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_62 l cd cs)
    (d_C__case_62 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_62
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_62 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_62"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_62" (showCons x1))

d_C__case_63 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_63 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 Curry_Prelude.C_True x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_63 l cd cs)
    (d_C__case_63 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_63
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_63 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_63"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_63" (showCons x1))

d_C__case_64 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_64 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 Curry_Prelude.C_False
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_64 l cd cs)
    (d_C__case_64 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_64
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_64 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_64"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_64" (showCons x1))

d_C__case_65 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_65 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 Curry_Prelude.C_True
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_65 l cd cs)
    (d_C__case_65 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_65
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_65 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_65"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_65" (showCons x1))

d_C__case_66 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_66 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 (Curry_Prelude.C_Int 4#) x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17
    x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_66 l cd cs)
    (d_C__case_66 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_66
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_66 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_66"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_66" (showCons x1))

d_C__case_67 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_67 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 (Curry_Prelude.C_Int 3#) x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17
    x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_67 l cd cs)
    (d_C__case_67 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_67
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_67 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_67"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_67" (showCons x1))

d_C__case_68 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_68 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 (Curry_Prelude.C_Int 2#) x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17
    x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_68 l cd cs)
    (d_C__case_68 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_68
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_68 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_68"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_68" (showCons x1))

d_C__case_69 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_69 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 (Curry_Prelude.C_Int 1#) x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17
    x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_69 l cd cs)
    (d_C__case_69 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_69
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_69 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_69"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_69" (showCons x1))

d_C__case_70 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_70 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 (Curry_Prelude.C_Int 0#) x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17
    x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_70 l cd cs)
    (d_C__case_70 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_70
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_70 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_70"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_70" (showCons x1))

d_C__case_71 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_71 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 Curry_Linker.C_DEBUG x17 x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_71 l cd cs)
    (d_C__case_71 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_71
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_71 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_71"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_71" (showCons x1))

d_C__case_72 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_72 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 Curry_Linker.C_PrDFS x17 x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_72 l cd cs)
    (d_C__case_72 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_72
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_72 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_72"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_72" (showCons x1))

d_C__case_73 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_73 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 Curry_Linker.C_DFS x17 x18 x19
    x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_73 l cd cs)
    (d_C__case_73 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_73
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_73 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_73"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_73" (showCons x1))

d_C__case_74 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_74 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 Curry_Linker.C_BFS x17 x18 x19
    x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_74 l cd cs)
    (d_C__case_74 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_74
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_74 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_74"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_74" (showCons x1))

d_C__case_79 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_79 x2 x6 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_printOptions x1 cd cs)
    (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_78 x6 x2 x5 x1 (Curry_Prelude.d_C_otherwise
    cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_79 x2 x6 x5 x1 l
    cd cs) (d_C__case_79 x2 x6 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_79 x2
    x6 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_79 x2 x6 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_79"
    [show x2, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_79" (showCons x7))

nd_C__case_79 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_79 x2 x6 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt (d_C_printOptions x1 cd cs)
    (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd cs) s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_78 x6 x2 x5 x1 (Curry_Prelude.d_C_otherwise cd cs) s0
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_79 x2 x6 x5 x1 l
    s cd cs) (nd_C__case_79 x2 x6 x5 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_79 x2
    x6 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_79 x2 x6 x5 x1 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_79"
    [show x2, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_79" (showCons x7))

d_C__case_78 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_78 x6 x2 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C__case_77 x2 x5 x1 x6 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_78 x6 x2 x5 x1 l
    cd cs) (d_C__case_78 x6 x2 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_78 x6
    x2 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_78 x6 x2 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_78"
    [show x6, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_78" (showCons x7))

nd_C__case_78 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState
  (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_78 x6 x2 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C__case_77 x2 x5 x1 x6 s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_78 x6 x2 x5 x1 l
    s cd cs) (nd_C__case_78 x6 x2 x5 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_78 x6
    x2 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_78 x6 x2 x5 x1 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_78"
    [show x6, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_78" (showCons x7))

d_C__case_77 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_77 x2 x5 x1 x6 cd cs = case x6 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_OP_dollar d_C_skipCommand
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "unknown option: '") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) cd cs
  Curry_Prelude.OP_Cons x7 x8 -> d_C__case_76 x8 x2 x5 x1 x7 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_77 x2 x5 x1 l cd
    cs) (d_C__case_77 x2 x5 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_77 x2
    x5 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_77 x2 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_77"
    [show x2, show x5, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_77" (showCons x6))

nd_C__case_77 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_77 x2 x5 x1 x6 s cd cs = case x6 of
  Curry_Prelude.OP_List -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id d_C_skipCommand)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "unknown option: '") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) s0 cd cs
  Curry_Prelude.OP_Cons x7 x8 -> let s0 = s
    in s0 `seq` nd_C__case_76 x8 x2 x5 x1 x7 s0 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_C__case_77 x2 x5 x1 l s
    cd cs) (nd_C__case_77 x2 x5 x1 r s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> nd_C__case_77 x2
    x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_C__case_77 x2 x5 x1 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_77"
    [show x2, show x5, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_77" (showCons x6))

d_C__case_76 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_76 x8 x2 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.OP_Tuple2 x9 x10 -> d_C__case_75 x2 x5 x1 x10 x8 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_76 x8 x2 x5 x1
    l cd cs) (d_C__case_76 x8 x2 x5 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_76
    x8 x2 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_76 x8 x2 x5 x1
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_76"
    [show x8, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_76" (showCons x7))

nd_C__case_76 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState
  (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_76 x8 x2 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.OP_Tuple2 x9 x10 -> let s0 = s
    in s0 `seq` nd_C__case_75 x2 x5 x1 x10 x8 s0 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_76 x8 x2 x5
    x1 l s cd cs) (nd_C__case_76 x8 x2 x5 x1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_76
    x8 x2 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_76 x8 x2 x5
    x1 e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_76"
    [show x8, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_76" (showCons x7))

d_C__case_75 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_75 x2 x5 x1 x10 x8 cd cs = case x8 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x10
    x1 cd cs) (Curry_Prelude.d_C_apply (Curry_Utils.d_C_strip cd cs) x5 cd cs)
    cd cs
  Curry_Prelude.OP_Cons x11 x12 -> Curry_Prelude.d_OP_dollar d_C_skipCommand
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "ambiguous option: ':") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_75 x2 x5 x1 x10
    l cd cs) (d_C__case_75 x2 x5 x1 x10 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_75 x2
    x5 x1 x10 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_75 x2 x5 x1 x10
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_75"
    [show x2, show x5, show x1, show x10, show x8] info)
  _ -> failCons cd (consFail "REPL._case_75" (showCons x8))

nd_C__case_75 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Func Curry_Linker.C_ReplState (Func (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState
  (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_75 x2 x5 x1 x10 x8 s cd cs = case x8 of
  Curry_Prelude.OP_List -> let s3 = s
    in s3 `seq` (let s2 = leftSupply s3
                     s4 = rightSupply s3
                     s0 = leftSupply s4
                     s1 = rightSupply s4
    in s2 `seq` (s4 `seq` (s0 `seq` (s1 `seq` Curry_Prelude.nd_C_apply
    (Curry_Prelude.nd_C_apply x10 x1 s0 cd cs) (Curry_Prelude.nd_C_apply (wrapDX
    id (Curry_Utils.d_C_strip cd cs)) x5 s1 cd cs) s2 cd cs))))
  Curry_Prelude.OP_Cons x11 x12 -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id d_C_skipCommand)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "ambiguous option: ':") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) s0 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_C__case_75 x2 x5 x1 x10
    l s cd cs) (nd_C__case_75 x2 x5 x1 x10 r s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> nd_C__case_75 x2
    x5 x1 x10 z s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_C__case_75 x2 x5 x1 x10
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_75"
    [show x2, show x5, show x1, show x10, show x8] info)
  _ -> failCons cd (consFail "REPL._case_75" (showCons x8))

d_C__case_82 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_82 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "no program loaded") cd cs
  Curry_Prelude.C_False -> d_C__case_81 x2 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_82 x1 x2 l cd cs)
    (d_C__case_82 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_82 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_82 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_82"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_82" (showCons x3))

d_C__case_81 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_81 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq
    (d_C_compileProgramWithGoal x1 Curry_Prelude.C_True (d_C__case_80 x2
    (Curry_Prelude.d_C_null x2 cd cs) cd cs) cd cs)
    d_OP_processFork_dot_uscore_hash_lambda238 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_81 x2 x1 l cd cs)
    (d_C__case_81 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_81 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_81 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_81"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_81" (showCons x3))

d_C__case_80 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_80 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "main"
  Curry_Prelude.C_False -> x2
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_80 x2 l cd cs)
    (d_C__case_80 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_80 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_80 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_80"
    [show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_80" (showCons x3))

d_C__case_85 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_85 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "no program loaded") cd cs
  Curry_Prelude.C_False -> d_C__case_84 x2 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_85 x1 x2 l cd cs)
    (d_C__case_85 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_85 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_85 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_85"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_85" (showCons x3))

d_C__case_84 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_84 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq
    (d_C_compileProgramWithGoal x1 Curry_Prelude.C_True (d_C__case_83 x2
    (Curry_Prelude.d_C_null x2 cd cs) cd cs) cd cs)
    d_OP_processSave_dot_uscore_hash_lambda237 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_84 x2 x1 l cd cs)
    (d_C__case_84 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_84 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_84 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_84"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_84" (showCons x3))

d_C__case_83 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_83 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "main"
  Curry_Prelude.C_False -> x2
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_83 x2 l cd cs)
    (d_C__case_83 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_83 x2 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_83 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_83"
    [show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_83" (showCons x3))

d_C__case_86 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_86 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Linker.d_C_mainMod x1 cd cs
  Curry_Prelude.C_False -> Curry_Distribution.d_C_stripCurrySuffix x2 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_86 x2 x1 l cd cs)
    (d_C__case_86 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_86 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_86 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_86"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_86" (showCons x3))

d_C__case_88 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_88 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "superfluous argument") cd cs
  Curry_Prelude.C_False -> d_C__case_87 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_88 x2 x1 l cd cs)
    (d_C__case_88 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_88 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_88 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_88"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_88" (showCons x3))

d_C__case_87 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_87 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_dollar (d_C_checkForWish cd cs)
    (Curry_Prelude.d_OP_gt_gt (Curry_Linker.d_C_writeVerboseInfo x1
    (Curry_Prelude.C_Int 1#) (Curry_Prelude.toCurryString
    "Starting Curry Browser in separate window...") cd cs)
    (d_C_checkAndCallCpmTool (Curry_Prelude.toCurryString "curry-browse")
    (Curry_Prelude.toCurryString "currybrowse")
    (d_OP_processBrowse_dot_uscore_hash_lambda235 x1) cd cs) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_87 x1 l cd cs)
    (d_C__case_87 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_87 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_87 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_87"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_87" (showCons x2))

d_C__case_90 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_90 x4 x3 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> x4
  Curry_Prelude.C_False -> d_C__case_89 x3 (Curry_Prelude.d_C_null x3 cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_90 x4 x3 l cd cs)
    (d_C__case_90 x4 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_90 x4
    x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_90 x4 x3 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_90"
    [show x4, show x3, show x5] info)
  _ -> failCons cd (consFail "REPL._case_90" (showCons x5))

d_C__case_89 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_89 x3 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.toCurryString "cat"
  Curry_Prelude.C_False -> x3
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_89 x3 l cd cs)
    (d_C__case_89 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_89 x3 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_89 x3 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_89"
    [show x3, show x4] info)
  _ -> failCons cd (consFail "REPL._case_89" (showCons x4))

d_C__case_92 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_92 x2 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Linker.d_C_mainMod x1
    cd cs) cd cs
  Curry_Prelude.C_False -> let x3 = Curry_FilePath.d_C_splitFileName
                                 (Curry_Distribution.d_C_stripCurrySuffix x2 cd
                                 cs) cd cs
                               x4 = d_OP_getModuleName_dot_uscore_hash_selFP27_hash_dirname
                                 x3 cd cs
                               x5 = d_OP_getModuleName_dot_uscore_hash_selFP28_hash_mname
                                 x3 cd cs
    in d_C__case_91 x4 x2 x5 (Curry_Prelude.d_OP_eq_eq x4
    (Curry_Prelude.toCurryString "./") cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_92 x2 x1 l cd cs)
    (d_C__case_92 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_92 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_92 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_92"
    [show x2, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_92" (showCons x6))

d_C__case_91 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_91 x4 x2 x5 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return x5 cd cs
  Curry_Prelude.C_False -> Curry_Directory.d_C_getAbsolutePath
    (Curry_Distribution.d_C_stripCurrySuffix x2 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_91 x4 x2 x5 l cd
    cs) (d_C__case_91 x4 x2 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_91 x4
    x2 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_91 x4 x2 x5 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_91"
    [show x4, show x2, show x5, show x6] info)
  _ -> failCons cd (consFail "REPL._case_91" (showCons x6))

d_C__case_93 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_93 x3 x1 x2 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "function not found") cd cs
  Curry_Prelude.C_False -> d_C_showFunctionInModule x2 x3 x1 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_93 x3 x1 x2 l cd
    cs) (d_C__case_93 x3 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_93 x3
    x1 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_93 x3 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_93"
    [show x3, show x1, show x2, show x4] info)
  _ -> failCons cd (consFail "REPL._case_93" (showCons x4))

d_C__case_96 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_96 x2 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "missing function name") cd cs
  Curry_Prelude.C_False -> d_C__case_95 x5 x4 x1 x2 (Curry_Prelude.d_C_null x5
    cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_96 x2 x5 x4 x1 l
    cd cs) (d_C__case_96 x2 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_96 x2
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_96 x2 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_96"
    [show x2, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_96" (showCons x6))

d_C__case_95 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_95 x5 x4 x1 x2 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq (d_C_getModuleOfFunction
    x1 x2 cd cs) (d_OP_processSource_dot_uscore_hash_lambda228 x2 x1) cd cs
  Curry_Prelude.C_False -> d_C__case_94 x5 x4 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_95 x5 x4 x1 x2 l
    cd cs) (d_C__case_95 x5 x4 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_95 x5
    x4 x1 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_95 x5 x4 x1 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_95"
    [show x5, show x4, show x1, show x2, show x6] info)
  _ -> failCons cd (consFail "REPL._case_95" (showCons x6))

d_C__case_94 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_94 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_showFunctionInModule x1 x4 (Curry_Prelude.d_C_tail
    x5 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_94 x5 x4 x1 l cd
    cs) (d_C__case_94 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_94 x5
    x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_94 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_94"
    [show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_94" (showCons x6))

d_C__case_97 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_97 x4 x3 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> x3
  Curry_Prelude.C_False -> x4
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_97 x4 x3 l cd cs)
    (d_C__case_97 x4 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_97 x4
    x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_97 x4 x3 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_97"
    [show x4, show x3, show x5] info)
  _ -> failCons cd (consFail "REPL._case_97" (showCons x5))

d_C__case_98 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Maybe
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_98 x4 x3 x1 x2 x5 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "no editor defined") cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_maybe (d_C_skipCommand
    (Curry_Prelude.toCurryString "source file not found") cd cs)
    (d_OP_processEdit_dot_uscore_hash_lambda224_dot_uscore_hash_lambda225_dot_uscore_hash_lambda226_dot_uscore_hash_lambda227
    x5 x2) x1 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_98 x4 x3 x1 x2 x5
    l cd cs) (d_C__case_98 x4 x3 x1 x2 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_98 x4
    x3 x1 x2 x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_98 x4 x3 x1 x2 x5
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_98"
    [show x4, show x3, show x1, show x2, show x5, show x6] info)
  _ -> failCons cd (consFail "REPL._case_98" (showCons x6))

d_C__case_99 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Maybe Curry_Linker.C_ReplState
d_C__case_99 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Just x1
  Curry_Prelude.C_False -> Curry_Prelude.C_Nothing
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_99 x1 l cd cs)
    (d_C__case_99 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_99 x1 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_99 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_99"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_99" (showCons x2))

d_C__case_100 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_100 x1 x2 cd cs = case x2 of
  Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 -> Curry_Linker.C_ReplState
    x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 (d_OP_processAdd_dot_insert_dot_350 x1
    (Curry_Linker.d_C_addMods x2 cd cs) cd cs) x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_100 x1 l cd
    cs) (d_C__case_100 x1 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_100
    x1 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_100 x1 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_100"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_100" (showCons x2))

d_C__case_101 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_C__case_101 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq
    (Curry_Files.d_C_lookupFileInPath (Curry_Prelude.d_C_apply
    (Curry_Names.d_C_moduleNameToPath cd cs) x3 cd cs) (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString ".curry") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString ".lcurry") Curry_Prelude.OP_List))
    (Curry_Linker.d_C_loadPaths x1 cd cs) cd cs)
    (d_OP_processAdd_dot_add_dot_350_dot_uscore_hash_lambda186 x3 x1) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    d_C_writeErrorMsg (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Illegal module name (ignored): ") x3 cd cs) cd cs)
    (Curry_Prelude.d_C_return x1 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_101 x3 x1 l cd
    cs) (d_C__case_101 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_101 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_101 x3 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_101"
    [show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_101" (showCons x4))

d_C__case_104 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0
  -> Curry_Prelude.OP_List t0 -> Curry_Prelude.OP_List t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List t0
d_C__case_104 x3 x1 x4 x2 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons x1 x2
  Curry_Prelude.C_False -> d_C__case_103 x3 x1 x4 x2 (Curry_Prelude.d_OP_eq_eq
    x1 x3 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_104 x3 x1 x4 x2 l
    cd cs) (d_C__case_104 x3 x1 x4 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_104 x3
    x1 x4 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_104 x3 x1 x4 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_104"
    [show x3, show x1, show x4, show x2, show x5] info)
  _ -> failCons cd (consFail "REPL._case_104" (showCons x5))

d_C__case_103 :: forall t0 . (Curry_Prelude.Curry t0) => t0 -> t0
  -> Curry_Prelude.OP_List t0 -> Curry_Prelude.OP_List t0
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List t0
d_C__case_103 x3 x1 x4 x2 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> x2
  Curry_Prelude.C_False -> d_C__case_102 x4 x1 x3 (Curry_Prelude.d_C_otherwise
    cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_103 x3 x1 x4 x2 l
    cd cs) (d_C__case_103 x3 x1 x4 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_103 x3
    x1 x4 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_103 x3 x1 x4 x2 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_103"
    [show x3, show x1, show x4, show x2, show x5] info)
  _ -> failCons cd (consFail "REPL._case_103" (showCons x5))

d_C__case_102 :: forall t0 . (Curry_Prelude.Curry t0) => Curry_Prelude.OP_List
  t0 -> t0 -> t0 -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List t0
d_C__case_102 x4 x1 x3 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons x3
    (d_OP_processAdd_dot_insert_dot_350 x1 x4 cd cs)
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_102 x4 x1 x3 l cd
    cs) (d_C__case_102 x4 x1 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_102 x4
    x1 x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_102 x4 x1 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_102"
    [show x4, show x1, show x3, show x5] info)
  _ -> failCons cd (consFail "REPL._case_102" (showCons x5))

d_C__case_106 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_106 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "Missing module name") cd cs
  Curry_Prelude.C_False -> d_C__case_105 x2 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_106 x2 x1 l cd
    cs) (d_C__case_106 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_106 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_106 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_106"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_106" (showCons x3))

d_C__case_105 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_105 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_liftIO (acceptCs id
    Curry_Prelude.C_Just) (Curry_Prelude.d_C_foldIO (acceptCs id
    d_OP_processAdd_dot_add_dot_350) x1 (Curry_Prelude.d_C_words x2 cd cs) cd
    cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_105 x2 x1 l cd
    cs) (d_C__case_105 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_105 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_105 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_105"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_105" (showCons x3))

d_C__case_109 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_109 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "no program loaded!") cd cs
  Curry_Prelude.C_False -> d_C__case_108 x2 x1 (Curry_Prelude.d_C_null
    (Curry_Distribution.d_C_stripCurrySuffix x2 cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_109 x1 x2 l cd
    cs) (d_C__case_109 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_109 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_109 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_109"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_109" (showCons x3))

d_C__case_108 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_108 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_compileCurryProgram x1
    (Curry_Linker.d_C_mainMod x1 cd cs) cd cs) (Curry_Prelude.d_C_return
    (Curry_Prelude.C_Just x1) cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_107 (Curry_Prelude.d_C_otherwise cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_108 x2 x1 l cd
    cs) (d_C__case_108 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_108 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_108 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_108"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_108" (showCons x3))

d_C__case_107 :: Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_107 x1 cd cs = case x1 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "superfluous argument") cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_107 l cd cs)
    (d_C__case_107 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_107 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_107 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_107"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_107" (showCons x1))

d_C__case_110 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Linker.C_ReplState
d_C__case_110 x1 x2 cd cs = case x2 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x1 Curry_Prelude.OP_List x14 x15 x16 x17 x18
    x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_110 x1 l cd
    cs) (d_C__case_110 x1 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_110
    x1 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_110 x1 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_110"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_110" (showCons x2))

d_C__case_112 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_112 x3 x2 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "missing module name") cd cs
  Curry_Prelude.C_False -> let x4 = Curry_FilePath.d_C_splitFileName x3 cd cs
                               x5 = d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP21_hash_dirname
                                 x4 cd cs
                               x6 = d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_selFP22_hash_modname
                                 x4 cd cs
    in Curry_Prelude.d_OP_gt_gt_eq (d_C__case_111 x5 x2
    (Curry_Prelude.d_OP_eq_eq x5 (Curry_Prelude.toCurryString "./") cd cs) cd
    cs) (d_OP_processLoad_dot_uscore_hash_lambda149_dot_uscore_hash_lambda150 x3
    x6) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_112 x3 x2 l cd
    cs) (d_C__case_112 x3 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_112 x3
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_112 x3 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_112"
    [show x3, show x2, show x7] info)
  _ -> failCons cd (consFail "REPL._case_112" (showCons x7))

d_C__case_111 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_111 x5 x2 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.C_Just x2) cd
    cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    Curry_Prelude.d_C_putStrLn (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "Changing working directory to ") x5 cd cs) cd
    cs) (d_C_processCd x2 x5 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_111 x5 x2 l cd
    cs) (d_C__case_111 x5 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_111 x5
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_111 x5 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_111"
    [show x5, show x2, show x6] info)
  _ -> failCons cd (consFail "REPL._case_111" (showCons x6))

d_C__case_113 :: Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_113 x1 cd cs = case x1 of
  Curry_Linker.C_ReplState x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 -> Curry_Linker.C_ReplState
    x3 x4 x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23
    x24 x25 x26 x27 x28 x29 Curry_Prelude.C_True x31 x32 x33
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_113 l cd cs)
    (d_C__case_113 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_113
    z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_113 e cd $!
    addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_113"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_113" (showCons x1))

d_C__case_115 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_115 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "missing system command") cd cs
  Curry_Prelude.C_False -> d_C__case_114 x1 x2 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_115 x2 x1 l cd
    cs) (d_C__case_115 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_115 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_115 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_115"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_115" (showCons x3))

d_C__case_114 :: Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_114 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_System.d_C_system x2
    cd cs) (Curry_Prelude.d_C_return (Curry_Prelude.C_Just x1) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_114 x1 x2 l cd
    cs) (d_C__case_114 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_114 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_114 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_114"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_114" (showCons x3))

d_C__case_116 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_116 x1 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "Operation not allowed in safe mode!") cd cs
  Curry_Prelude.C_False -> x2
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_116 x1 x2 l cd
    cs) (d_C__case_116 x1 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_116 x1
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_116 x1 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_116"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_116" (showCons x3))

nd_C__case_116 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState) -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_116 x1 x2 x3 s cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "Operation not allowed in safe mode!") cd cs
  Curry_Prelude.C_False -> x2
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_116 x1 x2 l s cd
    cs) (nd_C__case_116 x1 x2 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_116 x1
    x2 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_116 x1 x2 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_116"
    [show x1, show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_116" (showCons x3))

d_C__case_123 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_123 x2 x6 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "unknown command") cd cs
  Curry_Prelude.C_False -> d_C__case_122 x2 x6 x5 x1 (Curry_Prelude.d_OP_eq_eq
    (Curry_Prelude.d_C_head x2 cd cs) (Curry_Prelude.C_Char '!'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_123 x2 x6 x5 x1 l
    cd cs) (d_C__case_123 x2 x6 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_123 x2
    x6 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_123 x2 x6 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_123"
    [show x2, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_123" (showCons x7))

nd_C__case_123 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_123 x2 x6 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.C_True -> d_C_skipCommand (Curry_Prelude.toCurryString
    "unknown command") cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_122 x2 x6 x5 x1 (Curry_Prelude.d_OP_eq_eq
    (Curry_Prelude.d_C_head x2 cd cs) (Curry_Prelude.C_Char '!'#) cd cs) s0 cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_123 x2 x6 x5 x1
    l s cd cs) (nd_C__case_123 x2 x6 x5 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_123 x2
    x6 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_123 x2 x6 x5 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_123"
    [show x2, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_123" (showCons x7))

d_C__case_122 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_122 x2 x6 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_dollar (d_C_unsafeExec x1)
    (d_C_processSysCall x1 (Curry_Prelude.d_OP_dollar (Curry_Utils.d_C_strip cd
    cs) (Curry_Prelude.d_C_tail x2 cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_121 x6 x2 x5 x1
    (Curry_Prelude.d_C_otherwise cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_122 x2 x6 x5 x1 l
    cd cs) (d_C__case_122 x2 x6 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_122 x2
    x6 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_122 x2 x6 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_122"
    [show x2, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_122" (showCons x7))

nd_C__case_122 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
nd_C__case_122 x2 x6 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.C_True -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_OP_dollar (wrapNX id (nd_C_unsafeExec
    x1)) (d_C_processSysCall x1 (Curry_Prelude.nd_OP_dollar (wrapDX id
    (Curry_Utils.d_C_strip cd cs)) (Curry_Prelude.d_C_tail x2 cd cs) s0 cd cs)
    cd cs) s1 cd cs))
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_121 x6 x2 x5 x1 (Curry_Prelude.d_C_otherwise cd cs)
    s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_122 x2 x6 x5 x1
    l s cd cs) (nd_C__case_122 x2 x6 x5 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_122 x2
    x6 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_122 x2 x6 x5 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_122"
    [show x2, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_122" (showCons x7))

d_C__case_121 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_121 x6 x2 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C__case_120 x2 x5 x1 x6 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_121 x6 x2 x5 x1 l
    cd cs) (d_C__case_121 x6 x2 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_121 x6
    x2 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_121 x6 x2 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_121"
    [show x6, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_121" (showCons x7))

nd_C__case_121 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState
  (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_121 x6 x2 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` nd_C__case_120 x2 x5 x1 x6 s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_121 x6 x2 x5 x1
    l s cd cs) (nd_C__case_121 x6 x2 x5 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_121 x6
    x2 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_121 x6 x2 x5 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_121"
    [show x6, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_121" (showCons x7))

d_C__case_120 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_120 x2 x5 x1 x6 cd cs = case x6 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_OP_dollar d_C_skipCommand
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "unknown command: ':") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) cd cs
  Curry_Prelude.OP_Cons x7 x8 -> d_C__case_119 x8 x2 x5 x1 x7 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_120 x2 x5 x1 l
    cd cs) (d_C__case_120 x2 x5 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_120 x2
    x5 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_120 x2 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_120"
    [show x2, show x5, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_120" (showCons x6))

nd_C__case_120 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_120 x2 x5 x1 x6 s cd cs = case x6 of
  Curry_Prelude.OP_List -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id d_C_skipCommand)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "unknown command: ':") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) s0 cd cs
  Curry_Prelude.OP_Cons x7 x8 -> let s0 = s
    in s0 `seq` nd_C__case_119 x8 x2 x5 x1 x7 s0 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_C__case_120 x2 x5 x1 l
    s cd cs) (nd_C__case_120 x2 x5 x1 r s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> nd_C__case_120
    x2 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_C__case_120 x2 x5 x1 e
    s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_120"
    [show x2, show x5, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_120" (showCons x6))

d_C__case_119 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_119 x8 x2 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.OP_Tuple2 x9 x10 -> d_C__case_118 x2 x9 x5 x1 x10 x8 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_119 x8 x2 x5
    x1 l cd cs) (d_C__case_119 x8 x2 x5 x1 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_119
    x8 x2 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_119 x8 x2 x5
    x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_119"
    [show x8, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_119" (showCons x7))

nd_C__case_119 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState
  (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_119 x8 x2 x5 x1 x7 s cd cs = case x7 of
  Curry_Prelude.OP_Tuple2 x9 x10 -> let s0 = s
    in s0 `seq` nd_C__case_118 x2 x9 x5 x1 x10 x8 s0 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (nd_C__case_119 x8 x2 x5
    x1 l s cd cs) (nd_C__case_119 x8 x2 x5 x1 r s cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> nd_C__case_119
    x8 x2 x5 x1 z s cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (nd_C__case_119 x8 x2 x5
    x1 e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_119"
    [show x8, show x2, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_119" (showCons x7))

d_C__case_118 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> (Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Linker.C_ReplState
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)
d_C__case_118 x2 x9 x5 x1 x10 x8 cd cs = case x8 of
  Curry_Prelude.OP_List -> d_C__case_117 x9 x5 x1 x10 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_elem x9 cd cs) (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "eval") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "load") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "quit") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "reload") Curry_Prelude.OP_List)))) cd cs) cd
    cs
  Curry_Prelude.OP_Cons x11 x12 -> Curry_Prelude.d_OP_dollar d_C_skipCommand
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "ambiguous command: ':") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_118 x2 x9 x5 x1
    x10 l cd cs) (d_C__case_118 x2 x9 x5 x1 x10 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_118 x2
    x9 x5 x1 x10 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_118 x2 x9 x5 x1
    x10 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_118"
    [show x2, show x9, show x5, show x1, show x10, show x8] info)
  _ -> failCons cd (consFail "REPL._case_118" (showCons x8))

nd_C__case_118 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Func
  Curry_Linker.C_ReplState (Func (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.C_IO (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)))
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Func Curry_Linker.C_ReplState (Func
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState))))) -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_118 x2 x9 x5 x1 x10 x8 s cd cs = case x8 of
  Curry_Prelude.OP_List -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` nd_C__case_117 x9 x5 x1 x10 (Curry_Prelude.nd_C_apply
    (wrapDX id (Curry_Prelude.d_C_elem x9 cd cs)) (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "eval") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "load") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "quit") (Curry_Prelude.OP_Cons
    (Curry_Prelude.toCurryString "reload") Curry_Prelude.OP_List)))) s0 cd cs)
    s1 cd cs))
  Curry_Prelude.OP_Cons x11 x12 -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_dollar (wrapDX id d_C_skipCommand)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "ambiguous command: ':") (Curry_Prelude.d_OP_plus_plus x2
    (Curry_Prelude.toCurryString "'") cd cs) cd cs) s0 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (nd_C__case_118 x2 x9 x5 x1
    x10 l s cd cs) (nd_C__case_118 x2 x9 x5 x1 x10 r s cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> nd_C__case_118
    x2 x9 x5 x1 x10 z s cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (nd_C__case_118 x2 x9 x5 x1
    x10 e s cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_118"
    [show x2, show x9, show x5, show x1, show x10, show x8] info)
  _ -> failCons cd (consFail "REPL._case_118" (showCons x8))

d_C__case_117 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> (Curry_Linker.C_ReplState -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.C_Maybe Curry_Linker.C_ReplState)) -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
d_C__case_117 x9 x5 x1 x10 x11 cd cs = case x11 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x10
    x1 cd cs) (Curry_Prelude.d_C_apply (Curry_Utils.d_C_strip cd cs) x5 cd cs)
    cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_dollar (d_C_unsafeExec x1)
    (Curry_Prelude.d_C_apply (Curry_Prelude.d_C_apply x10 x1 cd cs)
    (Curry_Prelude.d_C_apply (Curry_Utils.d_C_strip cd cs) x5 cd cs) cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_117 x9 x5 x1 x10
    l cd cs) (d_C__case_117 x9 x5 x1 x10 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_117 x9
    x5 x1 x10 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_117 x9 x5 x1 x10
    e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_117"
    [show x9, show x5, show x1, show x10, show x11] info)
  _ -> failCons cd (consFail "REPL._case_117" (showCons x11))

nd_C__case_117 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> Func Curry_Linker.C_ReplState (Func (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState))) -> Curry_Prelude.C_Bool -> IDSupply -> Cover
  -> ConstStore -> Curry_Prelude.C_IO (Curry_Prelude.C_Maybe
  Curry_Linker.C_ReplState)
nd_C__case_117 x9 x5 x1 x10 x11 s cd cs = case x11 of
  Curry_Prelude.C_True -> let s3 = s
    in s3 `seq` (let s2 = leftSupply s3
                     s4 = rightSupply s3
                     s0 = leftSupply s4
                     s1 = rightSupply s4
    in s2 `seq` (s4 `seq` (s0 `seq` (s1 `seq` Curry_Prelude.nd_C_apply
    (Curry_Prelude.nd_C_apply x10 x1 s0 cd cs) (Curry_Prelude.nd_C_apply (wrapDX
    id (Curry_Utils.d_C_strip cd cs)) x5 s1 cd cs) s2 cd cs))))
  Curry_Prelude.C_False -> let s6 = s
    in s6 `seq` (let s5 = leftSupply s6
                     s3 = rightSupply s6
    in s5 `seq` (s3 `seq` Curry_Prelude.nd_OP_dollar (wrapNX id (nd_C_unsafeExec
    x1)) (let s2 = leftSupply s3
              s4 = rightSupply s3
              s0 = leftSupply s4
              s1 = rightSupply s4
    in s2 `seq` (s4 `seq` (s0 `seq` (s1 `seq` Curry_Prelude.nd_C_apply
    (Curry_Prelude.nd_C_apply x10 x1 s0 cd cs) (Curry_Prelude.nd_C_apply (wrapDX
    id (Curry_Utils.d_C_strip cd cs)) x5 s1 cd cs) s2 cd cs)))) s5 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_117 x9 x5 x1 x10
    l s cd cs) (nd_C__case_117 x9 x5 x1 x10 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_117 x9
    x5 x1 x10 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_117 x9 x5 x1 x10
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_117"
    [show x9, show x5, show x1, show x10, show x11] info)
  _ -> failCons cd (consFail "REPL._case_117" (showCons x11))

d_C__case_126 :: Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Int
d_C__case_126 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Int 2#
  Curry_Prelude.C_False -> d_C__case_125 x1 (Curry_Prelude.d_OP_gt_eq x1
    (Curry_Prelude.C_Int 4#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_126 x1 l cd cs)
    (d_C__case_126 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_126 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_126 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_126"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_126" (showCons x2))

d_C__case_125 :: Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Int
d_C__case_125 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.C_Int 3#
  Curry_Prelude.C_False -> d_C__case_124 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_125 x1 l cd cs)
    (d_C__case_125 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_125 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_125 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_125"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_125" (showCons x2))

d_C__case_124 :: Curry_Prelude.C_Int -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Int
d_C__case_124 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> x1
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_124 x1 l cd cs)
    (d_C__case_124 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_124 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_124 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_124"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_124" (showCons x2))

d_C__case_127 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C__case_127 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons (Curry_Prelude.toCurryString
    "--trace-failure") Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_127 x1 l cd cs)
    (d_C__case_127 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_127 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_127 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_127"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_127" (showCons x2))

d_C__case_128 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C__case_128 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.OP_Cons (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "--parse-options=\"")
    (Curry_Prelude.d_OP_plus_plus (Curry_Linker.d_C_parseOpts x1 cd cs)
    (Curry_Prelude.toCurryString "\"") cd cs) cd cs) Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_128 x1 l cd cs)
    (d_C__case_128 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_128 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_128 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_128"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_128" (showCons x2))

d_C__case_129 :: AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_129 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '('#)
    (Curry_Prelude.d_OP_plus_plus x1 (Curry_Prelude.toCurryString
    ") Prelude.>>= Prelude.print") cd cs)
  Curry_Prelude.C_False -> x1
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_129 x2 x1 l cd
    cs) (d_C__case_129 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_129 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_129 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_129"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_129" (showCons x3))

d_C__case_135 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_135 x3 x1 x7 cd cs = case x7 of
  Curry_Prelude.OP_Cons x9 x10 -> d_C__case_134 x10 x3 x1 x9 cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "REPL.makeMainGoalMonomorphic") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_135 x3 x1 l cd
    cs) (d_C__case_135 x3 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_135 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_135 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_135"
    [show x3, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_135" (showCons x7))

d_C__case_134 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_134 x10 x3 x1 x9 cd cs = case x9 of
  AbstractCurry.Curry_Types.C_CFunc x11 x12 x13 x14 x15 -> d_C__case_133 x14 x3
    x1 x10 cd cs
  AbstractCurry.Curry_Types.C_CmtFunc x18 x19 x20 x21 x22 x23 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString "REPL.makeMainGoalMonomorphic") cd cs
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C__case_134 x10 x3 x1 l cd cs) (d_C__case_134 x10 x3 x1 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C__case_134 x10 x3 x1 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C__case_134 x10 x3 x1 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "REPL._case_134" [show x10, show x3, show x1, show x9] info)
  _ -> failCons cd (consFail "REPL._case_134" (showCons x9))

d_C__case_133 :: AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_133 x14 x3 x1 x10 cd cs = case x10 of
  Curry_Prelude.OP_List -> d_C__case_132 x14 x3 x1
    (AbstractCurry.Curry_Select.d_C_isFunctionalType x14 cd cs) cd cs
  Curry_Prelude.OP_Cons x16 x17 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString "REPL.makeMainGoalMonomorphic") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_133 x14 x3 x1 l
    cd cs) (d_C__case_133 x14 x3 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_133
    x14 x3 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_133 x14 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_133"
    [show x14, show x3, show x1, show x10] info)
  _ -> failCons cd (consFail "REPL._case_133" (showCons x10))

d_C__case_132 :: AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_132 x14 x3 x1 x15 cd cs = case x15 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_writeErrorMsg
    (Curry_Prelude.toCurryString "expression is of functional type") cd cs)
    (Curry_Prelude.d_C_return Curry_Prelude.C_False cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_131 x14 x3 x1
    (AbstractCurry.Curry_Select.d_C_isPolyType x14 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_132 x14 x3 x1 l
    cd cs) (d_C__case_132 x14 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_132 x14
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_132 x14 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_132"
    [show x14, show x3, show x1, show x15] info)
  _ -> failCons cd (consFail "REPL._case_132" (showCons x15))

d_C__case_131 :: AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_131 x14 x3 x1 x15 cd cs = case x15 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_writeMainGoalFile x1
    (Curry_Prelude.d_C_apply (AbstractCurry.Curry_Select.d_C_modsOfType cd cs)
    x14 cd cs) (Curry_Prelude.d_OP_dollar (acceptCs id Curry_Prelude.C_Just)
    (Curry_Utils.d_C_showMonoTypeExpr Curry_Prelude.C_True x14 cd cs) cd cs) x3
    cd cs) (Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 2#))
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Type of main expression \"") (Curry_Prelude.d_OP_plus_plus
    (Curry_Utils.d_C_showMonoTypeExpr Curry_Prelude.C_False x14 cd cs)
    (Curry_Prelude.toCurryString "\" made monomorphic") cd cs) cd cs) cd cs)
    (Curry_Prelude.d_OP_gt_gt (Curry_Linker.d_C_writeVerboseInfo x1
    (Curry_Prelude.C_Int 1#) (Curry_Prelude.toCurryString
    "Type variables of main expression replaced by \"()\"") cd cs)
    (Curry_Prelude.d_C_return Curry_Prelude.C_True cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_130 x14 x3 x1 (Curry_Prelude.d_C_otherwise
    cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_131 x14 x3 x1 l
    cd cs) (d_C__case_131 x14 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_131 x14
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_131 x14 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_131"
    [show x14, show x3, show x1, show x15] info)
  _ -> failCons cd (consFail "REPL._case_131" (showCons x15))

d_C__case_130 :: AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool
  -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_130 x14 x3 x1 x15 cd cs = case x15 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    (Curry_Prelude.d_C_unless (Curry_Prelude.d_OP_eq_eq
    (d_OP_makeMainGoalMonomorphic_dot_newgoal_dot_262 x3 x14 cd cs) x3 cd cs))
    (d_C_writeSimpleMainGoalFile x1
    (d_OP_makeMainGoalMonomorphic_dot_newgoal_dot_262 x3 x14 cd cs) cd cs) cd
    cs) (Curry_Prelude.d_C_return Curry_Prelude.C_True cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "REPL.makeMainGoalMonomorphic") cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_130 x14 x3 x1 l
    cd cs) (d_C__case_130 x14 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_130 x14
    x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_130 x14 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_130"
    [show x14, show x3, show x1, show x15] info)
  _ -> failCons cd (consFail "REPL._case_130" (showCons x15))

d_C__case_137 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_137 x3 x2 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_drop (Curry_Prelude.C_Int 6#) x3 cd
    cs
  Curry_Prelude.C_False -> d_C__case_136 x3 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_137 x3 x2 l cd
    cs) (d_C__case_137 x3 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_137 x3
    x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_137 x3 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_137"
    [show x3, show x2, show x4] info)
  _ -> failCons cd (consFail "REPL._case_137" (showCons x4))

d_C__case_136 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_136 x3 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224
    x3 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_136 x3 l cd cs)
    (d_C__case_136 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_136 x3
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_136 x3 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_136"
    [show x3, show x4] info)
  _ -> failCons cd (consFail "REPL._case_136" (showCons x4))

d_C__case_139 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_139 x2 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> let x3 = d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186_dot_findWhere_dot_224
                                (Curry_Prelude.d_C_drop (Curry_Prelude.C_Int 4#)
                                x2 cd cs) cd cs
    in d_C__case_138 x3 x1 (Curry_Prelude.d_C_null x3 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.OP_Tuple2 x1 Curry_Prelude.OP_List
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_139 x2 x1 l cd
    cs) (d_C__case_139 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_139 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_139 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_139"
    [show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_139" (showCons x4))

d_C__case_138 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_138 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Tuple2 x1 Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.d_C_apply
    (Curry_Prelude.d_C_reverse cd cs) x3 cd cs) (Curry_Prelude.d_C_drop
    (Curry_Prelude.d_C_length x3 cd cs) x1 cd cs)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_138 x3 x1 l cd
    cs) (d_C__case_138 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_138 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_138 x3 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_138"
    [show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_138" (showCons x4))

d_C__case_141 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Cover -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C__case_141 x6 cd cs = case x6 of
  Curry_Prelude.OP_Cons x7 x8 -> d_C__case_140 x7 cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "REPL.insertFreeVarsInMainGoal.freeVarsInFuncRule") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_141 l cd cs)
    (d_C__case_141 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_141 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_141 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_141"
    [show x6] info)
  _ -> failCons cd (consFail "REPL._case_141" (showCons x6))

d_C__case_140 :: AbstractCurry.Curry_Types.C_CRule -> Cover -> ConstStore
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
d_C__case_140 x7 cd cs = case x7 of
  AbstractCurry.Curry_Types.C_CRule x9 x10 -> d_OP_insertFreeVarsInMainGoal_dot_freeVarsInRhs_dot_186
    x10 cd cs
  AbstractCurry.Curry_Types.Choice_C_CRule d i l r -> narrow d i (d_C__case_140
    l cd cs) (d_C__case_140 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CRule d i xs -> narrows cs d i (\z ->
    d_C__case_140 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CRule d c e -> guardCons d c (d_C__case_140
    e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CRule d info -> failCons d (traceFail
    "REPL._case_140" [show x7] info)
  _ -> failCons cd (consFail "REPL._case_140" (showCons x7))

d_C__case_142 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> AbstractCurry.Curry_Types.C_CLocalDecl -> Cover
  -> ConstStore -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)
d_C__case_142 x2 x1 cd cs = case x1 of
  AbstractCurry.Curry_Types.C_CLocalVars x3 -> Curry_Prelude.d_C_map
    Curry_Prelude.d_C_snd x3 cd cs
  AbstractCurry.Curry_Types.C_CLocalFunc x4 -> x2
  AbstractCurry.Curry_Types.C_CLocalPat x5 x6 -> x2
  AbstractCurry.Curry_Types.Choice_C_CLocalDecl d i l r -> narrow d i
    (d_C__case_142 x2 l cd cs) (d_C__case_142 x2 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CLocalDecl d i xs -> narrows cs d i (\z ->
    d_C__case_142 x2 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CLocalDecl d c e -> guardCons d c
    (d_C__case_142 x2 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CLocalDecl d info -> failCons d (traceFail
    "REPL._case_142" [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_142" (showCons x1))

d_C__case_143 :: Curry_Prelude.C_Bool -> Curry_Linker.C_NonDetMode -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_143 x2 x1 cd cs = case x1 of
  Curry_Linker.C_PrtChoices x3 -> Curry_Prelude.C_True
  Curry_Linker.C_DFS -> x2
  Curry_Linker.C_BFS -> x2
  Curry_Linker.C_IDS x4 -> x2
  Curry_Linker.C_Par x5 -> x2
  Curry_Linker.C_PrDFS -> x2
  Curry_Linker.C_DEBUG -> x2
  Curry_Linker.Choice_C_NonDetMode d i l r -> narrow d i (d_C__case_143 x2 l cd
    cs) (d_C__case_143 x2 r cd cs)
  Curry_Linker.Choices_C_NonDetMode d i xs -> narrows cs d i (\z ->
    d_C__case_143 x2 z cd cs) xs
  Curry_Linker.Guard_C_NonDetMode d c e -> guardCons d c (d_C__case_143 x2 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_NonDetMode d info -> failCons d (traceFail
    "REPL._case_143" [show x2, show x1] info)
  _ -> failCons cd (consFail "REPL._case_143" (showCons x1))

d_C__case_149 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> AbstractCurry.Curry_Types.C_CurryProg -> Cover
  -> ConstStore -> Curry_Prelude.C_IO C_GoalCompile
d_C__case_149 x2 x1 x4 cd cs = case x4 of
  AbstractCurry.Curry_Types.C_CurryProg x5 x6 x7 x8 x9 -> d_C__case_148 x2 x1 x4
    x8 cd cs
  AbstractCurry.Curry_Types.Choice_C_CurryProg d i l r -> narrow d i
    (d_C__case_149 x2 x1 l cd cs) (d_C__case_149 x2 x1 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CurryProg d i xs -> narrows cs d i (\z ->
    d_C__case_149 x2 x1 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CurryProg d c e -> guardCons d c
    (d_C__case_149 x2 x1 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CurryProg d info -> failCons d (traceFail
    "REPL._case_149" [show x2, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_149" (showCons x4))

d_C__case_148 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> AbstractCurry.Curry_Types.C_CurryProg
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl -> Cover
  -> ConstStore -> Curry_Prelude.C_IO C_GoalCompile
d_C__case_148 x2 x1 x4 x8 cd cs = case x8 of
  Curry_Prelude.OP_Cons x10 x11 -> d_C__case_147 x11 x2 x1 x4 x10 cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "REPL.insertFreeVarsInMainGoal") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_148 x2 x1 x4 l
    cd cs) (d_C__case_148 x2 x1 x4 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_148 x2
    x1 x4 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_148 x2 x1 x4 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_148"
    [show x2, show x1, show x4, show x8] info)
  _ -> failCons cd (consFail "REPL._case_148" (showCons x8))

d_C__case_147 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Linker.C_ReplState
  -> AbstractCurry.Curry_Types.C_CurryProg
  -> AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_GoalCompile
d_C__case_147 x11 x2 x1 x4 x10 cd cs = case x10 of
  AbstractCurry.Curry_Types.C_CFunc x12 x13 x14 x15 x16 -> d_C__case_146 x2 x10
    x15 x1 x4 x11 cd cs
  AbstractCurry.Curry_Types.C_CmtFunc x24 x25 x26 x27 x28 x29 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString "REPL.insertFreeVarsInMainGoal") cd cs
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C__case_147 x11 x2 x1 x4 l cd cs) (d_C__case_147 x11 x2 x1 x4 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C__case_147 x11 x2 x1 x4 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C__case_147 x11 x2 x1 x4 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "REPL._case_147" [show x11, show x2, show x1, show x4, show x10] info)
  _ -> failCons cd (consFail "REPL._case_147" (showCons x10))

d_C__case_146 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> AbstractCurry.Curry_Types.C_CFuncDecl
  -> AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Linker.C_ReplState
  -> AbstractCurry.Curry_Types.C_CurryProg -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO C_GoalCompile
d_C__case_146 x2 x10 x15 x1 x4 x11 cd cs = case x11 of
  Curry_Prelude.OP_List -> let x17 = d_OP_insertFreeVarsInMainGoal_dot_freeVarsInFuncRule_dot_186
                                 x10 cd cs
                               x18 = d_OP_insertFreeVarsInMainGoal_dot_breakWhereFreeClause_dot_186
                                 x2 cd cs
                               x19 = d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP15_hash_exp
                                 x18 cd cs
                               x20 = d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_selFP16_hash_whereclause
                                 x18 cd cs
    in d_C__case_145 x15 x1 x20 x17 x19 x4 (Curry_Prelude.d_OP_amp_amp
    (Curry_Linker.d_C_safeExec x1 cd cs)
    (AbstractCurry.Curry_Select.d_C_isIOType x15 cd cs) cd cs) cd cs
  Curry_Prelude.OP_Cons x22 x23 -> Curry_Prelude.d_C_error
    (Curry_Prelude.toCurryString "REPL.insertFreeVarsInMainGoal") cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_146 x2 x10 x15
    x1 x4 l cd cs) (d_C__case_146 x2 x10 x15 x1 x4 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_146 x2
    x10 x15 x1 x4 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_146 x2 x10 x15
    x1 x4 e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_146"
    [show x2, show x10, show x15, show x1, show x4, show x11] info)
  _ -> failCons cd (consFail "REPL._case_146" (showCons x11))

d_C__case_145 :: AbstractCurry.Curry_Types.C_CTypeExpr
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> AbstractCurry.Curry_Types.C_CurryProg -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO C_GoalCompile
d_C__case_145 x15 x1 x20 x17 x19 x4 x21 cd cs = case x21 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_writeErrorMsg
    (Curry_Prelude.toCurryString "Operation not allowed in safe mode!") cd cs)
    (Curry_Prelude.d_C_return C_GoalError cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_144 x20 x17 x15 x1 x19 x4
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_null x17 cd cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_C_not
    (Curry_Linker.d_C_showBindings x1 cd cs) cd cs) (Curry_Prelude.d_OP_bar_bar
    (d_OP_insertFreeVarsInMainGoal_dot_isPrtChoices_dot_186
    (Curry_Linker.d_C_ndMode x1 cd cs) cd cs) (Curry_Prelude.d_OP_bar_bar
    (AbstractCurry.Curry_Select.d_C_isIOType x15 cd cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_gt (Curry_Prelude.d_C_length
    x17 cd cs) (Curry_Prelude.C_Int 10#) cd cs) (Curry_Prelude.d_C_null x20 cd
    cs) cd cs) cd cs) cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_145 x15 x1 x20
    x17 x19 x4 l cd cs) (d_C__case_145 x15 x1 x20 x17 x19 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_145 x15
    x1 x20 x17 x19 x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_145 x15 x1 x20
    x17 x19 x4 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_145"
    [show x15, show x1, show x20, show x17, show x19, show x4, show x21] info)
  _ -> failCons cd (consFail "REPL._case_145" (showCons x21))

d_C__case_144 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  -> AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Linker.C_ReplState
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> AbstractCurry.Curry_Types.C_CurryProg -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO C_GoalCompile
d_C__case_144 x20 x17 x15 x1 x19 x4 x22 cd cs = case x22 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (C_GoalWithoutBindings x4) cd
    cs
  Curry_Prelude.C_False -> let x21 = Curry_Prelude.d_OP_dollar
                                 Curry_Prelude.d_C_unwords
                                 (Curry_Prelude.d_OP_plus_plus
                                 (Curry_Prelude.OP_Cons
                                 (Curry_Prelude.toCurryString "(")
                                 (Curry_Prelude.OP_Cons x19
                                 (Curry_Prelude.OP_Cons
                                 (Curry_Prelude.toCurryString ",[")
                                 Curry_Prelude.OP_List)))
                                 (Curry_Prelude.d_OP_plus_plus
                                 (Curry_List.d_C_intersperse
                                 (Curry_Prelude.toCurryString ",")
                                 (Curry_Prelude.d_C_map
                                 d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda105
                                 x17 cd cs) cd cs) (Curry_Prelude.d_OP_plus_plus
                                 (Curry_Prelude.OP_Cons
                                 (Curry_Prelude.toCurryString "]")
                                 Curry_Prelude.OP_List)
                                 (Curry_Prelude.d_OP_plus_plus
                                 (Curry_Prelude.d_C_map
                                 d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda106
                                 x17 cd cs) (Curry_Prelude.OP_Cons
                                 (Curry_Prelude.toCurryString ")")
                                 (Curry_Prelude.OP_Cons x20
                                 Curry_Prelude.OP_List)) cd cs) cd cs) cd cs) cd
                                 cs) cd cs
    in Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 2#))
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Adding printing of bindings for free variables: ")
    (Curry_List.d_C_intercalate (Curry_Prelude.toCurryString ",") x17 cd cs) cd
    cs) cd cs) (Curry_Prelude.d_OP_gt_gt (d_C_writeSimpleMainGoalFile x1 x21 cd
    cs) (Curry_Prelude.d_OP_gt_gt_eq (d_C_getAcyOfMainGoal x1 cd cs)
    (d_OP_insertFreeVarsInMainGoal_dot_uscore_hash_lambda107 x17 x21) cd cs) cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_144 x20 x17 x15
    x1 x19 x4 l cd cs) (d_C__case_144 x20 x17 x15 x1 x19 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_144 x20
    x17 x15 x1 x19 x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_144 x20 x17 x15
    x1 x19 x4 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_144"
    [show x20, show x17, show x15, show x1, show x19, show x4, show x22] info)
  _ -> failCons cd (consFail "REPL._case_144" (showCons x22))

d_C__case_150 :: Curry_Prelude.C_Bool -> Curry_Prelude.C_Int
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Maybe Curry_Prelude.C_Int
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
d_C__case_150 x6 x5 x4 x1 x3 x2 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> Curry_Linker.d_C_createAndCompileMain x4 x2 x3 x1 cd
    cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2
    (Curry_Linker.d_C_setExitStatus (Curry_Prelude.C_Int 1#) x4 cd cs)
    Curry_Linker.C_MainError) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_150 x6 x5 x4 x1
    x3 x2 l cd cs) (d_C__case_150 x6 x5 x4 x1 x3 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_150 x6
    x5 x4 x1 x3 x2 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_150 x6 x5 x4 x1
    x3 x2 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_150"
    [show x6, show x5, show x4, show x1, show x3, show x2, show x7] info)
  _ -> failCons cd (consFail "REPL._case_150" (showCons x7))

d_C__case_152 :: C_GoalCompile -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile)
d_C__case_152 x5 x2 x4 x3 x1 x14 cd cs = case x14 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return (Curry_Prelude.OP_Tuple2
    (Curry_Linker.d_C_setExitStatus (Curry_Prelude.C_Int 1#) x4 cd cs)
    Curry_Linker.C_MainError) cd cs
  Curry_Prelude.C_False -> let x6 = d_C__case_151 x2 x5 cd cs
                               x11 = d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP11_hash_newprog
                                 x6 cd cs
                               x12 = d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP12_hash_newgoal
                                 x6 cd cs
                               x13 = d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_selFP13_hash_bindings
                                 x6 cd cs
    in Curry_Prelude.d_OP_gt_gt_eq (d_C_makeMainGoalMonomorphic x4 x11 x12 cd
    cs)
    (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda94_dot_uscore_hash_lambda96
    x13 x1 x2 x3 x4) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_152 x5 x2 x4 x3
    x1 l cd cs) (d_C__case_152 x5 x2 x4 x3 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_152 x5
    x2 x4 x3 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_152 x5 x2 x4 x3
    x1 e cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_152"
    [show x5, show x2, show x4, show x3, show x1, show x14] info)
  _ -> failCons cd (consFail "REPL._case_152" (showCons x14))

d_C__case_151 :: Curry_Prelude.OP_List Curry_Prelude.C_Char -> C_GoalCompile
  -> Cover -> ConstStore -> Curry_Prelude.OP_Tuple3
  AbstractCurry.Curry_Types.C_CurryProg (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) (Curry_Prelude.C_Maybe Curry_Prelude.C_Int)
d_C__case_151 x2 x5 cd cs = case x5 of
  C_GoalWithBindings x7 x8 x9 -> Curry_Prelude.OP_Tuple3 x7 x9
    (Curry_Prelude.C_Just x8)
  C_GoalWithoutBindings x10 -> Curry_Prelude.OP_Tuple3 x10 x2
    Curry_Prelude.C_Nothing
  C_GoalError -> Curry_Prelude.d_C_error (Curry_Prelude.toCurryString
    "REPL.compileProgramWithGoal") cd cs
  Choice_C_GoalCompile d i l r -> narrow d i (d_C__case_151 x2 l cd cs)
    (d_C__case_151 x2 r cd cs)
  Choices_C_GoalCompile d i xs -> narrows cs d i (\z -> d_C__case_151 x2 z cd
    cs) xs
  Guard_C_GoalCompile d c e -> guardCons d c (d_C__case_151 x2 e cd $! addCs c
    cs)
  Fail_C_GoalCompile d info -> failCons d (traceFail "REPL._case_151" [show x2
    , show x5] info)
  _ -> failCons cd (consFail "REPL._case_151" (showCons x5))

d_C__case_153 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
d_C__case_153 x1 x5 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq (d_C_importUnsafeModule x1
    cd cs) (d_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x5 x1) cd cs
  Curry_Prelude.C_False -> x5
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_153 x1 x5 l cd
    cs) (d_C__case_153 x1 x5 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_153 x1
    x5 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_153 x1 x5 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_153"
    [show x1, show x5, show x6] info)
  _ -> failCons cd (consFail "REPL._case_153" (showCons x6))

nd_C__case_153 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_IO
  (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState Curry_Linker.C_MainCompile)
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO (Curry_Prelude.OP_Tuple2 Curry_Linker.C_ReplState
  Curry_Linker.C_MainCompile)
nd_C__case_153 x1 x5 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt_eq (d_C_importUnsafeModule x1 cd cs)
    (wrapNX id (nd_OP_compileProgramWithGoal_dot_uscore_hash_lambda99 x5 x1)) s0
    cd cs
  Curry_Prelude.C_False -> x5
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_153 x1 x5 l s cd
    cs) (nd_C__case_153 x1 x5 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_153 x1
    x5 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_153 x1 x5 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_153"
    [show x1, show x5, show x6] info)
  _ -> failCons cd (consFail "REPL._case_153" (showCons x6))

d_C__case_156 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl
  -> Cover -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_156 x5 cd cs = case x5 of
  Curry_Prelude.OP_Cons x7 x8 -> d_C__case_155 x8 x7 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_156 l cd cs)
    (d_C__case_156 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_156 z
    cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_156 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_156"
    [show x5] info)
  _ -> failCons cd (consFail "REPL._case_156" (showCons x5))

d_C__case_155 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl
  -> AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_155 x8 x7 cd cs = case x7 of
  AbstractCurry.Curry_Types.C_CFunc x9 x10 x11 x12 x13 -> d_C__case_154 x13 x8
    cd cs
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C__case_155 x8 l cd cs) (d_C__case_155 x8 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C__case_155 x8 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C__case_155 x8 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "REPL._case_155" [show x8, show x7] info)
  _ -> failCons cd (consFail "REPL._case_155" (showCons x7))

d_C__case_154 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_154 x13 x8 cd cs = case x8 of
  Curry_Prelude.OP_List -> d_OP_getModuleOfFunction_dot_modOfMain_dot_134 x13 cd
    cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_154 x13 l cd cs)
    (d_C__case_154 x13 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_154
    x13 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_154 x13 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_154"
    [show x13, show x8] info)
  _ -> failCons cd (consFail "REPL._case_154" (showCons x8))

d_C__case_170 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> AbstractCurry.Curry_Types.C_CRule -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_170 x3 x2 cd cs = case x2 of
  AbstractCurry.Curry_Types.C_CRule x4 x5 -> d_C__case_169 x5 x3 x4 cd cs
  AbstractCurry.Curry_Types.Choice_C_CRule d i l r -> narrow d i (d_C__case_170
    x3 l cd cs) (d_C__case_170 x3 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CRule d i xs -> narrows cs d i (\z ->
    d_C__case_170 x3 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CRule d c e -> guardCons d c (d_C__case_170
    x3 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CRule d info -> failCons d (traceFail
    "REPL._case_170" [show x3, show x2] info)
  _ -> failCons cd (consFail "REPL._case_170" (showCons x2))

d_C__case_169 :: AbstractCurry.Curry_Types.C_CRhs -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CRule -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CPattern -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_169 x5 x3 x4 cd cs = case x4 of
  Curry_Prelude.OP_List -> d_C__case_168 x3 x5 cd cs
  Curry_Prelude.OP_Cons x72 x73 -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_169 x5 x3 l cd
    cs) (d_C__case_169 x5 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_169 x5
    x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_169 x5 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_169"
    [show x5, show x3, show x4] info)
  _ -> failCons cd (consFail "REPL._case_169" (showCons x4))

d_C__case_168 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> AbstractCurry.Curry_Types.C_CRhs -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_168 x3 x5 cd cs = case x5 of
  AbstractCurry.Curry_Types.C_CSimpleRhs x6 x7 -> let x8 = Curry_Prelude.OP_List
    in d_C__case_167 x8 x7 x3 x6 cd cs
  AbstractCurry.Curry_Types.C_CGuardedRhs x36 x37 -> d_C__case_163 x37 x3 x36 cd
    cs
  AbstractCurry.Curry_Types.Choice_C_CRhs d i l r -> narrow d i (d_C__case_168
    x3 l cd cs) (d_C__case_168 x3 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CRhs d i xs -> narrows cs d i (\z ->
    d_C__case_168 x3 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CRhs d c e -> guardCons d c (d_C__case_168
    x3 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CRhs d info -> failCons d (traceFail
    "REPL._case_168" [show x3, show x5] info)
  _ -> failCons cd (consFail "REPL._case_168" (showCons x5))

d_C__case_163 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  AbstractCurry.Curry_Types.C_CExpr AbstractCurry.Curry_Types.C_CExpr) -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_163 x37 x3 x36 cd cs = case x36 of
  Curry_Prelude.OP_Cons x38 x39 -> d_C__case_162 x39 x37 x3 x38 cd cs
  Curry_Prelude.OP_List -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_163 x37 x3 l cd
    cs) (d_C__case_163 x37 x3 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_163
    x37 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_163 x37 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_163"
    [show x37, show x3, show x36] info)
  _ -> failCons cd (consFail "REPL._case_163" (showCons x36))

d_C__case_162 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  AbstractCurry.Curry_Types.C_CExpr AbstractCurry.Curry_Types.C_CExpr)
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_Tuple2 AbstractCurry.Curry_Types.C_CExpr
  AbstractCurry.Curry_Types.C_CExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_162 x39 x37 x3 x38 cd cs = case x38 of
  Curry_Prelude.OP_Tuple2 x40 x41 -> let x42 = Curry_Prelude.OP_List
    in d_C__case_161 x42 x39 x37 x3 x41 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_162 x39 x37 x3
    l cd cs) (d_C__case_162 x39 x37 x3 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_162
    x39 x37 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_162 x39 x37 x3
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_162"
    [show x39, show x37, show x3, show x38] info)
  _ -> failCons cd (consFail "REPL._case_162" (showCons x38))

d_C__case_161 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  AbstractCurry.Curry_Types.C_CExpr AbstractCurry.Curry_Types.C_CExpr)
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> AbstractCurry.Curry_Types.C_CExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_161 x42 x39 x37 x3 x41 cd cs = case x41 of
  AbstractCurry.Curry_Types.C_CSymbol x43 -> d_C__case_160 x39 x37 x3 x43 cd cs
  AbstractCurry.Curry_Types.C_CVar x52 -> x42
  AbstractCurry.Curry_Types.C_CLit x53 -> x42
  AbstractCurry.Curry_Types.C_CApply x54 x55 -> x42
  AbstractCurry.Curry_Types.C_CLambda x56 x57 -> x42
  AbstractCurry.Curry_Types.C_CLetDecl x58 x59 -> x42
  AbstractCurry.Curry_Types.C_CDoExpr x60 -> x42
  AbstractCurry.Curry_Types.C_CListComp x61 x62 -> x42
  AbstractCurry.Curry_Types.C_CCase x63 x64 x65 -> x42
  AbstractCurry.Curry_Types.C_CTyped x66 x67 -> x42
  AbstractCurry.Curry_Types.C_CRecConstr x68 x69 -> x42
  AbstractCurry.Curry_Types.C_CRecUpdate x70 x71 -> x42
  AbstractCurry.Curry_Types.Choice_C_CExpr d i l r -> narrow d i (d_C__case_161
    x42 x39 x37 x3 l cd cs) (d_C__case_161 x42 x39 x37 x3 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CExpr d i xs -> narrows cs d i (\z ->
    d_C__case_161 x42 x39 x37 x3 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CExpr d c e -> guardCons d c (d_C__case_161
    x42 x39 x37 x3 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CExpr d info -> failCons d (traceFail
    "REPL._case_161" [show x42, show x39, show x37, show x3, show x41] info)
  _ -> failCons cd (consFail "REPL._case_161" (showCons x41))

d_C__case_160 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  AbstractCurry.Curry_Types.C_CExpr AbstractCurry.Curry_Types.C_CExpr)
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_160 x39 x37 x3 x43 cd cs = case x43 of
  Curry_Prelude.OP_Tuple2 x44 x45 -> d_C__case_159 x37 x3 x44 x39 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_160 x39 x37 x3
    l cd cs) (d_C__case_160 x39 x37 x3 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_160
    x39 x37 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_160 x39 x37 x3
    e cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_160"
    [show x39, show x37, show x3, show x43] info)
  _ -> failCons cd (consFail "REPL._case_160" (showCons x43))

d_C__case_159 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_Tuple2 AbstractCurry.Curry_Types.C_CExpr
  AbstractCurry.Curry_Types.C_CExpr) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_159 x37 x3 x44 x39 cd cs = case x39 of
  Curry_Prelude.OP_List -> d_C__case_158 x3 x44 x37 cd cs
  Curry_Prelude.OP_Cons x50 x51 -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_159 x37 x3 x44 l
    cd cs) (d_C__case_159 x37 x3 x44 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_159
    x37 x3 x44 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_159 x37 x3 x44 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_159"
    [show x37, show x3, show x44, show x39] info)
  _ -> failCons cd (consFail "REPL._case_159" (showCons x39))

d_C__case_158 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CLocalDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_158 x3 x44 x37 cd cs = case x37 of
  Curry_Prelude.OP_List -> d_C__case_157 x44 x3 cd cs
  Curry_Prelude.OP_Cons x48 x49 -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_158 x3 x44 l cd
    cs) (d_C__case_158 x3 x44 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_158 x3
    x44 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_158 x3 x44 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_158"
    [show x3, show x44, show x37] info)
  _ -> failCons cd (consFail "REPL._case_158" (showCons x37))

d_C__case_157 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_157 x44 x3 cd cs = case x3 of
  Curry_Prelude.OP_List -> x44
  Curry_Prelude.OP_Cons x46 x47 -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_157 x44 l cd cs)
    (d_C__case_157 x44 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_157
    x44 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_157 x44 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_157"
    [show x44, show x3] info)
  _ -> failCons cd (consFail "REPL._case_157" (showCons x3))

d_C__case_167 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> AbstractCurry.Curry_Types.C_CExpr -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_167 x8 x7 x3 x6 cd cs = case x6 of
  AbstractCurry.Curry_Types.C_CSymbol x9 -> d_C__case_166 x7 x3 x9 cd cs
  AbstractCurry.Curry_Types.C_CVar x16 -> x8
  AbstractCurry.Curry_Types.C_CLit x17 -> x8
  AbstractCurry.Curry_Types.C_CApply x18 x19 -> x8
  AbstractCurry.Curry_Types.C_CLambda x20 x21 -> x8
  AbstractCurry.Curry_Types.C_CLetDecl x22 x23 -> x8
  AbstractCurry.Curry_Types.C_CDoExpr x24 -> x8
  AbstractCurry.Curry_Types.C_CListComp x25 x26 -> x8
  AbstractCurry.Curry_Types.C_CCase x27 x28 x29 -> x8
  AbstractCurry.Curry_Types.C_CTyped x30 x31 -> x8
  AbstractCurry.Curry_Types.C_CRecConstr x32 x33 -> x8
  AbstractCurry.Curry_Types.C_CRecUpdate x34 x35 -> x8
  AbstractCurry.Curry_Types.Choice_C_CExpr d i l r -> narrow d i (d_C__case_167
    x8 x7 x3 l cd cs) (d_C__case_167 x8 x7 x3 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CExpr d i xs -> narrows cs d i (\z ->
    d_C__case_167 x8 x7 x3 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CExpr d c e -> guardCons d c (d_C__case_167
    x8 x7 x3 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CExpr d info -> failCons d (traceFail
    "REPL._case_167" [show x8, show x7, show x3, show x6] info)
  _ -> failCons cd (consFail "REPL._case_167" (showCons x6))

d_C__case_166 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CLocalDecl
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_Tuple2 (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_166 x7 x3 x9 cd cs = case x9 of
  Curry_Prelude.OP_Tuple2 x10 x11 -> d_C__case_165 x3 x10 x7 cd cs
  Curry_Prelude.Choice_OP_Tuple2 d i l r -> narrow d i (d_C__case_166 x7 x3 l cd
    cs) (d_C__case_166 x7 x3 r cd cs)
  Curry_Prelude.Choices_OP_Tuple2 d i xs -> narrows cs d i (\z -> d_C__case_166
    x7 x3 z cd cs) xs
  Curry_Prelude.Guard_OP_Tuple2 d c e -> guardCons d c (d_C__case_166 x7 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_Tuple2 d info -> failCons d (traceFail "REPL._case_166"
    [show x7, show x3, show x9] info)
  _ -> failCons cd (consFail "REPL._case_166" (showCons x9))

d_C__case_165 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CLocalDecl -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_165 x3 x10 x7 cd cs = case x7 of
  Curry_Prelude.OP_List -> d_C__case_164 x10 x3 cd cs
  Curry_Prelude.OP_Cons x14 x15 -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_165 x3 x10 l cd
    cs) (d_C__case_165 x3 x10 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_165 x3
    x10 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_165 x3 x10 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_165"
    [show x3, show x10, show x7] info)
  _ -> failCons cd (consFail "REPL._case_165" (showCons x7))

d_C__case_164 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CRule -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_164 x10 x3 cd cs = case x3 of
  Curry_Prelude.OP_List -> x10
  Curry_Prelude.OP_Cons x12 x13 -> Curry_Prelude.OP_List
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_164 x10 l cd cs)
    (d_C__case_164 x10 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_164
    x10 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_164 x10 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_164"
    [show x10, show x3] info)
  _ -> failCons cd (consFail "REPL._case_164" (showCons x3))

d_C__case_171 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char
d_C__case_171 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> x2
  Curry_Prelude.C_False -> Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '('#)
    (Curry_Prelude.d_OP_plus_plus x2 (Curry_Prelude.toCurryString ")") cd cs)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_171 x2 l cd cs)
    (d_C__case_171 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_171 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_171 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_171"
    [show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_171" (showCons x3))

d_C__case_174 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_174 x1 x6 cd cs = case x6 of
  Curry_Prelude.OP_Cons x8 x9 -> d_C__case_173 x9 x1 x8 cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_174 x1 l cd cs)
    (d_C__case_174 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_174 x1
    z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_174 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_174"
    [show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_174" (showCons x6))

d_C__case_173 :: Curry_Prelude.OP_List AbstractCurry.Curry_Types.C_CFuncDecl
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_173 x9 x1 x8 cd cs = case x8 of
  AbstractCurry.Curry_Types.C_CFunc x10 x11 x12 x13 x14 -> d_C__case_172 x13 x1
    x9 cd cs
  AbstractCurry.Curry_Types.Choice_C_CFuncDecl d i l r -> narrow d i
    (d_C__case_173 x9 x1 l cd cs) (d_C__case_173 x9 x1 r cd cs)
  AbstractCurry.Curry_Types.Choices_C_CFuncDecl d i xs -> narrows cs d i (\z ->
    d_C__case_173 x9 x1 z cd cs) xs
  AbstractCurry.Curry_Types.Guard_C_CFuncDecl d c e -> guardCons d c
    (d_C__case_173 x9 x1 e cd $! addCs c cs)
  AbstractCurry.Curry_Types.Fail_C_CFuncDecl d info -> failCons d (traceFail
    "REPL._case_173" [show x9, show x1, show x8] info)
  _ -> failCons cd (consFail "REPL._case_173" (showCons x8))

d_C__case_172 :: AbstractCurry.Curry_Types.C_CTypeExpr -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  AbstractCurry.Curry_Types.C_CFuncDecl -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_172 x13 x1 x9 cd cs = case x9 of
  Curry_Prelude.OP_List -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_dollar
    Curry_Prelude.d_C_putStrLn (Curry_Prelude.d_OP_plus_plus x1
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString " :: ")
    (Curry_Utils.d_C_showMonoTypeExpr Curry_Prelude.C_False x13 cd cs) cd cs) cd
    cs) cd cs) (Curry_Prelude.d_C_return Curry_Prelude.C_True cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_172 x13 x1 l cd
    cs) (d_C__case_172 x13 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_172
    x13 x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_172 x13 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_172"
    [show x13, show x1, show x9] info)
  _ -> failCons cd (consFail "REPL._case_172" (showCons x9))

d_C__case_175 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.C_Bool
d_C__case_175 x1 x4 cd cs = case x4 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return Curry_Prelude.C_True cd cs
  Curry_Prelude.C_False -> let x2 = FlatCurry.Curry_Files.d_C_flatCurryFileName
                                 (Curry_Linker.d_C_mainMod x1 cd cs) cd cs
                               x3 = d_C_currentFrontendParams x1 cd cs
    in Curry_Prelude.d_C_catch (Curry_Prelude.d_OP_gt_gt_eq
    (Curry_Prelude.d_OP_gt_gt (Curry_Distribution.d_C_callFrontendWithParams
    Curry_Distribution.C_FCY x3 (Curry_Linker.d_C_mainMod x1 cd cs) cd cs)
    (FlatCurry.Curry_Files.d_C_readFlatCurryFile x2 cd cs) cd cs)
    d_OP_importUnsafeModule_dot_uscore_hash_lambda83 cd cs)
    (d_OP_importUnsafeModule_dot_uscore_hash_lambda84 x1) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_175 x1 l cd cs)
    (d_C__case_175 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_175 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_175 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_175"
    [show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_175" (showCons x4))

d_C__case_176 :: Curry_Linker.C_ReplState -> Curry_Linker.C_MainCompile
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Linker.C_ReplState
d_C__case_176 x3 x4 x1 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> Curry_Prelude.d_C_return x3 cd cs
  Curry_Prelude.C_False -> d_C_execMain x3 x4 x1 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_176 x3 x4 x1 l cd
    cs) (d_C__case_176 x3 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_176 x3
    x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_176 x3 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_176"
    [show x3, show x4, show x1, show x5] info)
  _ -> failCons cd (consFail "REPL._case_176" (showCons x5))

d_C__case_177 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_177 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> d_C_cleanUpAndExitRepl x1 cd cs
  Curry_Prelude.C_False -> d_C_repl x1 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_177 x1 l cd cs)
    (d_C__case_177 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_177 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_177 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_177"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_177" (showCons x2))

d_C__case_180 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_180 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> d_C_repl x1 cd cs
  Curry_Prelude.C_False -> d_C__case_179 x2 x1 (d_C_isCommand x2 cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_180 x2 x1 l cd
    cs) (d_C__case_180 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_180 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_180 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_180"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_180" (showCons x3))

d_C__case_179 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_179 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq (d_C_processCommand x1
    (Curry_Prelude.d_C_apply (Curry_Utils.d_C_strip cd cs)
    (Curry_Prelude.d_C_tail x2 cd cs) cd cs) cd cs)
    (d_OP_processInput_dot_uscore_hash_lambda79 x1) cd cs
  Curry_Prelude.C_False -> d_C__case_178 x2 x1 (Curry_Prelude.d_C_otherwise cd
    cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_179 x2 x1 l cd
    cs) (d_C__case_179 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_179 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_179 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_179"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_179" (showCons x3))

d_C__case_178 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_178 x2 x1 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt_eq (d_C_evalExpression x1 x2
    cd cs) d_C_repl cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_178 x2 x1 l cd
    cs) (d_C__case_178 x2 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_178 x2
    x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_178 x2 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_178"
    [show x2, show x1, show x3] info)
  _ -> failCons cd (consFail "REPL._case_178" (showCons x3))

d_C__case_184 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Cover
  -> ConstStore -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_184 x3 x1 x4 cd cs = case x4 of
  Curry_Prelude.OP_List -> Curry_Prelude.OP_Cons x3 Curry_Prelude.OP_List
  Curry_Prelude.OP_Cons x5 x6 -> d_C__case_183 x3 x6 x5 x1
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.C_Char '%'#) cd cs) cd cs
  Curry_Prelude.Choice_OP_List d i l r -> narrow d i (d_C__case_184 x3 x1 l cd
    cs) (d_C__case_184 x3 x1 r cd cs)
  Curry_Prelude.Choices_OP_List d i xs -> narrows cs d i (\z -> d_C__case_184 x3
    x1 z cd cs) xs
  Curry_Prelude.Guard_OP_List d c e -> guardCons d c (d_C__case_184 x3 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_OP_List d info -> failCons d (traceFail "REPL._case_184"
    [show x3, show x1, show x4] info)
  _ -> failCons cd (consFail "REPL._case_184" (showCons x4))

d_C__case_183 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_183 x3 x6 x5 x1 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> d_C__case_182 x5 x6 x1 x3 (Curry_Prelude.d_OP_eq_eq x5
    (Curry_Prelude.C_Char '%'#) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.OP_Cons x3
    (d_OP_calcPrompt_dot_subst_dot_58 x1 (Curry_Prelude.OP_Cons x5 x6) cd cs)
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_183 x3 x6 x5 x1 l
    cd cs) (d_C__case_183 x3 x6 x5 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_183 x3
    x6 x5 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_183 x3 x6 x5 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_183"
    [show x3, show x6, show x5, show x1, show x7] info)
  _ -> failCons cd (consFail "REPL._case_183" (showCons x7))

d_C__case_182 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_182 x5 x6 x1 x3 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_Cons (Curry_Prelude.C_Char '%'#) x6
  Curry_Prelude.C_False -> d_C__case_181 x5 x6 x1 x3 (Curry_Prelude.d_OP_eq_eq
    x5 (Curry_Prelude.C_Char 's'#) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_182 x5 x6 x1 x3 l
    cd cs) (d_C__case_182 x5 x6 x1 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_182 x5
    x6 x1 x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_182 x5 x6 x1 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_182"
    [show x5, show x6, show x1, show x3, show x7] info)
  _ -> failCons cd (consFail "REPL._case_182" (showCons x7))

d_C__case_181 :: Curry_Prelude.C_Char -> Curry_Prelude.OP_List
  Curry_Prelude.C_Char -> Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_181 x5 x6 x1 x3 x7 cd cs = case x7 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_plus_plus x1
    (d_OP_calcPrompt_dot_subst_dot_58 x1 x6 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.OP_Cons x3 (Curry_Prelude.OP_Cons x5
    (d_OP_calcPrompt_dot_subst_dot_58 x1 x6 cd cs))
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_181 x5 x6 x1 x3 l
    cd cs) (d_C__case_181 x5 x6 x1 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_181 x5
    x6 x1 x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_181 x5 x6 x1 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_181"
    [show x5, show x6, show x1, show x3, show x7] info)
  _ -> failCons cd (consFail "REPL._case_181" (showCons x7))

d_C__case_185 :: Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_185 x1 cd cs = case x1 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.toCurryString "-b") (Curry_Prelude.d_C_show
    (Curry_Installation.d_C_buildVersion cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_185 l cd cs)
    (d_C__case_185 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_185 z
    cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_185 e cd $! addCs
    c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_185"
    [show x1] info)
  _ -> failCons cd (consFail "REPL._case_185" (showCons x1))

d_C__case_186 :: Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_Bool
d_C__case_186 x2 x3 cd cs = case x3 of
  Curry_Prelude.C_True -> Curry_Prelude.C_True
  Curry_Prelude.C_False -> Curry_Prelude.C_False
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_186 x2 l cd cs)
    (d_C__case_186 x2 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_186 x2
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_186 x2 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_186"
    [show x2, show x3] info)
  _ -> failCons cd (consFail "REPL._case_186" (showCons x3))

d_C__case_195 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_195 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_processArgsAndStart x1 x4 cd cs
  Curry_Prelude.C_False -> d_C__case_194 x3 x5 x4 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "--nocypm") cd cs)
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "--noreadline") cd
    cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_195 x3 x5 x4 x1 l
    cd cs) (d_C__case_195 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_195 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_195 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_195"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_195" (showCons x6))

nd_C__case_195 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_195 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_processArgsAndStart x1 x4 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_194 x3 x5 x4 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "--nocypm") cd cs)
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "--noreadline") cd
    cs) cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_195 x3 x5 x4 x1
    l s cd cs) (nd_C__case_195 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_195 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_195 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_195"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_195" (showCons x6))

d_C__case_194 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_194 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_processArgsAndStart x1 x4 cd cs
  Curry_Prelude.C_False -> d_C__case_193 x3 x5 x4 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "-V") cd cs)
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "--version") cd
    cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_194 x3 x5 x4 x1 l
    cd cs) (d_C__case_194 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_194 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_194 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_194"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_194" (showCons x6))

nd_C__case_194 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_194 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> d_C_processArgsAndStart x1 x4 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_193 x3 x5 x4 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "-V") cd cs)
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "--version") cd
    cs) cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_194 x3 x5 x4 x1
    l s cd cs) (nd_C__case_194 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_194 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_194 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_194"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_194" (showCons x6))

d_C__case_193 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_193 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_gt_gt_eq
    (d_C_getBanner cd cs) Curry_Prelude.d_C_putStrLn cd cs)
    (d_C_cleanUpAndExitRepl x1 cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_192 x3 x5 x4 x1 (Curry_Prelude.d_OP_eq_eq
    x3 (Curry_Prelude.toCurryString "--compiler-name") cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_193 x3 x5 x4 x1 l
    cd cs) (d_C__case_193 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_193 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_193 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_193"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_193" (showCons x6))

nd_C__case_193 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_193 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s2 = s
    in s2 `seq` (let s1 = leftSupply s2
                     s0 = rightSupply s2
    in s1 `seq` (s0 `seq` Curry_Prelude.nd_OP_gt_gt
    (Curry_Prelude.nd_OP_gt_gt_eq (d_C_getBanner cd cs) (wrapDX id
    Curry_Prelude.d_C_putStrLn) s0 cd cs) (d_C_cleanUpAndExitRepl x1 cd cs) s1
    cd cs))
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_192 x3 x5 x4 x1 (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "--compiler-name") cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_193 x3 x5 x4 x1
    l s cd cs) (nd_C__case_193 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_193 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_193 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_193"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_193" (showCons x6))

d_C__case_192 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_192 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_putStrLn
    (Curry_Prelude.toCurryString "kics2") cd cs) (d_C_cleanUpAndExitRepl x1 cd
    cs) cd cs
  Curry_Prelude.C_False -> d_C__case_191 x3 x5 x4 x1 (Curry_Prelude.d_OP_eq_eq
    x3 (Curry_Prelude.toCurryString "--numeric-version") cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_192 x3 x5 x4 x1 l
    cd cs) (d_C__case_192 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_192 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_192 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_192"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_192" (showCons x6))

nd_C__case_192 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_192 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt (Curry_Prelude.d_C_putStrLn
    (Curry_Prelude.toCurryString "kics2") cd cs) (d_C_cleanUpAndExitRepl x1 cd
    cs) s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_191 x3 x5 x4 x1 (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "--numeric-version") cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_192 x3 x5 x4 x1
    l s cd cs) (nd_C__case_192 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_192 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_192 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_192"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_192" (showCons x6))

d_C__case_191 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_191 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_putStrLn
    (d_C_numericVersion cd cs) cd cs) (d_C_cleanUpAndExitRepl x1 cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_190 x3 x5 x4 x1 (Curry_Prelude.d_OP_eq_eq
    x3 (Curry_Prelude.toCurryString "--base-version") cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_191 x3 x5 x4 x1 l
    cd cs) (d_C__case_191 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_191 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_191 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_191"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_191" (showCons x6))

nd_C__case_191 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_191 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt (Curry_Prelude.d_C_putStrLn
    (d_C_numericVersion cd cs) cd cs) (d_C_cleanUpAndExitRepl x1 cd cs) s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_190 x3 x5 x4 x1 (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "--base-version") cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_191 x3 x5 x4 x1
    l s cd cs) (nd_C__case_191 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_191 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_191 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_191"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_191" (showCons x6))

d_C__case_190 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_190 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_C_putStrLn
    (Curry_Prelude.toCurryString "0.0.0") cd cs) (d_C_cleanUpAndExitRepl x1 cd
    cs) cd cs
  Curry_Prelude.C_False -> d_C__case_189 x3 x5 x4 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "-h") cd cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "--help") cd cs) (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "-?") cd cs) cd cs) cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_190 x3 x5 x4 x1 l
    cd cs) (d_C__case_190 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_190 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_190 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_190"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_190" (showCons x6))

nd_C__case_190 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_190 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt (Curry_Prelude.d_C_putStrLn
    (Curry_Prelude.toCurryString "0.0.0") cd cs) (d_C_cleanUpAndExitRepl x1 cd
    cs) s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_189 x3 x5 x4 x1 (Curry_Prelude.d_OP_bar_bar
    (Curry_Prelude.d_OP_eq_eq x3 (Curry_Prelude.toCurryString "-h") cd cs)
    (Curry_Prelude.d_OP_bar_bar (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "--help") cd cs) (Curry_Prelude.d_OP_eq_eq x3
    (Curry_Prelude.toCurryString "-?") cd cs) cd cs) cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_190 x3 x5 x4 x1
    l s cd cs) (nd_C__case_190 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_190 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_190 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_190"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_190" (showCons x6))

d_C__case_189 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_189 x3 x5 x4 x1 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt x5 (d_C_cleanUpAndExitRepl x1
    cd cs) cd cs
  Curry_Prelude.C_False -> d_C__case_188 x3 x5 x4 x1 (d_C_isCommand x3 cd cs) cd
    cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_189 x3 x5 x4 x1 l
    cd cs) (d_C__case_189 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_189 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_189 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_189"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_189" (showCons x6))

nd_C__case_189 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_189 x3 x5 x4 x1 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt x5 (d_C_cleanUpAndExitRepl x1 cd cs)
    s0 cd cs
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_188 x3 x5 x4 x1 (d_C_isCommand x3 cd cs) s0 cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_189 x3 x5 x4 x1
    l s cd cs) (nd_C__case_189 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_189 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_189 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_189"
    [show x3, show x5, show x4, show x1, show x6] info)
  _ -> failCons cd (consFail "REPL._case_189" (showCons x6))

d_C__case_188 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> Cover -> ConstStore -> Curry_Prelude.C_IO
  Curry_Prelude.OP_Unit
d_C__case_188 x3 x5 x4 x1 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> let x6 = Curry_Prelude.d_C_apply
                                (Curry_Prelude.d_C_break d_C_isCommand cd cs) x4
                                cd cs
                              x7 = d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs
                                x6 cd cs
                              x8 = d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more
                                x6 cd cs
    in Curry_Prelude.d_OP_gt_gt_eq (d_C_processCommand x1
    (Curry_Prelude.d_C_tail (Curry_Prelude.d_C_unwords (Curry_Prelude.OP_Cons x3
    x7) cd cs) cd cs) cd cs) (d_OP_processArgsAndStart_dot_uscore_hash_lambda72
    x8 x5) cd cs
  Curry_Prelude.C_False -> d_C__case_187 x5 x4 x3 (Curry_Prelude.d_C_otherwise
    cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_188 x3 x5 x4 x1 l
    cd cs) (d_C__case_188 x3 x5 x4 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_188 x3
    x5 x4 x1 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_188 x3 x5 x4 x1 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_188"
    [show x3, show x5, show x4, show x1, show x9] info)
  _ -> failCons cd (consFail "REPL._case_188" (showCons x9))

nd_C__case_188 :: Curry_Prelude.OP_List Curry_Prelude.C_Char
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState
  -> Curry_Prelude.C_Bool -> IDSupply -> Cover -> ConstStore
  -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_188 x3 x5 x4 x1 x9 s cd cs = case x9 of
  Curry_Prelude.C_True -> let s4 = s
    in s4 `seq` (let s2 = leftSupply s4
                     s3 = rightSupply s4
    in s2 `seq` (s3 `seq` (let x6 = let s1 = leftSupply s2
                                        s0 = rightSupply s2
                                 in s1 `seq` (s0 `seq` Curry_Prelude.nd_C_apply
                                 (Curry_Prelude.nd_C_break (wrapDX id
                                 d_C_isCommand) s0 cd cs) x4 s1 cd cs)
                               x7 = d_OP_processArgsAndStart_dot_uscore_hash_selFP8_hash_cmdargs
                                 x6 cd cs
                               x8 = d_OP_processArgsAndStart_dot_uscore_hash_selFP9_hash_more
                                 x6 cd cs
    in Curry_Prelude.nd_OP_gt_gt_eq (d_C_processCommand x1
    (Curry_Prelude.d_C_tail (Curry_Prelude.d_C_unwords (Curry_Prelude.OP_Cons x3
    x7) cd cs) cd cs) cd cs) (wrapNX id
    (nd_OP_processArgsAndStart_dot_uscore_hash_lambda72 x8 x5)) s3 cd cs)))
  Curry_Prelude.C_False -> let s0 = s
    in s0 `seq` nd_C__case_187 x5 x4 x3 (Curry_Prelude.d_C_otherwise cd cs) s0
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_188 x3 x5 x4 x1
    l s cd cs) (nd_C__case_188 x3 x5 x4 x1 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_188 x3
    x5 x4 x1 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_188 x3 x5 x4 x1
    e s cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_188"
    [show x3, show x5, show x4, show x1, show x9] info)
  _ -> failCons cd (consFail "REPL._case_188" (showCons x9))

d_C__case_187 :: Curry_Prelude.C_IO Curry_Prelude.OP_Unit
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_187 x5 x4 x3 x6 cd cs = case x6 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (d_C_writeErrorMsg
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "unknown command: ") (Curry_Prelude.d_C_unwords (Curry_Prelude.OP_Cons x3
    x4) cd cs) cd cs) cd cs) x5 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_187 x5 x4 x3 l cd
    cs) (d_C__case_187 x5 x4 x3 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_187 x5
    x4 x3 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_187 x5 x4 x3 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_187"
    [show x5, show x4, show x3, show x6] info)
  _ -> failCons cd (consFail "REPL._case_187" (showCons x6))

nd_C__case_187 :: Curry_Prelude.C_IO Curry_Prelude.OP_Unit
  -> Curry_Prelude.OP_List (Curry_Prelude.OP_List Curry_Prelude.C_Char)
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char -> Curry_Prelude.C_Bool
  -> IDSupply -> Cover -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
nd_C__case_187 x5 x4 x3 x6 s cd cs = case x6 of
  Curry_Prelude.C_True -> let s0 = s
    in s0 `seq` Curry_Prelude.nd_OP_gt_gt (d_C_writeErrorMsg
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "unknown command: ") (Curry_Prelude.d_C_unwords (Curry_Prelude.OP_Cons x3
    x4) cd cs) cd cs) cd cs) x5 s0 cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (nd_C__case_187 x5 x4 x3 l s
    cd cs) (nd_C__case_187 x5 x4 x3 r s cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> nd_C__case_187 x5
    x4 x3 z s cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (nd_C__case_187 x5 x4 x3 e s
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_187"
    [show x5, show x4, show x3, show x6] info)
  _ -> failCons cd (consFail "REPL._case_187" (showCons x6))

d_C__case_197 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_197 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> d_C_cleanUpAndExitRepl x1 cd cs
  Curry_Prelude.C_False -> d_C__case_196 x1 (Curry_Prelude.d_C_otherwise cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_197 x1 l cd cs)
    (d_C__case_197 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_197 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_197 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_197"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_197" (showCons x2))

d_C__case_196 :: Curry_Linker.C_ReplState -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_196 x1 x2 cd cs = case x2 of
  Curry_Prelude.C_True -> Curry_Prelude.d_OP_gt_gt (Curry_Prelude.d_OP_gt_gt_eq
    (d_C_getBanner cd cs) (Curry_Linker.d_C_writeVerboseInfo x1
    (Curry_Prelude.C_Int 1#)) cd cs) (Curry_Prelude.d_OP_gt_gt
    (Curry_Linker.d_C_writeVerboseInfo x1 (Curry_Prelude.C_Int 1#)
    (Curry_Prelude.toCurryString
    "Type \":h\" for help  (contact: kics2@curry-language.org)") cd cs)
    (d_C_repl x1 cd cs) cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_C_failed cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_196 x1 l cd cs)
    (d_C__case_196 x1 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_196 x1
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_196 x1 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_196"
    [show x1, show x2] info)
  _ -> failCons cd (consFail "REPL._case_196" (showCons x2))

d_C__case_199 :: Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState -> Curry_Prelude.OP_List
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) -> Curry_Prelude.C_Bool -> Cover
  -> ConstStore -> Curry_Prelude.C_IO Curry_Prelude.OP_Unit
d_C__case_199 x1 x2 x3 x4 x5 cd cs = case x5 of
  Curry_Prelude.C_True -> d_C_processArgsAndStart (d_C__case_198 x4 x3 cd cs)
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.d_C_map (Curry_Utils.d_C_strip
    cd cs) (Curry_Prelude.d_C_words (Curry_RCFile.d_C_rcValue
    (Curry_Linker.d_C_rcvars x3 cd cs) (Curry_Prelude.toCurryString
    "defaultparams") cd cs) cd cs) cd cs) x2 cd cs) cd cs
  Curry_Prelude.C_False -> Curry_Prelude.d_OP_dollar Curry_Prelude.d_C_putStrLn
    (Curry_Prelude.d_OP_plus_plus (Curry_Prelude.toCurryString
    "Error: rc property name '") (Curry_Prelude.d_OP_plus_plus
    (Curry_Prelude.d_C_fst (Curry_Prelude.d_C_head x1 cd cs) cd cs)
    (Curry_Prelude.toCurryString "' not found in kics2rc file!") cd cs) cd cs)
    cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_199 x1 x2 x3 x4 l
    cd cs) (d_C__case_199 x1 x2 x3 x4 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_199 x1
    x2 x3 x4 z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_199 x1 x2 x3 x4 e
    cd $! addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_199"
    [show x1, show x2, show x3, show x4, show x5] info)
  _ -> failCons cd (consFail "REPL._case_199" (showCons x5))

d_C__case_198 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_198 x4 x3 cd cs = case x3 of
  Curry_Linker.C_ReplState x5 x6 x7 x8 x9 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 -> Curry_Linker.C_ReplState
    x5 x6 x7 x8 x4 x10 x11 x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24
    x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_198 x4 l cd
    cs) (d_C__case_198 x4 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_198
    x4 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_198 x4 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_198"
    [show x4, show x3] info)
  _ -> failCons cd (consFail "REPL._case_198" (showCons x3))

d_C__case_201 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.OP_List (Curry_Prelude.OP_Tuple2
  (Curry_Prelude.OP_List Curry_Prelude.C_Char) (Curry_Prelude.OP_List
  Curry_Prelude.C_Char)) -> Curry_Linker.C_ReplState -> Cover -> ConstStore
  -> Curry_Linker.C_ReplState
d_C__case_201 x8 x9 x43 cd cs = case x43 of
  Curry_Linker.C_ReplState x12 x13 x14 x15 x16 x17 x18 x19 x20 x21 x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 x36 x37 x38 x39 x40 x41 x42 -> Curry_Linker.C_ReplState
    (Curry_Installation.d_C_installDir cd cs) x9 x14 x15 x16 x17 x18 x19 x20 x21
    x22 x23 x24 x25 x26 x27 x28 x29 x30 x31 x32 x33 x34 x35 x36 x37
    (d_C__case_200 x8 (Curry_Prelude.d_C_null x8 cd cs) cd cs) x39 x40 x41 x42
  Curry_Linker.Choice_C_ReplState d i l r -> narrow d i (d_C__case_201 x8 x9 l
    cd cs) (d_C__case_201 x8 x9 r cd cs)
  Curry_Linker.Choices_C_ReplState d i xs -> narrows cs d i (\z -> d_C__case_201
    x8 x9 z cd cs) xs
  Curry_Linker.Guard_C_ReplState d c e -> guardCons d c (d_C__case_201 x8 x9 e
    cd $! addCs c cs)
  Curry_Linker.Fail_C_ReplState d info -> failCons d (traceFail "REPL._case_201"
    [show x8, show x9, show x43] info)
  _ -> failCons cd (consFail "REPL._case_201" (showCons x43))

d_C__case_200 :: Curry_Prelude.OP_List (Curry_Prelude.OP_List
  Curry_Prelude.C_Char) -> Curry_Prelude.C_Bool -> Cover -> ConstStore
  -> Curry_Prelude.OP_List Curry_Prelude.C_Char
d_C__case_200 x8 x9 cd cs = case x9 of
  Curry_Prelude.C_True -> Curry_Prelude.OP_List
  Curry_Prelude.C_False -> Curry_Prelude.d_C_unwords (Curry_Prelude.d_C_tail x8
    cd cs) cd cs
  Curry_Prelude.Choice_C_Bool d i l r -> narrow d i (d_C__case_200 x8 l cd cs)
    (d_C__case_200 x8 r cd cs)
  Curry_Prelude.Choices_C_Bool d i xs -> narrows cs d i (\z -> d_C__case_200 x8
    z cd cs) xs
  Curry_Prelude.Guard_C_Bool d c e -> guardCons d c (d_C__case_200 x8 e cd $!
    addCs c cs)
  Curry_Prelude.Fail_C_Bool d info -> failCons d (traceFail "REPL._case_200"
    [show x8, show x9] info)
  _ -> failCons cd (consFail "REPL._case_200" (showCons x9))

